@@ -659,7 +659,7 @@ void AddresseeEditorWidget::setupTab2()
           QHBox * nbox = new QHBox ( tab2 );
           label = new QLabel( i18n( "Birthday:" )+" ", nbox );
           mBirthdayPicker = new KDateEdit(  nbox  );
-          mBirthdayPicker->toggleDateFormat();
+          //mBirthdayPicker->toggleDateFormat();
           mBirthdayPicker->setHandleInvalid( true );
           connect( mBirthdayPicker, SIGNAL( dateChanged( QDate ) ),
                    SLOT( dateChanged( QDate ) ) );
@@ -681,7 +681,7 @@ void AddresseeEditorWidget::setupTab2()
           label = new QLabel( i18n( "Birthday:" ), tab2 );
           layout->addWidget( label, iii, 1 );
           mBirthdayPicker = new KDateEdit( tab2 );
-          mBirthdayPicker->toggleDateFormat();
+          //mBirthdayPicker->toggleDateFormat();
           mBirthdayPicker->setHandleInvalid( true );
           connect( mBirthdayPicker, SIGNAL( dateChanged( QDate ) ),
                    SLOT( dateChanged( QDate ) ) );
@@ -706,7 +706,7 @@ void AddresseeEditorWidget::setupTab2()
       label = new QLabel( i18n( "Gender:" ), tab2 );
       layout->addWidget( label, iii, 1 );
       mGenderBox = new QComboBox ( tab2 );
-      mGenderBox->insertItem ( i18n( "ALIEN (gender undefined)" ));
+      mGenderBox->insertItem ( i18n( "ALIEN (undefined)" ));
       mGenderBox->insertItem ( i18n( "female" ));
       mGenderBox->insertItem ( i18n( "male" ));
       connect( mGenderBox, SIGNAL(  activated ( const QString & )  ),
@@ -1079,8 +1079,6 @@ void AddresseeEditorWidget::save()
   mAddressee.setNote( mNoteEdit->text() );
   if ( mBirthdayPicker->inputIsValid() ) {
       QDate da = mBirthdayPicker->date();
-      if ( da > QDate::currentDate() )
-          da.setYMD(da.year()-100, da.month(), da.day() );
       mAddressee.setBirthday( QDateTime( da ) );
       //qDebug("bday %s ",da.toString().latin1());
   }
