@@ -26,6 +26,7 @@
 #include <qpixmap.h>
 #include <qlayout.h>
 #include <qprogressbar.h>
+#include <qprogressdialog.h>
 #include <qwidgetstack.h>
 #include <qdatetime.h>
 #include <qdir.h>
@@ -218,13 +219,13 @@ void KAImportOLdialog::readContactData( DWORD folder )
   LPDISPATCH itm;
   int i;
   folderItems = mf.GetItems(); 
-  QProgressBar bar( folderItems.GetCount(),0 );
-  bar.setCaption (i18n("Importing - close to abort!") );
+  QProgressDialog bar( i18n("Importing contact data"),i18n("Abort"), folderItems.GetCount(),this);
+  bar.setCaption (i18n("Importing!") );
   int h = bar.sizeHint().height() ;
   int w = 300;
   int dw = QApplication::desktop()->width();
   int dh = QApplication::desktop()->height();
-  bar.setGeometry( (dw-w)/2, (dh - h )/2 ,w,h );
+  //bar.setGeometry( (dw-w)/2, (dh - h )/2 ,w,h );
   bar.show();
   for(i=1; i <= folderItems.GetCount(); ++i)
     {
