@@ -244,6 +244,11 @@ void OpieMail::slotSearchMails()
 {
     qDebug("OpieMail::slotSearchMails():not implemented ");
 }
+void OpieMail::slotEditGlobalSettings()
+{
+    KPimPrefsGlobalDialog gc ( this );
+    gc.exec();
+}
 
 void OpieMail::slotEditSettings()
 {
@@ -485,6 +490,14 @@ void OpieMail::clearSelection()
     mailView->clearSelection();
   
 }
+void OpieMail::selectAll()
+{
+    QListViewItem* item = mailView->firstChild ();
+    while ( item ) {
+        mailView->setSelected ( item, true ); 
+        item = item->nextSibling();
+    }
+}
 
 void OpieMail::mailHold(int button, QListViewItem *item,const QPoint&,int  )
 {
@@ -515,6 +528,7 @@ void OpieMail::mailHold(int button, QListViewItem *item,const QPoint&,int  )
             m->insertItem(i18n("Move/Copy all selected mail"),this,SLOT(slotMoveCopyAllMail()));
             m->insertItem(i18n("Delete all selected mails"),this,SLOT(slotDeleteAllMail()));
             m->insertSeparator();
+            m->insertItem(i18n("Select all"),this,SLOT(selectAll()));
             m->insertItem(i18n("Clear selection"),this,SLOT(clearSelection()));
         }
         m->setFocus();
