@@ -30,6 +30,7 @@
 #include <qptrlist.h>
 #include <qvbox.h>
 #include <qmap.h>
+#include <qscrollbar.h>
 #ifndef DESKTOP_VERSION
 #include <qtopia/ir.h> 
 #else
@@ -44,12 +45,14 @@
 #include <korganizer/calendarviewbase.h>
 
 #include <ksyncmanager.h>
+//#include <koprefs.h>
 
 class QWidgetStack;
 class QSplitter;
-
+class KopiCalendarFile;
 class CalPrinter;
 class KOFilterView;
+class KOCalEditView;
 class KOViewManager;
 class KODialogManager;
 class KOTodoView;
@@ -134,6 +137,8 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     void showView(KOrg::BaseView *);
     KOEventViewerDialog* getEventViewerDialog();
     Incidence *currentSelection();
+    void checkSuspendAlarm();
+    void mergeFile( QString fn );
 
   signals:
     void save ();
@@ -192,10 +197,17 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     
     void calendarViewExpanded( bool );
     void updateSearchDialog();
+    void filtersUpdated();
 
 
-  public slots:
+  public slots: 
+    void nextConflict( bool all, bool allday );
+    void conflictAll();
+    void conflictAllday();
+    void conflictNotAll();
+    void setCalReadOnly( int id, bool readO );
     void checkAlarms();
+    void checkFiles();
     void slotprintSelInc();
     void showNextAlarms();
     void showOpenError();
@@ -221,6 +233,11 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
       loading. Return true, if calendar could be successfully loaded.
     */
     bool openCalendar(QString filename, bool merge=false);
+    bool loadCalendars();
+    bool saveCalendars();
+    bool restoreCalendarSettings();
+    bool addCalendar( KopiCalendarFile * );
+    void addCalendarId( int id );
     bool syncCalendar(QString filename,int mode = 0 );
 
     /**
@@ -349,6 +366,7 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
   
     /** edit viewing and configuration options. */
     void edit_options();
+    void edit_global_options();
     /**
       Functions for printing, previewing a print, and setting up printing
       parameters.
@@ -445,7 +463,6 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     void toggleExpand();
     void toggleDateNavigatorWidget();
     void toggleAllDaySize();
-    void dialogClosing(Incidence *);
   
     /** Look for new messages in the inbox */
     void lookForIncomingMessages();
@@ -475,6 +492,7 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     void beamFilteredCalendar() ;
     void beamIncidenceList(QPtrList<Incidence>) ;
     void manageCategories();
+    void editCategories();
     int addCategories();
     void removeCategories();
     void setSyncDevice( QString );
@@ -483,6 +501,7 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     void undo_delete();
   protected slots:
     void resetFocus();
+    void scrollBarValue(int);
     void slotViewerClosed();
     void timerAlarm();
     void suspendAlarm();
@@ -490,6 +509,7 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     /** Select a view or adapt the current view to display the specified dates. */
     void showDates( const KCal::DateList & );
     void selectWeekNum ( int );
+    void checkConflictForEvent();
   
   public:
     // show a standard warning
@@ -502,6 +522,7 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     void setSyncManager(KSyncManager* manager);
     void setLoadedFileVersion(QDateTime);
     bool checkFileVersion(QString fn);
+    bool checkAllFileVersions();
     bool checkFileChanged(QString fn);
     Event* getLastSyncEvent();
     /** Adapt navigation units correpsonding to step size of navigation of the
@@ -512,17 +533,21 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     int  takeEvent( Incidence* local,  Incidence* remote, int mode, bool full = false );
     //Attendee* getYourAttendee(Event *event);
     void setBlockShowDates( bool b ) { mBlockShowDates = b ;}
+    void setScrollBarStep(int val );
+
   protected:
+    Event *mConflictingEvent;
     void schedule(Scheduler::Method, Incidence *incidence = 0);
     
     // returns KMsgBox::OKCandel()
     int msgItemDelete(const QString name);
     void showEventEditor();
     void showTodoEditor();
-    void writeLocale();
     Todo *selectedTodo();
-
   private:
+#ifdef DESKTOP_VERSION
+    QScrollBar * mDateScrollBar;
+#endif
     QDateTime mNextAlarmDateTime;
     bool mViewerCallerIsSearchDialog;
     bool mBlockShowDates;
@@ -543,7 +568,6 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     int mGlobalSyncMode;
     QString  mCurrentSyncDevice;
     QString  mCurrentSyncName;
-    KOBeamPrefs* beamDialog;
     void init();
     int mDatePickerMode;
     bool mFlagEditDescription;
@@ -565,6 +589,7 @@ class CalendarView : public KOrg::CalendarViewBase, public KCal::Calendar::Obser
     DateNavigatorContainer *mDateNavigator;       // widget showing small month view.
 
     KOFilterView *mFilterView;
+    KOCalEditView *mCalEditView;
 
     ResourceView *mResourceView;
 
