@@ -60,6 +60,7 @@ extern int globalFlagBlockAgendaItemPaint;
 extern int globalFlagBlockAgendaItemUpdate;
 extern int globalFlagBlockStartup;
 
+
 ////////////////////////////////////////////////////////////////////////////
 MarcusBains::MarcusBains(KOAgenda *_agenda,const char *name)
     : QFrame(_agenda->viewport(),name), agenda(_agenda)
@@ -84,7 +85,7 @@ MarcusBains::MarcusBains(KOAgenda *_agenda,const char *name)
 
 MarcusBains::~MarcusBains()
 {
-    delete minutes;
+    //delete minutes;
 }
 
 int MarcusBains::todayColumn()
@@ -150,10 +151,10 @@ void MarcusBains::updateLocation(bool recalculate)
     agenda->moveChild(mTimeBox,
                x+agenda->gridSpacingX()-mTimeBox->width()+offs-1,
                   y-mTimeBox->height());
- 
     mTimeBox->raise();
     //mTimeBox->setAutoMask(true);
-    minutes->start(5000,true);
+    int secs = QTime::currentTime().second();
+    minutes->start( (60 - secs +1)*1000 ,true);
 }
 
 
@@ -178,6 +179,7 @@ KOAgenda::KOAgenda(int columns,int rows,int rowSize,QWidget *parent,
 #endif
   mHolidayMask = 0;
   init();
+  connect ( this, SIGNAL (contentsMoving ( int , int )   ), this, SLOT ( slotContentMove(int,int)) );
 }
 
 /*
@@ -317,8 +319,25 @@ void KOAgenda::init()
   }  
   mPopupKind = 0;
   mPopupItem =  0; 
+  mInvalidPixmap = false;
+  
 }
 
+void KOAgenda::shrinkPixmap()
+{
+    mPaintPixmap.resize( 20,20);
+    mInvalidPixmap = true;
+}
+void KOAgenda::slotContentMove(int,int)
+{
+    emit sendPing(); 
+    if ( mActionType == NOP )
+        slotClearSelection(); 
+    if ( mSelectedItem && !mActionItem ) {
+        deselectItem();
+        emit incidenceSelected( 0 );
+    }
+}
 void KOAgenda::clear()
 {
   KOAgendaItem *item;
@@ -408,9 +427,27 @@ void KOAgenda::popupMenu()
     mPopupItem = 0;
     mPopupKind = 0;
 }
-
+void KOAgenda::categoryChanged(Incidence * inc)
+{
+    KOAgendaItem *item;
+    for ( item=mItems.first(); item != 0; item=mItems.next() ) {
+        if ( item->incidence() == inc ) {
+            item->initColor ();
+            item->updateItem();
+        }
+    }
+}
 bool KOAgenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
 {
+
+    if ( mInvalidPixmap ) {
+        mInvalidPixmap = false;
+        qDebug("KO: Upsizing Pixmaps ");
+        computeSizes();
+        emit updateViewSignal();
+        return true;
+    } 
+    emit sendPing(); 
     static int startX = 0;
     static int startY = 0;
     int blockmoveDist = ( QApplication::desktop()->width() < 480 ? 7 : 9 );
@@ -456,7 +493,11 @@ bool KOAgenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
     } else {
         viewportPos = me->pos();
     }
-    
+    bool objIsNotViewport = (object != viewport());
+    bool leftButt = false;
+#ifdef DESKTOP_VERSION
+    leftButt  = (me->button() == LeftButton);
+#endif
     switch (me->type())  {
     case QEvent::MouseButtonPress:
         if (me->button() == LeftButton) {
@@ -467,7 +508,65 @@ bool KOAgenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
         startX = viewportPos.x();
         startY = viewportPos.y();  
         mPopupPos = me->globalPos();
-        if (object != viewport()) {
+        if (  objIsNotViewport && !leftButt ) {
+            KOAgendaItem * tempItem = (KOAgendaItem *)object;
+            if (mAllDayMode) {
+                if ( tempItem->height() > 10 ) {
+                    int minV = tempItem->height()/4;
+                    if ( minV > (blockmoveDist/2)-2 ) {
+                        if ( minV > blockmoveDist )
+                            minV = blockmoveDist;
+                        else
+                            minV = (blockmoveDist/2);
+                    }
+                    bool border = false;
+                    int diff = tempItem->y() - viewportPos.y();
+                    if ( diff < 0 )
+                        diff *= -1;
+                    if ( diff < minV ) {
+                        border = true;
+                        objIsNotViewport = false;
+                    }
+                    if ( ! border ) {
+                        diff = tempItem->y() + tempItem->height()- viewportPos.y();
+                        if ( diff < 0 )
+                            diff *= -1;
+                        if ( diff < minV ) {
+                            border = true;
+                            objIsNotViewport = false;
+                        }
+                    }
+                }
+            } else { // not allday
+                if ( tempItem->width() > 10 ) {
+                    int minH = tempItem->width()/4;
+                    if ( minH > (blockmoveDist/2)-2 ) {
+                        if ( minH > blockmoveDist )
+                            minH = blockmoveDist;
+                        else
+                            minH = (blockmoveDist/2);
+                    }
+                    bool border = false;
+                    int diff = tempItem->x() - viewportPos.x();
+                    if ( diff < 0 )
+                        diff *= -1;
+                    if ( diff < minH ) {
+                        border = true;
+                        objIsNotViewport = false;
+                    }
+                    if ( ! border ) {
+                        diff = tempItem->x() + tempItem->width() - viewportPos.x();
+                        if ( diff < 0 )
+                            diff *= -1;
+                        if ( diff < minH ) {
+                            border = true;
+                            objIsNotViewport = false;
+                        }          
+                    }
+                }
+            }
+        }
+        if ( objIsNotViewport ) {
             mPopupItem = (KOAgendaItem *)object;
             mPopupKind = 1;
             if (me->button() == RightButton) {
@@ -480,7 +579,7 @@ bool KOAgenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
                     slotClearSelection();
                     selectItem(mActionItem);
                     Incidence *incidence = mActionItem->incidence();
-                    if ( incidence->isReadOnly() /*|| incidence->recurrence()->doesRecur() */) {
+                    if ( incidence->isReadOnly() /*|| incidence->doesRecur() */) {
                         mActionItem = 0;
                     } else {
                         startItemAction(viewportPos);
@@ -753,7 +852,7 @@ void KOAgenda::startItemAction(QPoint viewportPos)
     }
   } else {
     int gridDistanceY = (y - gy * mGridSpacingY);
-    bool allowResize = ( mActionItem->incidence()->type() != "Todo" );
+    bool allowResize = ( mActionItem->incidence()->typeID() != todoID );
     if (allowResize && gridDistanceY < mResizeBorderWidth &&
         mActionItem->cellYTop() == mCurrentCellY &&
         !mActionItem->firstMultiItem()) {
@@ -851,6 +950,7 @@ void KOAgenda::performItemAction(QPoint viewportPos)
         gridToContents(moveItem->cellX(),moveItem->cellYTop(),x,y);
         moveItem->resize(mGridSpacingX * moveItem->cellWidth(),
                          mGridSpacingY * moveItem->cellHeight());
+        moveItem->raise();
         moveChild(moveItem,x,y);
         moveItem = moveItem->nextMultiItem();
       }
@@ -899,7 +999,7 @@ void KOAgenda::endItemAction()
         if ( !placeItem ) {
             placeItem = mActionItem;      
         }
-        if ( placeItem->incidence()->recurrence()->doesRecur() ) {
+        if ( placeItem->incidence()->doesRecur() ) {
             Incidence* oldInc =  placeItem->incidence();
             placeItem->recreateIncidence();
             emit addToCalSignal(placeItem->incidence(), oldInc );
@@ -912,7 +1012,7 @@ void KOAgenda::endItemAction()
         QPtrList<KOAgendaItem> oldconflictItems ;//= placeItem->conflictItems();
         KOAgendaItem *item;
   
-        if ( placeItem->incidence()->type() == "Todo" ) {
+        if ( placeItem->incidence()->typeID() == todoID ) {
             mSelectedItem = 0;
             //qDebug("todo %d %d %d ", mCurrentCellX, modifiedItem->cellX() ,modifiedItem->cellXWidth());
             modifiedItem->mLastMoveXPos = mCurrentCellX;
@@ -996,7 +1096,8 @@ void KOAgenda::endItemAction()
         }
      
     }
-
+    if ( mActionItem )
+        emit incidenceSelected( mActionItem->incidence() );
     mScrollUpTimer.stop();
     mScrollDownTimer.stop();
     setCursor( arrowCursor );
@@ -1064,7 +1165,7 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
 
     QPtrList<KOAgendaItem> conflictItems;
     int maxSubCells = 0;
-    QIntDict<KOAgendaItem> subCellDict(5);
+    QIntDict<KOAgendaItem> subCellDict(7);
 
     KOAgendaItem *item;
     for ( item=mItems.first(); item != 0; item=mItems.next() ) {
@@ -1173,13 +1274,24 @@ void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
 {
     if ( globalFlagBlockAgenda )
         return;
+
+    if ( mInvalidPixmap ) {
+        mInvalidPixmap = false;
+        qDebug("KO: Upsizing Pixmaps ");
+        computeSizes();
+        emit updateViewSignal();
+        return;
+    }
     if ( ! mAllDayMode ) {
         // currently not working for
    
         //qDebug("KOAgenda::drawContents ");
-        if (  mCurPixWid != contentsWidth() || mCurPixHei != contentsHeight() )
-            ;//drawContentsToPainter();
-   
+#if 0
+        if (  mCurPixWid != contentsWidth() || mCurPixHei != contentsHeight() ) {
+            qDebug("WAU ");
+            drawContentsToPainter();
+        }
+#endif
         QPaintDevice* pd = p->device();
         p->end();
         int vx, vy; 
@@ -1209,15 +1321,27 @@ void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
             if ( ( cx + cw ) >= selectionX && cx <= ( selectionX + mGridSpacingX ) &&
                  ( cy + ch ) >= mSelectionYTop && cy <= ( mSelectionYTop + mSelectionHeight ) ) {
                 contentsToViewport ( selectionX, mSelectionYTop, vx,vy); 
-                bitBlt ( pd, vx+1, vy, &mHighlightPixmap, 0, mSelectionYTop, mGridSpacingX-1, mSelectionHeight ,CopyROP); 
+                // bitBlt ( pd, vx+1, vy, &mHighlightPixmap, 0, mSelectionYTop, mGridSpacingX-1, mSelectionHeight ,CopyROP); 
+                int hei = mSelectionHeight;
+                int offset = 0;
+                while ( hei > 0 ) {
+                    int p_hei = 5;
+                    if ( hei < 5 ) p_hei = hei;
+                    hei -= 5;
+                    bitBlt ( pd, vx+1, vy+offset, &mHighlightPixmap, 0, 0, mGridSpacingX-1, p_hei ,CopyROP); 
+                    offset += 5;
+                }
             }     
         } 
         p->begin( pd );
     } else {
- 
-        if (  mCurPixWid != contentsWidth() || mCurPixHei != contentsHeight() )
-            ;//drawContentsToPainter();
-   
+#if 0
+        qDebug("mCurPixWid  %d %d ",mCurPixWid, contentsWidth() );
+        if (  mCurPixWid != contentsWidth() || mCurPixHei != contentsHeight() ) {
+            qDebug("WAUWAU ");
+            drawContentsToPainter();
+        }
+#endif
         QPaintDevice* pd = p->device();
         p->end();
         int vx, vy; 
@@ -1234,7 +1358,16 @@ void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
             if ( ( cx + cw ) >= selectionX && cx <= ( selectionX + mGridSpacingX ) &&
                  ( cy + ch ) >= mSelectionYTop && cy <= ( mSelectionYTop + mSelectionHeight ) ) {
                 contentsToViewport ( selectionX, mSelectionYTop, vx,vy); 
-                bitBlt ( pd, vx+1, vy, &mHighlightPixmap, 0, mSelectionYTop, mGridSpacingX-1, mSelectionHeight ,CopyROP); 
+                //bitBlt ( pd, vx+1, vy, &mHighlightPixmap, 0, mSelectionYTop, mGridSpacingX-1, mSelectionHeight ,CopyROP); 
+                int hei = mSelectionHeight;
+                int offset = 0;
+                while ( hei > 0 ) {
+                    int p_hei = 5;
+                    if ( hei < 5 ) p_hei = hei;
+                    hei -= 5;
+                    bitBlt ( pd, vx+1, vy+offset, &mHighlightPixmap, 0, 0, mGridSpacingX-1, p_hei ,CopyROP); 
+                    offset += 5;
+                }
             }     
         } 
         p->begin( pd );
@@ -1285,7 +1418,7 @@ void KOAgenda::finishUpdate()
     for ( item=mItems.first(); item != 0; item=mItems.next() ) {
         item->repaint( false );
     }
-    
+    marcus_bains();
 }
 
 /*
@@ -1307,8 +1440,8 @@ void KOAgenda::drawContentsToPainter( QPainter* paint, bool backgroundOnly )// i
     }
     mCurPixWid = contentsWidth();
     mCurPixHei = ch;
-    if ( mHighlightPixmap.width() < mGridSpacingX-1 ||  mHighlightPixmap.height() < ch ) {
-        mHighlightPixmap.resize( mGridSpacingX-1, ch );
+    if ( mHighlightPixmap.width() < mGridSpacingX-1  ) {
+        mHighlightPixmap.resize( mGridSpacingX-1, 5 );
         mHighlightPixmap.fill ( KOPrefs::instance()->mHighlightColor );
     }
     mPixPainter.begin( &mPaintPixmap) ;
@@ -1323,119 +1456,121 @@ void KOAgenda::drawContentsToPainter( QPainter* paint, bool backgroundOnly )// i
     // qDebug("++++++KOAgenda::drawContentsTo Painter %d %d %d %d ",  cx, cy, cw, ch); 
    
     //--cx;++cw;
-  int lGridSpacingY = mGridSpacingY*2;
-  int selDay;
-  if ( !backgroundOnly )
-  for ( selDay = 0; selDay < mSelectedDates.count();  ++selDay)
-      {
-          if ( mSelectedDates[selDay] == QDateTime::currentDateTime ().date() && KOPrefs::instance()->mHighlightCurrentDay) {
-              int x1 = cx;
-              int y1 = 0;
-              if (y1 < cy) y1 = cy;
-              int x2 = cx+cw-1;
-              int y2 = contentsHeight();
-              if (y2 > cy+ch-1) y2=cy+ch-1;
-              if (x2 >= x1 && y2 >= y1) {
-                  int gxStart = selDay;
-                  int gxEnd = gxStart ;
-                  int xStart = KOGlobals::self()->reverseLayout() ?
-                      (mColumns - 1 - gxStart)*mGridSpacingX :
-                      gxStart*mGridSpacingX;
-                  if (xStart < x1) xStart = x1;
-                  int xEnd = KOGlobals::self()->reverseLayout() ?
-                      (mColumns - gxStart)*mGridSpacingX-1 :
-                      (gxStart+1)*mGridSpacingX-1;
-                  if (xEnd > x2) xEnd = x2;
-                  if ( KOPrefs::instance()->mUseHighlightLightColor )
-                      p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
-                                  KOPrefs::instance()->mAgendaBgColor.light());
-                  else
-                      p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
-                                  KOPrefs::instance()->mAgendaBgColor.dark());
+    int lGridSpacingY = mGridSpacingY*2;
+    int selDay;
+    QDate curDate = QDate::currentDate();
+    if ( !backgroundOnly ) {
+        for ( selDay = 0; selDay < mSelectedDates.count();  ++selDay)
+            {
+                if ( mSelectedDates[selDay] == curDate && KOPrefs::instance()->mHighlightCurrentDay) {
+                    int x1 = cx;
+                    int y1 = 0;
+                    if (y1 < cy) y1 = cy;
+                    int x2 = cx+cw-1;
+                    int y2 = contentsHeight();
+                    if (y2 > cy+ch-1) y2=cy+ch-1;
+                    if (x2 >= x1 && y2 >= y1) {
+                        int gxStart = selDay;
+                        int gxEnd = gxStart ;
+                        int xStart = KOGlobals::self()->reverseLayout() ?
+                            (mColumns - 1 - gxStart)*mGridSpacingX :
+                            gxStart*mGridSpacingX;
+                        if (xStart < x1) xStart = x1;
+                        int xEnd = KOGlobals::self()->reverseLayout() ?
+                            (mColumns - gxStart)*mGridSpacingX-1 :
+                            (gxStart+1)*mGridSpacingX-1;
+                        if (xEnd > x2) xEnd = x2;
+                        if ( KOPrefs::instance()->mUseHighlightLightColor )
+                            p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
+                                        KOPrefs::instance()->mAgendaBgColor.light());
+                        else
+                            p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
+                                        KOPrefs::instance()->mAgendaBgColor.dark());
                       
-              } 
-          }
-      }
-  // Highlight working hours
-
-  if ( !backgroundOnly )
-  if (mWorkingHoursEnable) {
-    int x1 = cx;
-    int y1 = mWorkingHoursYTop;
-    if (y1 < cy) y1 = cy;
-    int x2 = cx+cw-1;
-    //  int x2 = mGridSpacingX * 5 - 1;
-    //  if (x2 > cx+cw-1) x2 = cx + cw - 1;
-    int y2 = mWorkingHoursYBottom;
-    if (y2 > cy+ch-1) y2=cy+ch-1;
-
-    if (x2 >= x1 && y2 >= y1) {
-        // qDebug("x1 %d mGridSpacingX %d ", x1, mGridSpacingX );
-      int gxStart = x1/mGridSpacingX;
-      int gxEnd = x2/mGridSpacingX;
-      while(gxStart <= gxEnd) {
-        if (gxStart < int(mHolidayMask->count()) &&
-            !mHolidayMask->at(gxStart)) {
-          int xStart = KOGlobals::self()->reverseLayout() ?
-                                    (mColumns - 1 - gxStart)*mGridSpacingX :
-                                     gxStart*mGridSpacingX;
-          if (xStart < x1) xStart = x1;
-          int xEnd = KOGlobals::self()->reverseLayout() ?
-                                    (mColumns - gxStart)*mGridSpacingX-1 :
-                                    (gxStart+1)*mGridSpacingX-1;
-          if (xEnd > x2) xEnd = x2;
-          if ( mSelectedDates[gxStart] == QDateTime::currentDateTime ().date()&& KOPrefs::instance()->mHighlightCurrentDay ) {
-              if ( KOPrefs::instance()->mUseHighlightLightColor )
-                  p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
-                              KOPrefs::instance()->mWorkingHoursColor.light());
-              else
-                  p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
-                              KOPrefs::instance()->mWorkingHoursColor.dark());
-          } else {
-              p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
-                          KOPrefs::instance()->mWorkingHoursColor);
-          }
-        }
-        ++gxStart;
-      }
+                    } 
+                }
+            }
     }
-  }
-  /*
-  int selectionX = KOGlobals::self()->reverseLayout() ?
-                   (mColumns - 1 - mSelectionCellX) * mGridSpacingX : 
-                    mSelectionCellX * mGridSpacingX;
+    // Highlight working hours
 
-  // Draw selection
-  if ( ( cx + cw ) >= selectionX && cx <= ( selectionX + mGridSpacingX ) &&
-       ( cy + ch ) >= mSelectionYTop && cy <= ( mSelectionYTop + mSelectionHeight ) ) {
-    // TODO: paint only part within cx,cy,cw,ch
-    p->fillRect( selectionX, mSelectionYTop, mGridSpacingX,
-                 mSelectionHeight, KOPrefs::instance()->mHighlightColor );
-  }
-  */
-  // Draw vertical lines of grid
- 
-  int x = ((int)(cx/mGridSpacingX))*mGridSpacingX;
-  if ( mGridSpacingX > 0 ) {
-      while (x < cx + cw) {
-          p->drawLine(x,cy,x,cy+ch);
-          x+=mGridSpacingX;
+    if ( !backgroundOnly )
+        if (mWorkingHoursEnable) {
+            int x1 = cx;
+            int y1 = mWorkingHoursYTop;
+            if (y1 < cy) y1 = cy;
+            int x2 = cx+cw-1;
+            //  int x2 = mGridSpacingX * 5 - 1;
+            //  if (x2 > cx+cw-1) x2 = cx + cw - 1;
+            int y2 = mWorkingHoursYBottom;
+            if (y2 > cy+ch-1) y2=cy+ch-1;
+
+            if (x2 >= x1 && y2 >= y1) {
+                // qDebug("x1 %d mGridSpacingX %d ", x1, mGridSpacingX );
+                int gxStart = x1/mGridSpacingX;
+                int gxEnd = x2/mGridSpacingX;
+                while(gxStart <= gxEnd) {
+                    if (gxStart < int(mHolidayMask->count()) &&
+                        !mHolidayMask->at(gxStart)) {
+                        int xStart = KOGlobals::self()->reverseLayout() ?
+                            (mColumns - 1 - gxStart)*mGridSpacingX :
+                            gxStart*mGridSpacingX;
+                        if (xStart < x1) xStart = x1;
+                        int xEnd = KOGlobals::self()->reverseLayout() ?
+                            (mColumns - gxStart)*mGridSpacingX-1 :
+                            (gxStart+1)*mGridSpacingX-1;
+                        if (xEnd > x2) xEnd = x2;
+                        if ( mSelectedDates[gxStart] == curDate && KOPrefs::instance()->mHighlightCurrentDay ) {
+                            if ( KOPrefs::instance()->mUseHighlightLightColor )
+                                p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
+                                            KOPrefs::instance()->mWorkingHoursColor.light());
+                            else
+                                p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
+                                            KOPrefs::instance()->mWorkingHoursColor.dark());
+                        } else {
+                            p->fillRect(xStart,y1,xEnd-xStart+1,y2-y1+1,
+                                        KOPrefs::instance()->mWorkingHoursColor);
+                        }
+                    }
+                    ++gxStart;
+                }
+            }
+        }
+    /*
+      int selectionX = KOGlobals::self()->reverseLayout() ?
+      (mColumns - 1 - mSelectionCellX) * mGridSpacingX : 
+      mSelectionCellX * mGridSpacingX;
+
+      // Draw selection
+      if ( ( cx + cw ) >= selectionX && cx <= ( selectionX + mGridSpacingX ) &&
+      ( cy + ch ) >= mSelectionYTop && cy <= ( mSelectionYTop + mSelectionHeight ) ) {
+      // TODO: paint only part within cx,cy,cw,ch
+      p->fillRect( selectionX, mSelectionYTop, mGridSpacingX,
+      mSelectionHeight, KOPrefs::instance()->mHighlightColor );
       }
-  }
-  // Draw horizontal lines of grid
-  int y = ((int)(cy/lGridSpacingY))*lGridSpacingY;
-  if ( lGridSpacingY > 0 ) {
-      while (y < cy + ch) {
-          p->setPen( SolidLine );
-          p->drawLine(cx,y,cx+cw,y);
-          y+=lGridSpacingY;
-          p->setPen( DotLine );
-          p->drawLine(cx,y,cx+cw,y);
-          y+=lGridSpacingY;
-      } 
-      p->setPen( SolidLine );
-  }
-   mPixPainter.end() ;
+    */
+    // Draw vertical lines of grid
+ 
+    int x = ((int)(cx/mGridSpacingX))*mGridSpacingX;
+    if ( mGridSpacingX > 0 ) {
+        while (x < cx + cw) {
+            p->drawLine(x,cy,x,cy+ch);
+            x+=mGridSpacingX;
+        }
+    }
+    // Draw horizontal lines of grid
+    int y = ((int)(cy/lGridSpacingY))*lGridSpacingY;
+    if ( lGridSpacingY > 0 ) {
+        while (y < cy + ch) {
+            p->setPen( SolidLine );
+            p->drawLine(cx,y,cx+cw,y);
+            y+=lGridSpacingY;
+            p->setPen( DotLine );
+            p->drawLine(cx,y,cx+cw,y);
+            y+=lGridSpacingY;
+        } 
+        p->setPen( SolidLine );
+    }
+    mPixPainter.end() ;
 }
 
 /*
@@ -1498,6 +1633,13 @@ void KOAgenda::setStartHour(int startHour)
   int startCell = startHour * mRows / 24;
   setContentsPos(0,startCell * gridSpacingY());
 }
+QTime KOAgenda::getEndTime()
+{
+    int tim = (contentsY ()+viewport()->height())*24/contentsHeight ();
+    if ( tim > 23 )
+        return QTime ( 23,59,59);
+    return QTime ( tim,0,0);
+}
 void KOAgenda::hideUnused()
 {
     // experimental only
@@ -1575,8 +1717,10 @@ void KOAgenda::updateTodo( Todo * todo, int days, bool remove)
             globalFlagBlockAgendaItemUpdate = 0;
             if ( itemit != item )
                 itemit->repaintMe();
-            globalFlagBlockAgendaItemUpdate = 1;
-            itemit->repaint(); 
+            globalFlagBlockAgendaItemUpdate = 1; 
+            //qDebug("sigleshot ");
+            QTimer::singleShot( 0, itemit, SLOT ( repaintItem() ));
+            //itemit->repaint( false ); repaintItem()
         }
         blockSignals( false );
     }
@@ -1587,15 +1731,14 @@ void KOAgenda::updateTodo( Todo * todo, int days, bool remove)
     if ( todo->hasCompletedDate() && !KOPrefs::instance()->mShowCompletedTodoInAgenda )
         return;
     //qDebug("updateTodo+++++++++++++++++++++++++++++++++++++ ");
-    bool overdue = (!todo->isCompleted()) && (todo->dtDue() < QDate::currentDate())&&  ( KOPrefs::instance()->mShowTodoInAgenda );
-    QDate currentDate;
+    QDate currentDate = QDate::currentDate();
+    bool overdue = (!todo->isCompleted()) && (todo->dtDue() < currentDate)&&  ( KOPrefs::instance()->mShowTodoInAgenda );
     QDateTime dt;
     if ( todo->hasCompletedDate() )
         dt =  todo->completed();
     else
         dt = todo->dtDue();
     if ( overdue ) {
-        currentDate = QDate::currentDate();
         days += todo->dtDue().date().daysTo( currentDate );
     }
     else
@@ -1665,7 +1808,6 @@ KOAgendaItem *KOAgenda::insertItem (Incidence *event,QDate qd,int X,int YTop,int
 
   //agendaItem->show();
 
-  marcus_bains();
 
   return agendaItem;
 }
@@ -1738,8 +1880,6 @@ void KOAgenda::insertMultiItem (Event *event,QDate qd,int XBegin,int XEnd,
     current->setMultiItem(setFirst,next,setLast);
     current = next;
   }
-
-  marcus_bains();
 }
 
 
@@ -1823,16 +1963,19 @@ void KOAgenda::computeSizes()
     int ch = contentsHeight();
     if ( mAllDayMode ) { 
         QPixmap* paintPixAll = KOAgendaItem::paintPixAllday();
-        if ( (paintPixAll->width() < cw || paintPixAll->height() <  ch) && cw > 0  && ch > 0  )
+        if ( (paintPixAll->width() < cw || paintPixAll->height() <  ch) && cw > 0  && ch > 0  ) {
+            //qDebug("paintPixAll->resize ");
             paintPixAll->resize( cw, ch ); 
+        }
     } else {
         QPixmap* paintPix = KOAgendaItem::paintPix();
-        if ( paintPix->width() < cw || paintPix->height() <  ch )
-            KOAgendaItem::resizePixmap( cw , ch );
+        if ( paintPix->width() < cw || paintPix->height() <  ch ) {
+            //qDebug("paintPix->resize ");
+            paintPix->resize( cw , ch );
+        }
     }
 
     checkScrollBoundaries();
-    marcus_bains();
     drawContentsToPainter();
     viewport()->repaint(false);
 }
@@ -1892,7 +2035,6 @@ void KOAgenda::updateConfig()
   else {
       mGridSpacingY = KOPrefs::instance()->mHourSize;
       calculateWorkingHours();
-      marcus_bains();
   }
 }
 
@@ -1985,7 +2127,6 @@ DateList KOAgenda::dateList() const
 void KOAgenda::setDateList(const DateList &selectedDates)
 {
     mSelectedDates = selectedDates;
-    marcus_bains();
 }
 
 void KOAgenda::setHolidayMask(QMemArray<bool> *mask)
