@@ -97,19 +97,13 @@ QString KOAgendaItem::getWhatsThisText()
                                                                   KOPrefs::instance()->mWTshowChanged);
     return "KOAgendaItem::getWhatsThisText()::internal error";
 }
-void KOAgendaItem::init ( Incidence *incidence, QDate qd )
+
+void KOAgendaItem::initColor ()
 {
-    mIncidence = incidence;
-    mDate = qd;
-    mFirstMultiItem = 0;
-    mNextMultiItem = 0;
-    mLastMultiItem = 0;  
-    computeText();
-   
-    if ( (incidence->type() == "Todo") &&
-         ( !((static_cast<Todo*>(incidence))->isCompleted()) &&
-           ((static_cast<Todo*>(incidence))->dtDue().date() <=  QDate::currentDate()) ) ) {
-        if (  (static_cast<Todo*>(incidence))->dtDue() <  QDateTime::currentDateTime().date()) 
+    if ( (mIncidence->typeID() == todoID ) &&
+         ( !((static_cast<Todo*>(mIncidence))->isCompleted()) &&
+           ((static_cast<Todo*>(mIncidence))->dtDue().date() <=  QDate::currentDate()) ) ) {
+        if (  (static_cast<Todo*>(mIncidence))->dtDue() <  QDateTime::currentDateTime().date()) 
             mBackgroundColor = KOPrefs::instance()->mTodoOverdueColor ;
         else 
             mBackgroundColor = KOPrefs::instance()->mTodoDueTodayColor;
@@ -118,24 +112,39 @@ void KOAgendaItem::init ( Incidence *incidence, QDate qd )
         QStringList categories = mIncidence->categories();
         QString cat = categories.first();
         if (cat.isEmpty()) {
-            if ( (incidence->type() == "Todo") &&((static_cast<Todo*>(incidence))->isCompleted()) )
+            if ( (mIncidence->typeID() == todoID ) &&((static_cast<Todo*>(mIncidence))->isCompleted()) )
                 mBackgroundColor =KOPrefs::instance()->mTodoDoneColor;
             else
-                mBackgroundColor =KOPrefs::instance()->mEventColor;
+                mBackgroundColor =KOPrefs::instance()->defaultColor( mIncidence->calID() );
         } else {
             mBackgroundColor = *KOPrefs::instance()->categoryColor(cat);
-            if ( (incidence->type() == "Todo") &&((static_cast<Todo*>(incidence))->isCompleted()) ) {
+            if ( (mIncidence->typeID() == todoID ) &&((static_cast<Todo*>(mIncidence))->isCompleted()) ) {
                 if ( mBackgroundColor == KOPrefs::instance()->mEventColor )
-                    mBackgroundColor =KOPrefs::instance()->mTodoDoneColor;
+                    mBackgroundColor = KOPrefs::instance()->mTodoDoneColor;
             }
         }
             
     }
-    mColorGroup  = QColorGroup( mBackgroundColor.light(), 
-                                mBackgroundColor.dark(),mBackgroundColor.light(),
-                                mBackgroundColor.dark(),mBackgroundColor, black, mBackgroundColor) ;
+
+    QColor BackgroundColor ( mBackgroundColor );
+    if ( mIncidence->calID() > 1 ) {
+        //BackgroundColor = KOPrefs::instance()->defaultColor( mIncidence->calID() );
+    }
+    mColorGroup  = QColorGroup( BackgroundColor.light(), 
+                                BackgroundColor.dark(),BackgroundColor.light(),
+                                BackgroundColor.dark(),BackgroundColor, black, BackgroundColor) ;
     setBackgroundColor( mBackgroundColor );
-   
+    mWhiteText = (mBackgroundColor.red() + mBackgroundColor.green() + mBackgroundColor.blue() < 250);
+}
+void KOAgendaItem::init ( Incidence *incidence, QDate qd )
+{
+    mIncidence = incidence;
+    mDate = qd;
+    mFirstMultiItem = 0;
+    mNextMultiItem = 0;
+    mLastMultiItem = 0;  
+    computeText();
+    initColor();
     mConflictItems.clear();
     setCellXY(0,0,1);
     setCellXWidth(0);
@@ -185,13 +194,30 @@ bool KOAgendaItem::updateIcons(QPainter * p, bool horLayout)
 
     int yOff = 0;
     int xOff = 0;
-    int x = pos().x() +3; 
+    int x = pos().x();
+
+    if ( x < 0 ) x = 0;
+    x += 3; 
     int y;
     if ( mAllDay )
         y = pos().y()+3;
     else
         y =  mCellYTop * ( height() / cellHeight() ) +3;
-    if (mIncidence->cancelled()) {
+
+
+    if ( mIncidence->calID() > 1 ) {
+        p->fillRect ( xOff*( 1 +AGENDA_ICON_SIZE )+x, yOff*( 1 +AGENDA_ICON_SIZE)+y, AGENDA_ICON_SIZE, AGENDA_ICON_SIZE, KOPrefs::instance()->defaultColor( mIncidence->calID() ) );
+        p->drawRect ( xOff*( 1 +AGENDA_ICON_SIZE )+x-1, yOff*( 1 +AGENDA_ICON_SIZE)+y-1, AGENDA_ICON_SIZE+2, AGENDA_ICON_SIZE+2 );
+        if ( horLayout ){
+            ++xOff;
+            ++x;
+        }
+        else {
+            ++yOff;
+            ++y;
+        }
+    }
+    if (mIncidence->cancelled() &&  height() < 20 ) {
         int xpos = xOff*( 1 +AGENDA_ICON_SIZE )+x;
         int ypos = yOff*( 1 +AGENDA_ICON_SIZE)+y;
         p->drawLine( xpos, ypos, xpos+AGENDA_ICON_SIZE-1, ypos+AGENDA_ICON_SIZE-1  );
@@ -201,14 +227,14 @@ bool KOAgendaItem::updateIcons(QPainter * p, bool horLayout)
         else
             ++yOff;
     }
-    if (mIncidence->isAlarmEnabled()) {
+    if (mIncidence->isAlarmEnabled() && mIncidence->alarmEnabled()) {
         p->fillRect ( xOff*( 1 +AGENDA_ICON_SIZE )+x, yOff*( 1 +AGENDA_ICON_SIZE)+y, AGENDA_ICON_SIZE, AGENDA_ICON_SIZE, red );
         if ( horLayout )
             ++xOff;
         else
             ++yOff;
     }
-    if (mIncidence->recurrence()->doesRecur()) {
+    if (mIncidence->doesRecur()) {
         p->fillRect ( xOff*( 1 +AGENDA_ICON_SIZE )+x, yOff*( 1 +AGENDA_ICON_SIZE)+y, AGENDA_ICON_SIZE, AGENDA_ICON_SIZE, blue );
         if ( horLayout )
             ++xOff;
@@ -318,7 +344,7 @@ void KOAgendaItem::paintMe( bool selected, QPainter* paint )
     QPainter pa;
     
     if ( mSelected ) {
-        pa.begin( paintPixSel() );
+        pa.begin( this );
     } else {
         if ( mAllDay )
             pa.begin( paintPixAllday() );
@@ -331,7 +357,10 @@ void KOAgendaItem::paintMe( bool selected, QPainter* paint )
     if ( mAllDay )
         yy = y();
     else
-        yy = mCellYTop * ( height() / cellHeight() );
+        yy = mCellYTop * ( height() / cellHeight() ); 
+    if ( mSelected ) {
+        pa.translate( -x, -yy );
+    } 
     xPaintCoord= x;
     yPaintCoord = yy;
     wPaintCoord = width();
@@ -359,7 +388,7 @@ void KOAgendaItem::paintMe( bool selected, QPainter* paint )
     paint->fillRect ( x, yy,  w, h, mBackgroundColor );
     static const  QPixmap completedPxmp = SmallIcon("greenhook16");
     static const QPixmap overduePxmp = SmallIcon("redcross16");
-    if ( mIncidence->type() == "Todo" ) {
+    if ( mIncidence->typeID() == todoID ) {
         Todo* tempTodo = static_cast<Todo*>(mIncidence);
         int xx = pos().x()+(width()-completedPxmp.width()-3 );
         int yyy =  yy+3;
@@ -374,7 +403,8 @@ void KOAgendaItem::paintMe( bool selected, QPainter* paint )
     if ( ! small || w > 3 * h || h > 3* w )
        addIcon =  updateIcons(  paint, horLayout );
 
-    qDrawShadePanel (paint, x,  yy,  w,  h, mColorGroup, selected , 2, 0);
+    //qDrawShadePanel (paint, x,  yy,  w,  h, mColorGroup, selected , 2, 0);
+    qDrawWinPanel (paint, x,  yy,  w,  h, mColorGroup, selected ,0);
     //qDebug("draw rect %d %d %d %d ",x,  yy,  w,  h );
     if ( ! small ) {
         x += 3; yy += 3;w -= 6;  h-= 5;
@@ -404,12 +434,13 @@ void KOAgendaItem::paintMe( bool selected, QPainter* paint )
             h -=(AGENDA_ICON_SIZE+3);
         }
     } 
-    int colsum = mBackgroundColor.red() + mBackgroundColor.green() + mBackgroundColor.blue();
-    if ( colsum < 250 )
+    if ( mWhiteText )
         paint->setPen ( white); 
     if ( x < 0 ) {
         w = w+x-3;
         x = 3;
+        if ( !horLayout && addIcon )
+            x += AGENDA_ICON_SIZE+3;
         if ( w > parentWidget()->width() ){
             w = parentWidget()->width() - 6;
 #ifndef DESKTOP_VERSION
@@ -439,12 +470,7 @@ void KOAgendaItem::paintMe( bool selected, QPainter* paint )
     pa.end();
  
 }
-void KOAgendaItem::resizePixmap( int w , int h )
-{
-    paintPix()->resize( w, h ); 
-    paintPixSel()->resize( w, h ); 
 
-}
 QPixmap * KOAgendaItem::paintPix()
 {
     static QPixmap* mPaintPix = 0;
@@ -460,24 +486,21 @@ QPixmap * KOAgendaItem::paintPixAllday()
     static QPixmap* mPaintPixA = 0;
     if ( ! mPaintPixA ) {
         int w = QApplication::desktop()->width();
-        int h = QApplication::desktop()->height()/3;
+        int h = QApplication::desktop()->height()/5;
         mPaintPixA = new QPixmap(w,h);
     }
     return mPaintPixA ; 
 }
-QPixmap * KOAgendaItem::paintPixSel()
-{
-    static QPixmap* mPaintPixSel = 0;
-    if ( ! mPaintPixSel ) {
-        int w = QApplication::desktop()->width();
-        int h = QApplication::desktop()->height();
-        mPaintPixSel = new QPixmap(w,h);
-    }
-    return mPaintPixSel ; 
+
+void KOAgendaItem::repaintItem()
+{ 
+    globalFlagBlockAgendaItemPaint = 0;
+    globalFlagBlockAgenda = 0;
+    repaint( false );
 }
 void KOAgendaItem::paintEvent ( QPaintEvent *e )
 {  
-
+  
     if ( globalFlagBlockAgendaItemPaint )
         return; 
     if ( globalFlagBlockAgenda > 0 &&  globalFlagBlockAgenda < 5 )
@@ -499,6 +522,8 @@ void KOAgendaItem::paintEvent ( QPaintEvent *e )
         paintMe( mSelected );
         //qDebug("calling paintMe ");
         globalFlagBlockAgendaItemUpdate = 1;
+        if ( mSelected )
+            return;
     }
     int rx, ry, rw, rh;
     rx =  e->rect().x();
@@ -509,7 +534,8 @@ void KOAgendaItem::paintEvent ( QPaintEvent *e )
 
     QPixmap* paintFrom ;
     if ( mSelected ) {
-        paintFrom =  paintPixSel();
+        paintMe( mSelected );
+        return;
     } else {
         if ( mAllDay )
             paintFrom =  paintPixAllday();
@@ -540,7 +566,7 @@ void KOAgendaItem::paintEvent ( QPaintEvent *e )
 void KOAgendaItem::computeText()
 {
     mDisplayedText =  mIncidence->summary();
-    if ( (mIncidence->type() == "Todo") ) {
+    if ( (mIncidence->typeID() == todoID ) ) {
         if ( static_cast<Todo*>(mIncidence)->hasDueDate() ) {
             if ( static_cast<Todo*>(mIncidence)->dtDue().date() < QDate::currentDate() )
                 mDisplayedText += i18n(" (") +KGlobal::locale()->formatDate((static_cast<Todo*>(mIncidence))->dtDue().date(), true)+")";
@@ -572,7 +598,7 @@ void KOAgendaItem::computeText()
 #ifdef DESKTOP_VERSION
     QString tipText = mIncidence->summary();
     if ( !mIncidence->doesFloat() ) {
-        if ( mIncidence->type() == "Event" ) {
+        if ( mIncidence->typeID() == eventID ) {
             if ( (static_cast<Event*>(mIncidence))->isMultiDay() ) {
                 tipText += "\n"+i18n("From: ")+mIncidence->dtStartStr();
                 tipText += "\n"+i18n("To: ")+(static_cast<Event*>(mIncidence))->dtEndStr();
@@ -582,13 +608,13 @@ void KOAgendaItem::computeText()
                 tipText += " - "+(static_cast<Event*>(mIncidence))->dtEndTimeStr();
             }
         }
-        else if ( mIncidence->type() == "Todo" ) {
+        else if ( mIncidence->typeID() == todoID ) {
             if (mIncidence->hasStartDate())
                 tipText += "\n"+i18n("Start: ")+ (static_cast<Todo*>(mIncidence))->dtStartStr();
             if (((Todo*)mIncidence)->hasDueDate())
                 tipText += "\n"+i18n("Due: ")+ (static_cast<Todo*>(mIncidence))->dtDueStr();
         }
-    } else if ( mIncidence->type() == "Todo" ) {
+    } else if ( mIncidence->typeID() == todoID ) {
             if (mIncidence->hasStartDate())
                 tipText += "\n"+i18n("Start: ")+ (static_cast<Todo*>(mIncidence))->dtStartDateStr();
             if (((Todo*)mIncidence)->hasDueDate())
