@@ -76,7 +76,7 @@ extern int globalFlagBlockAgendaItemUpdate;
 extern int globalFlagBlockLabel;
 using namespace KOrg;
 
-
+#define IDLETIMEOUT 45
 
 TimeLabels::TimeLabels(int rows,QWidget *parent,const char *name,WFlags f) :
     QScrollView(parent,name,f)
@@ -474,6 +474,11 @@ KOAgendaView::KOAgendaView(Calendar *cal,QWidget *parent,const char *name) :
   
     connect(mAllDayAgenda,SIGNAL(showIncidencePopupSignal(Incidence *)),
             mAllAgendaPopup,SLOT(showIncidencePopup(Incidence *)));
+
+    connect(mAllAgendaPopup,SIGNAL(categoryChanged(Incidence *)),
+            this,SLOT(categoryChanged(Incidence *)));
+
+
     mAgenda->setPopup( mAllAgendaPopup );
     mAllDayAgenda->setPopup( mAllAgendaPopup );
     // make connections between dependent widgets
@@ -568,9 +573,44 @@ KOAgendaView::KOAgendaView(Calendar *cal,QWidget *parent,const char *name) :
 
     connect( mAllDayAgenda, SIGNAL( signalClearSelection() ),mAgenda, SLOT( slotClearSelection()) ); 
     connect( mAgenda, SIGNAL( signalClearSelection() ),mAllDayAgenda, SLOT( slotClearSelection()) );   
- 
+#ifndef DESKTOP_VERSION
+    connect( mAllDayAgenda, SIGNAL( updateViewSignal() ),this, SLOT( fillAgenda()) ); 
+    connect( mAgenda, SIGNAL( updateViewSignal() ), this, SLOT( fillAgenda()) );   
+    connect( mAllDayAgenda, SIGNAL( sendPing() ),this, SLOT( startIdleTimeout()) ); 
+    connect( mAgenda, SIGNAL( sendPing() ), this, SLOT( startIdleTimeout()) );   
+    mIdleTimer = new QTimer ( this );;
+    connect(mIdleTimer,SIGNAL(timeout()),SLOT(slotIdleTimeout()));
+#endif
+}
+void KOAgendaView::startIdleTimeout()
+{
+#ifndef DESKTOP_VERSION
+    mIdleStart = QDateTime::currentDateTime();
+    mIdleTimer->start( IDLETIMEOUT * 1000 );
+#endif
+}
+void KOAgendaView::slotIdleTimeout()
+{
+#ifndef DESKTOP_VERSION
+    //qDebug("SECS TO %d ",mIdleStart.secsTo( QDateTime::currentDateTime()  ) );
+    int secsfromstart = mIdleStart.secsTo( QDateTime::currentDateTime()  );
+    mIdleTimer->stop();
+    bool isActice = topLevelWidget()->isActiveWindow();
+    //qDebug("KO: Active Window %d %d",  isActice, isVisible());
+    // we do nothing if we wake up from a suspend
+    if ( secsfromstart > IDLETIMEOUT + 30 && isActice ) {
+        qDebug("KO: Wakeup from suspend ");
+        startIdleTimeout();
+        return;
+    }
+    qDebug("KO: Downsizing Pixmaps ");
+    mAgenda->shrinkPixmap();
+    mAllDayAgenda->shrinkPixmap();
+    KOAgendaItem::paintPix()->resize( 20,20);
+    KOAgendaItem::paintPixAllday()->resize( 20,20);
+#endif
+    
 }
-
 void KOAgendaView::toggleAllDay()
 {
     if ( mSplitterAgenda->firstHandle() ) 
@@ -581,20 +621,24 @@ void KOAgendaView::addToCalSlot(Incidence * inc, Incidence * incOld )
     calendar()->addIncidence( inc ); 
     
     if ( incOld ) {
-        if ( incOld->type() == "Todo" )
+        if ( incOld->typeID() == todoID )
             emit  todoMoved((Todo*)incOld,  KOGlobals::EVENTEDITED );
         else
             emit incidenceChanged(incOld, KOGlobals::EVENTEDITED);
     }
     
 }
-
+void KOAgendaView::categoryChanged(Incidence * inc)
+{
+    mAgenda->categoryChanged( inc );
+    mAllDayAgenda->categoryChanged( inc );
+}
 KOAgendaView::~KOAgendaView()
 {
     delete mAllAgendaPopup;
     //delete mAllDayAgendaPopup;
     delete KOAgendaItem::paintPix();
-    delete KOAgendaItem::paintPixSel();
+    delete KOAgendaItem::paintPixAllday();
 }
 void KOAgendaView::resizeEvent( QResizeEvent* e )
 {
@@ -662,7 +706,7 @@ void KOAgendaView::createDayLabels()
     // ### Before deleting and recreating we could check if mSelectedDates changed...
     // It would remove some flickering and gain speed (since this is called by
     // each updateView() call)
-
+    
     int maxWid = mUpcomingWidth - mTimeLabels->width()- mAgenda->verticalScrollBar()->width() - mAgenda->frameWidth()*2;
     mDayLabelsFrame->setMaximumWidth( mUpcomingWidth );
     if ( maxWid < 20 )
@@ -670,6 +714,7 @@ void KOAgendaView::createDayLabels()
 
     QFont dlf = KOPrefs::instance()->mTimeLabelsFont;
     QFontMetrics fm ( dlf );
+    dlf.setBold( true );
     int selCount = mSelectedDates.count();
     int widModulo = maxWid - (mAgenda->gridSpacingX() * selCount)+1;
     QString dayTest = "Mon 20";
@@ -679,7 +724,7 @@ void KOAgendaView::createDayLabels()
     if ( QApplication::desktop()->width() <= 320 )
         maxWid  -= ( selCount * 3 );  //working for QPushButton
     else
-        maxWid  -= ( selCount * 3 );  //working for QPushButton
+        maxWid  -= ( selCount * 4 );  //working for QPushButton
     if ( maxWid < 0 )
         maxWid = 20;
     int needWid = wid * selCount;
@@ -698,7 +743,7 @@ void KOAgendaView::createDayLabels()
         while ( fontPoint > 4 ) {
             --fontPoint;
             dlf.setPointSize( fontPoint );
-            QFontMetrics f( dlf );
+            QFontMetrics f( dlf ); 
             wid = f.width( "30" );
             needWid = wid * selCount;
             if ( needWid < maxWid )
@@ -707,7 +752,8 @@ void KOAgendaView::createDayLabels()
         maxLen = 2;
     }
     //qDebug("Max len %d ", dayTest.length() );
-
+    if ( !KOPrefs::instance()->mTimeLabelsFont.bold() )
+        dlf.setBold( false );
     QFontMetrics tempF( dlf );
     newHight = tempF.height();
     mDayLabels->setFont( dlf );
@@ -790,7 +836,10 @@ void KOAgendaView::createDayLabels()
             else if ( mSelectedDates.first() == QDateTime::currentDateTime().date().addDays(2) )
                 addString = i18n("Day after tomorrow");
             if ( !addString.isEmpty() ) {
-                str = addString+", " + str;
+                if (  QApplication::desktop()->width() < 640 )
+                    str = addString+", " + str;
+                else
+                    str = addString+", "+ KGlobal::locale()->formatDate( date, false);
             } else {
                 str = KGlobal::locale()->formatDate( date, KOPrefs::instance()->mShortDateInViewer);
             }
@@ -967,7 +1016,7 @@ void KOAgendaView::updateEventDates(KOAgendaItem *item, int type)
     //       qDebug("RESIZEBOTTOM ");
     //   if ( type ==  KOAgenda::MOVE )
     //       qDebug("MOVE ");
-    if ( item->incidence()->type() == "Event" ) {
+    if ( item->incidence()->typeID() == eventID ) {
         startDt =item->incidence()->dtStart();
         endDt = item->incidence()->dtEnd();
         lenInSecs = startDt.secsTo( endDt );
@@ -975,7 +1024,7 @@ void KOAgendaView::updateEventDates(KOAgendaItem *item, int type)
 
     // emit incidenceItemChanged( item->incidence(), KOGlobals::EVENTEDITED );
 
-    if ( item->incidence()->type()=="Todo" && item->mLastMoveXPos > 0 ) {
+    if ( item->incidence()->typeID()== todoID && item->mLastMoveXPos > 0 ) {
         startDate = mSelectedDates[item->mLastMoveXPos];
     } else {
         if (item->cellX() < 0) {
@@ -991,7 +1040,7 @@ void KOAgendaView::updateEventDates(KOAgendaItem *item, int type)
     } else {
         if ( type == KOAgenda::RESIZETOP ||  type ==  KOAgenda::MOVE )
             startDt.setTime(mAgenda->gyToTime(item->cellYTop()));
-        if ( item->incidence()->type() == "Event" ) {
+        if ( item->incidence()->typeID() == eventID ) {
             if ( type ==  KOAgenda::MOVE ) {
                 endDt = startDt.addSecs(lenInSecs);
 
@@ -1021,10 +1070,10 @@ void KOAgendaView::updateEventDates(KOAgendaItem *item, int type)
             }
         }
     }
-    if ( item->incidence()->type() == "Event" ) {
+    if ( item->incidence()->typeID() == eventID ) {
         item->incidence()->setDtStart(startDt);
         (static_cast<Event*>(item->incidence()))->setDtEnd(endDt);
-    } else if ( item->incidence()->type() == "Todo" ) {
+    } else if ( item->incidence()->typeID() == todoID ) {
         Todo* to = static_cast<Todo*>(item->incidence());
 
         to->setDtDue(endDt);
@@ -1038,7 +1087,7 @@ void KOAgendaView::updateEventDates(KOAgendaItem *item, int type)
     item->incidence()->setRevision(item->incidence()->revision()+1);
     item->setItemDate(startDt.date());
     //item->updateItem();
-    if ( item->incidence()->type() == "Todo" ) {
+    if ( item->incidence()->typeID() == todoID ) {
          emit  todoMoved((Todo*)item->incidence(),  KOGlobals::EVENTEDITED );
 
     }
@@ -1110,12 +1159,6 @@ void KOAgendaView::fillAgenda()
     mEventIndicatorBottom->changeColumns(mSelectedDates.count());
     setHolidayMasks();
 
-    //mAgenda->hideUnused();
-    //mAllDayAgenda->hideUnused();
- 
-    //   mAgenda->blockNextRepaint( false );
-    //   mAgenda->viewport()->repaint();
-    //   mAgenda->blockNextRepaint( true );
     mMinY.resize(mSelectedDates.count());
     mMaxY.resize(mSelectedDates.count());
 
@@ -1131,18 +1174,20 @@ void KOAgendaView::fillAgenda()
 
     DateList::ConstIterator dit;
     int curCol = 0;
+    int maxCol = mSelectedDates.count()-1;
     for( dit = mSelectedDates.begin(); dit != mSelectedDates.end(); ++dit ) {
         QDate currentDate = *dit;
         //    kdDebug() << "KOAgendaView::fillAgenda(): " << currentDate.toString()
         //              << endl;
 
-        dayEvents = calendar()->events(currentDate,true);
+        dayEvents = calendar()->events(currentDate,false);
 
         // Default values, which can never be reached
         mMinY[curCol] = mAgenda->timeToY(QTime(23,59)) + 1;
         mMaxY[curCol] = mAgenda->timeToY(QTime(0,0)) - 1;
 
         unsigned int numEvent;
+        //qDebug("+++++NUMEVENT %d", dayEvents.count());
         for(numEvent=0;numEvent<dayEvents.count();++numEvent) {
             Event *event = dayEvents.at(numEvent);
             if ( !KOPrefs::instance()->mShowSyncEvents && event->uid().left(2) == QString("la") )
@@ -1156,7 +1201,7 @@ void KOAgendaView::fillAgenda()
             //      kdDebug() << "  beginX: " << beginX << "  endX: " << endX << endl;
 
             if (event->doesFloat()) {
-                if (event->recurrence()->doesRecur()) {
+                if (event->doesRecur()) {
                     if (event->isMultiDay() ) {
                         endX = endX - beginX;// endX is now number of days
                         if ( event->recursOn( currentDate ) ) {
@@ -1164,12 +1209,25 @@ void KOAgendaView::fillAgenda()
                             beginX = curCol;
                             mAllDayAgenda->insertAllDayItem(event,currentDate,beginX,endX);
                         } else {
-                            //qDebug("days %d %s",endX , currentDate.toString().latin1());
-                            QDate dateit = currentDate.addDays( -endX );
-                            if ( event->recursOn( dateit ) ) {
-                                //qDebug("found %d %d %d %s", endX,curCol, curCol-endX ,dateit.toString().latin1()  );
-                                if ( curCol-endX < 0 ) {
+                            //qDebug("days endX %d curCol %d max Col %d %s",endX ,curCol, maxCol, currentDate.toString().latin1());
+                            if ( curCol == maxCol && maxCol+1 < endX ) {
+                                int i;
+                                for ( i = 1; i< endX; ++i ) {
+                                    if ( event->recursOn( currentDate.addDays( -i ) ) )
+                                        break;
+                                }
+                                if ( i > maxCol ) {
                                     mAllDayAgenda->insertAllDayItem(event,currentDate,0,curCol);
+                                    //qDebug("BINGO ");
+                                }
+
+                            } else {
+                                QDate dateit = currentDate.addDays( -endX );
+                                if ( event->recursOn( dateit ) ) {
+                                    //qDebug("found %d %d %d %s", endX,curCol, curCol-endX ,dateit.toString().latin1()  );
+                                    if ( curCol-endX < 0 ) {
+                                        mAllDayAgenda->insertAllDayItem(event,currentDate,0,curCol);
+                                    }
                                 }
                             }
                         }
@@ -1278,9 +1336,7 @@ void KOAgendaView::fillAgenda()
     mAgenda->hideUnused();
     mAllDayAgenda->hideUnused();
     mAgenda->checkScrollBoundaries();
-
     deleteSelectedDateTime();
-  
     createDayLabels();
     emit incidenceSelected( 0 );
 
@@ -1289,35 +1345,17 @@ void KOAgendaView::fillAgenda()
             setStartHour( KOPrefs::instance()->mDayBegins  );
         else if ( KOPrefs::instance()->mCenterOnCurrentTime )
             setStartHour( QTime::currentTime ().hour() );
-        //  qApp->processEvents();   
     }
     qApp->processEvents(); 
-    //qDebug("qApp->processEvents(); END ");
     globalFlagBlockAgenda = 0; 
-
-    // mAgenda->hideUnused();
-    //mAllDayAgenda->hideUnused();
     mAllDayAgenda->drawContentsToPainter();
     mAgenda->drawContentsToPainter();
     repaintAgenda();
+    startIdleTimeout();
     onlyOne = false;
-    // mAgenda->finishUpdate();
-    //mAllDayAgenda->finishUpdate();
-
-    // repaintAgenda();
-    //qApp->processEvents(); 
-    // globalFlagBlockAgenda = 0;
 }
 void KOAgendaView::repaintAgenda()
 {
-   //  mAllDayAgenda->drawContentsToPainter();
-//     mAllDayAgenda->viewport()->repaint( false ); 
-//     mAgenda->drawContentsToPainter();
-//     mAgenda->viewport()->repaint( false ); 
-//     qApp->processEvents(); 
-
-    //qDebug("KOAgendaView::repaintAgenda() ");
-    //qApp->processEvents(); 
     mAgenda->viewport()->repaint( false );
     mAllDayAgenda->viewport()->repaint( false );
     mAgenda->finishUpdate();
@@ -1327,13 +1365,11 @@ void KOAgendaView::repaintAgenda()
 
 void KOAgendaView::clearView()
 {
-    //  kdDebug() << "ClearView" << endl;
     mAllDayAgenda->clear();
     mAgenda->clear();
 }
 void KOAgendaView::clearList()
 {
-    //  kdDebug() << "ClearView" << endl;
     clearView();
     mAllDayAgenda->hideUnused();
     mAgenda->hideUnused();
@@ -1359,7 +1395,7 @@ void KOAgendaView::printPreview(CalPrinter *calPrinter, const QDate &fd,
 void KOAgendaView::slotShowDateView( int mode , int d )
 {
     if ( d >= mSelectedDates.count() ) {
-        qDebug("KOAgendaView::slotShowDateView datecounterror %d d ", d, mSelectedDates.count() );
+        qDebug("KOAgendaView::slotShowDateView datecounterror %d %d ", d, mSelectedDates.count() );
 
     } else {
         QDate day = mSelectedDates[d];
