@@ -220,14 +220,23 @@ QString KODayMatrix::getWhatsThisText( QPoint p )
         }               
     }
     if (KOPrefs::instance()->mCurrentDisplayedView == VIEW_J_VIEW ) {
-        Journal *j = mCalendar->journal( mDate );
-        if ( j ) {
-            QString mToolTipText = j->description().left(100);
-            if ( j->description().length() > 100 )
-                mToolTipText += " ...";
-            mToolTipText = deTag( mToolTipText);
+        QPtrList<Journal> j_list = mCalendar->journals4Date( mDate );
+        Journal *j = j_list.first();
+        while ( j ) {
+            QString mToolTipText;
+            if ( !j->summary().isEmpty() ) {
+                mToolTipText = j->summary().left(30);
+                if ( j->summary().length() > 30 )
+                    mToolTipText += " ...";
+            } else {
+                mToolTipText = j->description().left(25);
+                if ( j->description().length() > 25 )
+                    mToolTipText += " ...";
+                mToolTipText = deTag( mToolTipText);
+            }
             mToolTipText = "<b>" + i18n("Journal: ") + "</b>"+ mToolTipText;
-            mToolTip.append(  mToolTipText );    
+            mToolTip.append(  mToolTipText );
+            j = j_list.next();
         }
     }
     return  "<b>"+KGlobal::locale()->formatDate(days[tmp]) + "</b><br>" + mToolTip.join("<br>");
@@ -444,7 +453,7 @@ void KODayMatrix::updateViewTimed()
     QDate mStartDate = days[0];
     QDate endDate =  mStartDate.addDays( timeSpan );
     for( event = events.first(); event; event = events.next() ) { // for event
-        ushort recurType = event->recurrence()->doesRecur();
+        ushort recurType = event->doesRecur();
         if ((recurType == Recurrence::rDaily && !KOPrefs::instance()->mDailyRecur) ||
             (recurType == Recurrence::rWeekly && !KOPrefs::instance()->mWeeklyRecur)) {
             continue;
@@ -549,7 +558,9 @@ void KODayMatrix::updateViewTimed()
                 pDays.setBit(i);
                 if ( !holiStr.isEmpty() )
                     holiStr += "\n";
-                holiStr += i18n("Journal");
+                holiStr += i18n("Journal: ")+todo->summary().left(25);
+                if ( todo->summary().length() > 25 )
+                    holiStr +="...";
                 bDays.setBit(i);
                 mHolidays[i] =holiStr ;
                 eDays.setBit(i);
@@ -935,8 +946,8 @@ void KODayMatrix::paintEvent(QPaintEvent * pevent)
 
         // draw background and topleft frame
         p.fillRect(0,0,width(),height(), mDefaultBackColor);
-        p.setPen(mDefaultTextColor);
-        p.drawRect(0, 0, width(), height());
+        //p.setPen(mDefaultTextColor);
+        //p.drawRect(0, 0, width(), height());
         int mSelStartT = mSelStart;
         int mSelEndT = mSelEnd;
         if ( mSelEndT >=  NUMDAYS )
@@ -1172,6 +1183,8 @@ void KODayMatrix::paintEvent(QPaintEvent * pevent)
                 p.setFont(myFont);
             }
         }
+        p.setPen(mDefaultTextColor);
+        p.drawRect(0, 0, width(), height());
     } else {
         //qDebug("NO  redraw ");
     }
@@ -1184,11 +1197,12 @@ void KODayMatrix::paintEvent(QPaintEvent * pevent)
 //  R E SI Z E   E V E N T   H A N D L I N G
 // ----------------------------------------------------------------------------
 
-void KODayMatrix::resizeEvent(QResizeEvent *)
+void KODayMatrix::resizeEvent(QResizeEvent * e)
 {
   QRect sz = frameRect();
   daysize.setHeight(sz.height()*7 / NUMDAYS);
   daysize.setWidth(sz.width() / 7);
+  QFrame::resizeEvent( e );
 }
 
 QSize KODayMatrix::sizeHint() const
