@@ -31,9 +31,11 @@
 #include <qdatetime.h>
 #include <qtimer.h>
 #include <qfile.h>
+#include <qregexp.h>
 
 
 #include <kglobal.h>
+#include <kdialog.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -75,11 +77,13 @@ void KOEditorGeneral::initHeader(QWidget *parent,QBoxLayout *topLayout)
     mOwnerLabel = new QLabel(i18n("Owner:"),parent);
     headerLayout->addMultiCellWidget(mOwnerLabel,0,0,0,1);
 #endif
-
+    // 1 on pda
+    // 11 on desktop
+    headerLayout->setSpacing( (KDialog::spacingHint()-3)*2+1 );
     QLabel *summaryLabel = new QLabel(i18n("Summary:"),parent);
-    headerLayout->addWidget(summaryLabel,1,0);
+    headerLayout->addWidget(summaryLabel,0,0);
 
-    mSummaryEdit = new KOLocationBox(TRUE,parent, 10);
+    mSummaryEdit = new KOLocationBox(TRUE,parent, 50);
     mSummaryEdit->setSizePolicy( QSizePolicy(  QSizePolicy::Preferred  ,QSizePolicy::MinimumExpanding  ,FALSE) );
     //mSummaryEdit->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5 ,(QSizePolicy::SizeType)3 ,FALSE) );
     //qDebug("h %d %d ", summaryLabel->sizeHint().height(),mSummaryEdit->sizeHint().height() );
@@ -89,31 +93,42 @@ void KOEditorGeneral::initHeader(QWidget *parent,QBoxLayout *topLayout)
     //qDebug("%d %d %d %d %d %d ", QSizePolicy::Fixed ,  QSizePolicy::Minimum ,   QSizePolicy:: Maximum ,   QSizePolicy:: Preferred  ,    QSizePolicy::  MinimumExpanding , QSizePolicy::Expanding   );
     // SizeType { Fixed = 0, Minimum = MayGrow, Maximum = MayShrink, Preferred = MayGrow|MayShrink, MinimumExpanding = Minimum|ExpMask, Expanding = MinimumExpanding|MayShrink }
     //   mSummaryEdit = new QLineEdit(parent);
-    headerLayout->addWidget(mSummaryEdit,1,1);
+    if ( QApplication::desktop()->height() < 320 ) 
+        headerLayout->addWidget(mSummaryEdit,0,1);
+    else
+        headerLayout->addMultiCellWidget(mSummaryEdit,0,0,1,2);
     connect ( mSummaryEdit->lineEdit(), SIGNAL ( returnPressed() ), this, SIGNAL (allAccepted () ) );
   
     QLabel *locationLabel = new QLabel(i18n("Location:"),parent);
     if ( QApplication::desktop()->height() < 320 ) 
-        headerLayout->addWidget(locationLabel,1,2);
+        headerLayout->addWidget(locationLabel,0,2);
     else
-        headerLayout->addWidget(locationLabel,2,0);
+        headerLayout->addWidget(locationLabel,1,0);
 
-    mLocationEdit = new KOLocationBox(TRUE,parent,10); 
-    mLocationEdit->setSizePolicy( QSizePolicy( QSizePolicy::Preferred  ,QSizePolicy::MinimumExpanding  ,FALSE) );
-    if ( QApplication::desktop()->width() > 320 ) 
+    mLocationEdit = new KOLocationBox(TRUE,parent,30); 
+    mLocationEdit->setSizePolicy( QSizePolicy( QSizePolicy::Preferred  ,QSizePolicy::MinimumExpanding ,FALSE) );
+    if ( QApplication::desktop()->width() > 320 && QApplication::desktop()->height() > 240 ) 
         mLocationEdit->setMaximumHeight( hei + 6);
 
     //   mLocationEdit = new QLineEdit(parent);
     connect ( mLocationEdit->lineEdit(), SIGNAL ( returnPressed() ), this, SIGNAL (allAccepted () ) );
+
+    mCalendarBox = new QComboBox ( parent );
+    mCalendarBox->setSizePolicy( QSizePolicy( QSizePolicy::Preferred  ,QSizePolicy::MinimumExpanding ,FALSE) );
     if ( QApplication::desktop()->height() < 320 ) {
-        headerLayout->addWidget(mLocationEdit,1,3);
+        headerLayout->addWidget(mLocationEdit,0,3);
+        headerLayout->addWidget(mCalendarBox,0,4);
         headerLayout->setColStretch( 1, 10);
         headerLayout->setColStretch( 3, 10);
+        mCalendarBox->setMaximumWidth( 64 );
     }
     else {
-        headerLayout->addWidget(mLocationEdit,2,1);
-        headerLayout->setColStretch( 1, 10);
+        headerLayout->addWidget(mLocationEdit,1,1);
+        headerLayout->addWidget(mCalendarBox,1,2);
+        headerLayout->setColStretch( 1, 3);
+        headerLayout->setColStretch( 2, 1);
     }
+    
 }
 void KOEditorGeneral::setFocusOn( int i )
 {
@@ -142,17 +157,55 @@ void KOEditorGeneral::editCategories()
     csd->exec();
     delete csd;
 }
+
+void KOEditorGeneral::showCatPopup()
+{
+    mCatPopup->clear(); 
+    QStringList checkedCategories = QStringList::split (",", mCategoriesLabel->text());
+    int index = 0;
+    for (QStringList::Iterator it = KOPrefs::instance()->mCustomCategories.begin ();
+         it != KOPrefs::instance()->mCustomCategories.end ();
+         ++it) {
+        mCatPopup->insertItem (*it, index );
+        //mCategory[index] = *it;
+        if (checkedCategories.find (*it) != checkedCategories.end ()) mCatPopup->setItemChecked (index, true);
+        ++index;
+    }
+}
+void KOEditorGeneral::selectedCatPopup( int index )
+{
+    QStringList categories =  QStringList::split (",", mCategoriesLabel->text());
+    QString colcat = categories.first();
+    if (categories.find (KOPrefs::instance()->mCustomCategories[index]) != categories.end ())
+      categories.remove (KOPrefs::instance()->mCustomCategories[index]);
+    else
+        categories.insert (categories.end(), KOPrefs::instance()->mCustomCategories[index]);
+    categories.sort ();
+    if ( !colcat.isEmpty() ) {
+        if ( categories.find ( colcat ) != categories.end () ) {
+            categories.remove( colcat );
+            categories.prepend( colcat );
+        }
+    }
+    setCategories( categories.join(",") );
+}
+
 void KOEditorGeneral::initCategories(QWidget *parent, QBoxLayout *topLayout)
 {
     QBoxLayout *categoriesLayout = new QHBoxLayout( topLayout );
-
+    mCatPopup = new QPopupMenu ( parent );
+    mCatPopup->setCheckable (true);
+    connect(mCatPopup,SIGNAL(aboutToShow ()  ), this ,SLOT(showCatPopup()));
+    connect(mCatPopup,SIGNAL(  activated ( int ) ), this ,SLOT(selectedCatPopup( int )));
     mCategoriesButton = new QPushButton(parent);
     mCategoriesButton->setText(i18n("Categories..."));
     connect(mCategoriesButton,SIGNAL(clicked()),this, SLOT(editCategories() ));
+    //connect(mCategoriesButton,SIGNAL(clicked()),this, SLOT(editCategories() ));
     categoriesLayout->addWidget(mCategoriesButton);
-
-    mCategoriesLabel = new QLabel(parent);
-    mCategoriesLabel->setFrameStyle(QFrame::Panel|QFrame::Sunken);
+    mCategoriesLabel = new QPushButton(parent);//new QLabel(parent);
+    mCategoriesLabel->setSizePolicy( QSizePolicy(  QSizePolicy::Preferred  ,QSizePolicy::Fixed  ,FALSE) );
+    mCategoriesLabel->setPopup( mCatPopup );
+    //mCategoriesLabel->setFrameStyle(QFrame::Panel|QFrame::Sunken);
     categoriesLayout->addWidget(mCategoriesLabel,1);
 }
 
@@ -359,6 +412,8 @@ void KOEditorGeneral::alarmDisable(bool disable)
 
 void KOEditorGeneral::setCategories(const QString &str)
 {
+    QString tt = str;
+    QToolTip::add( mCategoriesLabel, i18n("<b>Click here to edit categories: </b>") +"<em>"+tt.replace( QRegExp(","),", ")+"</em>");
     mCategoriesLabel->setText(str);
 }
 
@@ -392,14 +447,48 @@ void KOEditorGeneral::setDefaults(bool allDay)
     mDescriptionEdit->setText("");
     mAlarmSound = KOPrefs::instance()->mDefaultAlarmFile;
     setCategories("");
+    fillCalCombo();
 }
 void KOEditorGeneral::setSecrecy( int num )
 {
     mSecrecyCombo->setCurrentItem(num);
 }
+void KOEditorGeneral::fillCalCombo( int setToID )
+{
+    mCalendarBox->clear();
+    KopiCalendarFile * kkf = KOPrefs::instance()->mCalendars.first();
+    int std = 0;
+    int count = 0;
+    while ( kkf ) {
+        if ( !kkf->mErrorOnLoad &&! kkf->isReadOnly ) {
+            if ( setToID ) {
+                if ( kkf->mCalNumber == setToID ) 
+                    std = count;
+            } else {
+                if ( kkf->isStandard ) {
+                    std = count;
+                }
+            }
+            ++count;
+            mCalendarBox->insertItem( kkf->mName );
+        }
+        kkf = KOPrefs::instance()->mCalendars.next();
+    }
+    mCalendarBox->setCurrentItem( std );
+    if ( KOPrefs::instance()->mCalendars.count() == 1 )
+        mCalendarBox->hide();
+    else
+        mCalendarBox->show();
+
+}
+int KOEditorGeneral::getCalendarID()
+{
+    return KOPrefs::instance()->getCalendarID( mCalendarBox->currentText() );
+}
+
 void KOEditorGeneral::readIncidence(Incidence *event)
 {
-
+    fillCalCombo( event->calID() );
     mAlarmMessage = event->summary(); 
     if ( ! event->location().isEmpty() )
         mAlarmMessage += " ("+event->location()+")";
@@ -525,4 +614,5 @@ void KOEditorGeneral::writeIncidence(Incidence *event)
             alarm->setType(Alarm::Invalid);
         }
     }
+    event->setCalID( getCalendarID() );
 }
