@@ -835,12 +835,32 @@ void KOEditorRecurrence::setDateTimes( QDateTime start, QDateTime end )
   mExceptions->setDefaults( end );
 
 }
+void KOEditorRecurrence::setDefaultsDates( QDateTime from, QDateTime to )
+{
+    setDateTimes( from, to );
+    QBitArray days( 7 );
+    days.fill( 0 );
+    days.setBit( from.date().dayOfWeek()- 1);
+    mWeekly->setDays( days );
+    bool byPos = mMonthly->byPos();
+    if ( byPos )
+        mMonthly->setByDay( from.date().day()-1 );
+    mMonthly->setByPos((from.date().day()/7), from.date().dayOfWeek()-1 );
+    if ( ! byPos)
+        mMonthly->setByDay( from.date().day()-1 );
 
-void KOEditorRecurrence::setDefaults( QDateTime from, QDateTime to, bool )
+    bool byDay = mYearly->byDay();
+    if ( ! byDay )
+        mYearly->setByDay( from.date().dayOfYear() );
+    mYearly->setByMonth( from.date().month(), from.date().day() );
+    if ( byDay )
+        mYearly->setByDay( from.date().dayOfYear() );
+}
+void KOEditorRecurrence::setDefaults( QDateTime from, QDateTime to )
 {
 
     // qDebug("KOEditorRecurrence::setDefaults %s %s ",from.toString().latin1(),to.toString().latin1() );
-  setDateTimes( from, to );
+    //setDateTimes( from, to );
 
   bool enabled = false;
   mEnabledCheck->setChecked( enabled );
@@ -853,30 +873,22 @@ void KOEditorRecurrence::setDefaults( QDateTime from, QDateTime to, bool )
   showCurrentRule( mRecurrenceChooser->type() );
 
   mDaily->setFrequency( 1 );
-
   mWeekly->setFrequency( 1 );
-  QBitArray days( 7 );
-  days.fill( 0 );
-  days.setBit( from.date().dayOfWeek()- 1);
-  mWeekly->setDays( days );
   mMonthly->setFrequency( 1 );
-  mMonthly->setByPos((from.date().day()/7), from.date().dayOfWeek()-1 );
-  mMonthly->setByDay( from.date().day()-1 );
   mYearly->setFrequency( 1 );
-  mYearly->setByDay( from.date().dayOfYear() );
-  mYearly->setByMonth( from.date().month(), from.date().day() );
+  setDefaultsDates( from, to );
 }
 
 void KOEditorRecurrence::readEvent(Incidence *event)
 {
 
     QDateTime dtEnd;
-    if ( event->type() == "Event" )
+    if ( event->typeID() == eventID )
         dtEnd = ((Event*)event)->dtEnd();
     else
         dtEnd = ((Todo*)event)->dtDue();
         
-    setDefaults( event->dtStart(), dtEnd, true );
+    setDefaults( event->dtStart(), dtEnd );
   QBitArray rDays( 7 );
   QPtrList<Recurrence::rMonthPos> rmp;
   QPtrList<int> rmd;
@@ -885,100 +897,102 @@ void KOEditorRecurrence::readEvent(Incidence *event)
   int month = 0;
   setDateTimes( event->dtStart(), dtEnd );
 
-  Recurrence *r = event->recurrence();
-  int f = r->frequency();
+ 
 
-  int recurs = r->doesRecur();
+  int recurs = event->doesRecur();
 
   mEnabledCheck->setChecked( recurs );
   setEnabled( recurs );
 
   int recurrenceType = RecurrenceChooser::Weekly;
+  if ( recurs ) {
+      Recurrence *r = event->recurrence();
+      int f = r->frequency();
+      switch ( recurs ) {
+      case Recurrence::rNone:
+          setDefaults( event->dtStart(), dtEnd );
+          break;
+      case Recurrence::rDaily:
+          recurrenceType = RecurrenceChooser::Daily;
+          mDaily->setFrequency( f );
+          break;
+      case Recurrence::rWeekly:
+          recurrenceType = RecurrenceChooser::Weekly;
+          mWeekly->setFrequency( f );
+          mWeekly->setDays( r->days() );
+          break;
+      case Recurrence::rMonthlyPos:
+          // we only handle one possibility in the list right now,
+          // so I have hardcoded calls with first().  If we make the GUI
+          // more extended, this can be changed.
+          recurrenceType = RecurrenceChooser::Monthly;
 
-  switch ( recurs ) {
-    case Recurrence::rNone:
-        setDefaults( event->dtStart(), dtEnd, true );
-      break;
-    case Recurrence::rDaily:
-      recurrenceType = RecurrenceChooser::Daily;
-      mDaily->setFrequency( f );
-      break;
-    case Recurrence::rWeekly:
-      recurrenceType = RecurrenceChooser::Weekly;
-      mWeekly->setFrequency( f );
-      mWeekly->setDays( r->days() );
-      break;
-    case Recurrence::rMonthlyPos:
-      // we only handle one possibility in the list right now,
-      // so I have hardcoded calls with first().  If we make the GUI
-      // more extended, this can be changed.
-      recurrenceType = RecurrenceChooser::Monthly;
+          rmp = r->monthPositions();
+          if ( rmp.first()->negative )
+              count = 5 - rmp.first()->rPos - 1;
+          else
+              count = rmp.first()->rPos - 1;
+          day = 0;
+          while ( !rmp.first()->rDays.testBit( day ) ) ++day;
+          mMonthly->setByPos( count, day );
 
-      rmp = r->monthPositions();
-      if ( rmp.first()->negative )
-        count = 5 - rmp.first()->rPos - 1;
-      else
-        count = rmp.first()->rPos - 1;
-      day = 0;
-      while ( !rmp.first()->rDays.testBit( day ) ) ++day;
-      mMonthly->setByPos( count, day );
+          mMonthly->setFrequency( f );
 
-      mMonthly->setFrequency( f );
+          break;
+      case Recurrence::rMonthlyDay:
+          recurrenceType = RecurrenceChooser::Monthly;
 
-      break;
-    case Recurrence::rMonthlyDay:
-      recurrenceType = RecurrenceChooser::Monthly;
+          rmd = r->monthDays();
+          day = *rmd.first() - 1;
+          mMonthly->setByDay( day );
 
-      rmd = r->monthDays();
-      day = *rmd.first() - 1;
-      mMonthly->setByDay( day );
+          mMonthly->setFrequency( f );
 
-      mMonthly->setFrequency( f );
-
-      break;
-    case Recurrence::rYearlyMonth:
-        {
-        recurrenceType = RecurrenceChooser::Yearly;
-        //qDebug("Recurrence::rYearlyMonth: ");
-            day = event->dtStart().date().day(); 
-            rmd = r->yearNums();
-            if ( rmd.count() > 0 )
-                month = *rmd.first();
-            else
-                month = event->dtStart().date().month() ;
-            mYearly->setByMonth( month, day );
+          break;
+      case Recurrence::rYearlyMonth:
+          {
+              recurrenceType = RecurrenceChooser::Yearly;
+              //qDebug("Recurrence::rYearlyMonth: ");
+              day = event->dtStart().date().day(); 
+              rmd = r->yearNums();
+              if ( rmd.count() > 0 )
+                  month = *rmd.first();
+              else
+                  month = event->dtStart().date().month() ;
+              mYearly->setByMonth( month, day );
 #if 0
-            //qDebug("2day = %d ",day );
-            QPtrList<Recurrence::rMonthPos> monthlist = r->yearMonthPositions();
-            int month;
-            if ( !monthlist.isEmpty() ) {
-                month =  monthlist.first()->rPos ;
-            } else {
-                month = event->dtStart().date().month() ;
-            }
-            mYearly->setByMonth( day, month );
+              //qDebug("2day = %d ",day );
+              QPtrList<Recurrence::rMonthPos> monthlist = r->yearMonthPositions();
+              int month;
+              if ( !monthlist.isEmpty() ) {
+                  month =  monthlist.first()->rPos ;
+              } else {
+                  month = event->dtStart().date().month() ;
+              }
+              mYearly->setByMonth( day, month );
 #endif
-            mYearly->setFrequency( f );
-        }
+              mYearly->setFrequency( f );
+          }
 
-      break;
-    case Recurrence::rYearlyDay:
-        //qDebug("Recurrence::rYearlyDay: ");
-        recurrenceType = RecurrenceChooser::Yearly;
-        mYearly->setByDay( event->dtStart().date().dayOfYear() );
-        mYearly->setFrequency( f );
-        break;
-    default:
-        setDefaults( event->dtStart(), dtEnd, true );
-      break;
+          break;
+      case Recurrence::rYearlyDay:
+          //qDebug("Recurrence::rYearlyDay: ");
+          recurrenceType = RecurrenceChooser::Yearly;
+          mYearly->setByDay( event->dtStart().date().dayOfYear() );
+          mYearly->setFrequency( f );
+          break;
+      default:
+          setDefaults( event->dtStart(), dtEnd );
+          break;
+      }
   }
-
   mRecurrenceChooser->setType( recurrenceType );
   showCurrentRule( recurrenceType );
 
   mRecurrenceRange->setDateTimes( event->dtStart() );
 
-  if ( r->doesRecur() ) {
+  if ( event->doesRecur() ) {
+      Recurrence *r = event->recurrence();
     mRecurrenceRange->setDuration( r->duration() );
     if ( r->duration() == 0 ) 
         {
@@ -995,12 +1009,16 @@ void KOEditorRecurrence::readEvent(Incidence *event)
 
 void KOEditorRecurrence::writeEvent( Incidence *event )
 {
-  Recurrence *r = event->recurrence();
+  
 
-  // clear out any old settings;
-  r->unsetRecurs();
+  if ( !mEnabledCheck->isChecked() ) {
+      if ( event->doesRecur() )
+          event->recurrence()->unsetRecurs();
+  } else {
+      Recurrence *r = event->recurrence();
 
-  if ( mEnabledCheck->isChecked() ) {
+      // clear out any old settings;
+      r->unsetRecurs();
     int duration = mRecurrenceRange->duration();
     QDate endDate;
     if ( duration == 0 ) endDate = mRecurrenceRange->endDate();
