@@ -34,6 +34,8 @@
 #include <qdir.h>
 #include <qwhatsthis.h>
 #include <qregexp.h>
+#include <qpainter.h>
+#include <qpaintdevicemetrics.h>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -63,9 +65,10 @@
 #include "kfiledialog.h"
 
 #include "kolistview.h"
+#include "koeventviewer.h"
 
-
-
+extern QPixmap* sgListViewCompletedPix[6];
+extern QPixmap* sgListViewJournalPix;
 
 class KOListViewWhatsThis :public QWhatsThis
 {
@@ -125,21 +128,26 @@ bool ListItemVisitor::visit(Event *e)
         mItem->setText(4,"---");
     else
         mItem->setText(4,e->dtEndTimeStr());
+    mItem->setText(5, e->durationText());
     if ( e->isAlarmEnabled() ) {
-        mItem->setText(5,e->alarms().first()->offsetText() );
+        mItem->setText(6,e->alarms().first()->offsetText() );
     } else {
-        mItem->setText(5, i18n("No"));
+        mItem->setText(6, i18n("No"));
     }
-    mItem->setText(6, e->recurrence()->recurrenceText());
+    mItem->setText(7, e->recurrenceText());
     if( ! e->doesRecur() )
-        mItem->setSortKey( 6, "-" );
-    mItem->setText(7,"---");
-    mItem->setText(8,"---");
-    mItem->setText(9, e->cancelled() ? i18n("Yes") : i18n("No"));
-    mItem->setText(10,e->categoriesStr());
+        mItem->setSortKey( 7, "-" );
+    mItem->setText(8, e->cancelled() ? i18n("Yes") : i18n("No"));
+    mItem->setText(9,e->categoriesStr());
+    mItem->setText(10, KOPrefs::instance()->calName( e->calID() ));
+    mItem->setText(11, KGlobal::locale()->formatDateTime( e->lastModified(), true, true ));
 
-    QString key;
-    QTime t = e->doesFloat() ? QTime(0,0) : e->dtStart().time();
+    QString key; 
+    QDate d = e->lastModified().date();
+    QTime t = e->lastModified().time();
+    key.sprintf("%04d%02d%02d%02d%02d%02d",d.year(),d.month(),d.day(),t.hour(),t.minute(),t.second() );
+    mItem->setSortKey(12,key);
+    t = e->doesFloat() ? QTime(0,0) : e->dtStart().time();
     key.sprintf("%04d%02d%02d%02d%02d",ds.year(),ds.month(),ds.day(),t.hour(),t.minute());
     mItem->setSortKey(1,key);
 
@@ -151,7 +159,12 @@ bool ListItemVisitor::visit(Event *e)
 
 bool ListItemVisitor::visit(Todo *t)
 {
-    mItem->setText(0,i18n("Todo: %1").arg(t->summary()));
+    mItem->setText(0,t->summary());
+    if ( t->isCompleted() ) {
+        mItem->setSortKey(0,"99"+ t->summary().left(10));
+    } else 
+        mItem->setSortKey(0,QString::number( t->percentComplete()+1 )+ t->summary().left(10));
+    mItem->setPixmap( 0, *(sgListViewCompletedPix[t->percentComplete()/20]));
     if (t->hasStartDate()) {
         mItem->setText(1,t->dtStartDateStr());
         if (t->doesFloat()) {
@@ -163,41 +176,44 @@ bool ListItemVisitor::visit(Todo *t)
         mItem->setText(1,"---");
         mItem->setText(2,"---");
     }
-    mItem->setText(3,"---");
-    mItem->setText(4,"---");  
     if ( t->isAlarmEnabled() ) {
-        mItem->setText(5,t->alarms().first()->offsetText() );
+        mItem->setText(6,t->alarms().first()->offsetText() );
     } else {
-        mItem->setText(5, i18n("No"));
+        mItem->setText(6, i18n("No"));
     }
-    mItem->setText(6, t->recurrence()->recurrenceText());
+    mItem->setText(7, t->recurrenceText());
     if( ! t->doesRecur() )
-        mItem->setSortKey( 6, "-" );
+        mItem->setSortKey( 7, "-" );
     if (t->hasDueDate()) {
-        mItem->setText(7,t->dtDueDateStr());
+        mItem->setText(3,t->dtDueDateStr());
         if (t->doesFloat()) {
-            mItem->setText(8,"---");
+            mItem->setText(4,"---");
         } else {
-            mItem->setText(8,t->dtDueTimeStr());
+            mItem->setText(4,t->dtDueTimeStr());
         }
     } else {
-        mItem->setText(7,"---");
-        mItem->setText(8,"---");
+        mItem->setText(3,"---");
+        mItem->setText(4,"---");
     }
-    mItem->setText(9, t->cancelled() ? i18n("Yes") : i18n("No"));
-    mItem->setText(10,t->categoriesStr());
-
+    mItem->setText(5, t->durationText());
+    mItem->setText(8, t->cancelled() ? i18n("Yes") : i18n("No"));
+    mItem->setText(9,t->categoriesStr());
+    mItem->setText(10, KOPrefs::instance()->calName( t->calID() ));
+    mItem->setText(11, KGlobal::locale()->formatDateTime( t->lastModified(), true, true ));
     QString key;
-    QDate d;
+    QDate d = t->lastModified().date();
+    QTime tm = t->lastModified().time();
+    key.sprintf("%04d%02d%02d%02d%02d%02d",d.year(),d.month(),d.day(),tm.hour(),tm.minute(),tm.second() );
+    mItem->setSortKey(11,key);
     if (t->hasDueDate()) {
         d = t->dtDue().date();
-        QTime tm = t->doesFloat() ? QTime(0,0) : t->dtDue().time();
+        tm = t->doesFloat() ? QTime(0,0) : t->dtDue().time();
         key.sprintf("%04d%02d%02d%02d%02d",d.year(),d.month(),d.day(),tm.hour(),tm.minute());
-        mItem->setSortKey(7,key);
+        mItem->setSortKey(3,key);
     }
     if ( t->hasStartDate() ) {
         d = t->dtStart().date();
-        QTime tm = t->doesFloat() ? QTime(0,0) : t->dtStart().time();
+        tm = t->doesFloat() ? QTime(0,0) : t->dtStart().time();
         key.sprintf("%04d%02d%02d%02d%02d",d.year(),d.month(),d.day(),tm.hour(),tm.minute());
         mItem->setSortKey(1,key);
     }
@@ -206,24 +222,37 @@ bool ListItemVisitor::visit(Todo *t)
 
 bool ListItemVisitor::visit(Journal * j)
 { 
-    QString des = j->description().left(30);
-    des = des.simplifyWhiteSpace ();
-    des.replace (QRegExp ("\\n"),"" );
-    des.replace (QRegExp ("\\r"),"" );
-    mItem->setText(0,i18n("Journal: ")+des.left(25));
+    
+    QString des;
+    mItem->setPixmap( 0, *sgListViewJournalPix);
+    if ( !j->summary().isEmpty() ) {
+        des = j->summary();
+    } else {
+        des = j->description().left(30);
+        des = des.simplifyWhiteSpace ();
+        des.replace (QRegExp ("\\n"),"" );
+        des.replace (QRegExp ("\\r"),"" );
+    }
+    mItem->setText(0,des.left(25));
+    mItem->setSortKey(0,"0"+ des.left(25));
     mItem->setText(1,j->dtStartDateStr());
     mItem->setText(2,"---");
     mItem->setText(3,"---");
     mItem->setText(4,"---");
     mItem->setText(5,"---");
     mItem->setText(6,"---");
-    mItem->setText(7,j->dtStartDateStr());
+    mItem->setText(7,"---");
     mItem->setText(8,"---");
-    mItem->setText(9,"---");
-    mItem->setText(10,i18n("Last Modified: ")+  KGlobal::locale()->formatDateTime( j->lastModified() , true) );
+    mItem->setText(9,j->categoriesStr());
+    mItem->setText(10, KOPrefs::instance()->calName( j->calID() ));
+    mItem->setText(11, KGlobal::locale()->formatDateTime( j->lastModified(), true, true ));
 
-    QString key;
-    QDate d = j->dtStart().date();
+    QString key; 
+    QDate d = j->lastModified().date();
+    QTime tm = j->lastModified().time();
+    key.sprintf("%04d%02d%02d%02d%02d%02d",d.year(),d.month(),d.day(),tm.hour(),tm.minute(),tm.second() );
+    mItem->setSortKey(12,key);
+    d = j->dtStart().date();
     key.sprintf("%04d%02d%02d",d.year(),d.month(),d.day());
     mItem->setSortKey(1,key);
     mItem->setSortKey(7,key);
@@ -235,19 +264,22 @@ KOListView::KOListView(Calendar *calendar, QWidget *parent,
                        const char *name)
     : KOEventView(calendar, parent, name)
 {
+    
     mActiveItem = 0;
+    mForceShowCompletedTodos = false;
     mListView = new KOListViewListView(this);
     mListView->addColumn(i18n("Summary"));
     mListView->addColumn(i18n("Start Date"));
     mListView->addColumn(i18n("Start Time"));
-    mListView->addColumn(i18n("End Date"));
-    mListView->addColumn(i18n("End Time"));
+    mListView->addColumn(i18n("End/Due Date"));
+    mListView->addColumn(i18n("End/Due Time"));
+    mListView->addColumn(i18n("Duration"));
     mListView->addColumn(i18n("Alarm")); // alarm set?
     mListView->addColumn(i18n("Recurs")); // recurs?
-    mListView->addColumn(i18n("Due Date"));
-    mListView->addColumn(i18n("Due Time"));
     mListView->addColumn(i18n("Cancelled"));
     mListView->addColumn(i18n("Categories"));
+    mListView->addColumn(i18n("Calendar"));
+    mListView->addColumn(i18n("Last Modified"));
 
     mListView->setColumnAlignment(0,AlignLeft);
     mListView->setColumnAlignment(1,AlignLeft);
@@ -260,29 +292,61 @@ KOListView::KOListView(Calendar *calendar, QWidget *parent,
     mListView->setColumnAlignment(8,AlignLeft);
     mListView->setColumnAlignment(9,AlignLeft);
     mListView->setColumnAlignment(10,AlignLeft);
-    mListView->setColumnWidthMode(10, QListView::Manual);
+    mListView->setColumnAlignment(11,AlignLeft);
     mKOListViewWhatsThis = new KOListViewWhatsThis(mListView->viewport(),this);
 
     int iii = 0;
-    for ( iii = 0; iii< 10 ; ++iii )
+    for ( iii = 0; iii< 12 ; ++iii )
         mListView->setColumnWidthMode( iii, QListView::Manual );
 
     QBoxLayout *layoutTop = new QVBoxLayout(this);
     layoutTop->addWidget(mListView);
     mListView->setFont ( KOPrefs::instance()->mListViewFont );
     mPopupMenu = eventPopup();
-    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Select all"),this,
-                                  SLOT(allSelection()),true);
-    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Deselect all"),this,
-                                  SLOT(clearSelection()),true);
-    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Delete all selected"),this,
-                                  SLOT(deleteAll()),true);
+    QPopupMenu* selPopup = new QPopupMenu ( this );
     mPopupMenu->insertSeparator();
+    
+    selPopup->insertItem(i18n("All"),this,
+                                  SLOT(allSelection()));
+    selPopup->insertItem(i18n("None"),this,
+                                  SLOT(clearSelection()));
+    selPopup->insertItem(i18n("Delete selected..."),this,
+                                  SLOT(deleteAll()));
+    mPopupMenu->insertItem(i18n("Selection"), selPopup );
+    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
+                                  i18n("Hide all selected"),this,
+                                  SLOT(hideAll()),true);
+
+    selPopup->insertSeparator();
     QPopupMenu * exportPO = new QPopupMenu ( this );
-    mPopupMenu->insertItem( i18n("Export selected"),  exportPO );
+    selPopup->insertItem( i18n("Export"),  exportPO );
+#ifdef DESKTOP_VERSION
+    mPopupMenu->insertSeparator();
+    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
+                                  i18n("Print complete list..."),this,
+                                  SLOT(printList()),true);
+#endif
+    mCalPopup = new QPopupMenu ( this );
+    selPopup->insertItem( i18n("Set Calendar"),  mCalPopup );
+
+    selPopup->insertItem(i18n("Set categories")+"...",this,
+                         SLOT(setCat()) );
+    selPopup->insertItem( i18n("Set alarm..."),this,
+                          SLOT(setAlarm()));
+#if 0
+    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
+                                  i18n("Set categories")+"...",this,
+                                  SLOT(setCat()),true);
+    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
+                                  i18n("Set alarm..."),this,
+                                  SLOT(setAlarm()),true); 
+#endif
+    QObject::connect(mCalPopup,SIGNAL(aboutToShow()),this,
+                     SLOT( populateCalPopup() ));
+    QObject::connect(mCalPopup,SIGNAL(activated( int )),this,
+                     SLOT( setCalendar( int ) ));
+    QObject::connect(mPopupMenu,SIGNAL(categoryChanged( Incidence * )),this,
+                     SLOT( catChanged( Incidence * ) ));
     exportPO->insertItem( i18n("As iCal (ics) file..."),this,
                                   SLOT(saveToFile()));
     exportPO->insertItem( i18n("As vCal (vcs) file..."),this,
@@ -290,23 +354,19 @@ KOListView::KOListView(Calendar *calendar, QWidget *parent,
     exportPO->insertItem( i18n("Journal/Details..."),this,
                                   SLOT(saveDescriptionToFile()));
     // mPopupMenu->insertSeparator();
-    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Add Categ. to selected..."),this,
-                                  SLOT(addCat()),true);
-    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Set Categ. for selected..."),this,
-                                  SLOT(setCat()),true);
+    // mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
+    //                            i18n("Add Categ. to selected..."),this,
+    //                            SLOT(addCat()),true);
     //mPopupMenu->insertSeparator();
-    mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Set alarm for selected..."),this,
-                                  SLOT(setAlarm()),true);
-
-
 #ifndef DESKTOP_VERSION
-    mPopupMenu->insertSeparator();
+    selPopup->insertSeparator();
+    selPopup->insertItem( i18n("Beam via IR..."),this,
+                          SLOT(beamSelected()));
+#if 0
     mPopupMenu->addAdditionalItem(QIconSet(QPixmap()),
-                                  i18n("Beam selected via IR"),this,
+                                  i18n("Beam via IR"),this,
                                   SLOT(beamSelected()),true);
+#endif
 #endif
     /*
       mPopupMenu = new QPopupMenu;
@@ -345,6 +405,14 @@ KOListView::~KOListView()
 #endif 
 }
 
+void KOListView::catChanged( Incidence* inc)
+{
+    KOListViewItem* item = getItemForEvent(inc);
+    if (item) { 
+        ListItemVisitor v(item, mStartDate );
+        inc->accept(v);
+    }
+}
 QString KOListView::getWhatsThisText(QPoint p)
 {
     KOListViewItem* item = ( KOListViewItem* ) mListView->itemAt( p );
@@ -357,6 +425,55 @@ QString KOListView::getWhatsThisText(QPoint p)
 
 }
 
+void KOListView::setCalendar( int c )
+{
+    int result = QMessageBox::warning( this, i18n("KO/Pi: Information!"),
+                                       i18n("This adds the selected\nitems to the calendar\n%1\nand removes them from\ntheir current calendar!").arg( KOPrefs::instance()->calName( c ) ),
+                                       i18n("Continue"), i18n("Cancel"), 0,
+                                       0, 1 );
+    if ( result != 0 ) {
+        return;
+    }
+    
+    QPtrList<Incidence> delSel = getSelectedIncidences() ;
+    int icount = delSel.count();
+    if ( icount ) {
+        Incidence *incidence = delSel.first();
+        while ( incidence ) {
+            incidence->setCalID( c );
+            KOListViewItem * item = getItemForEvent( incidence );
+            if ( item ) {
+                ListItemVisitor v(item, mStartDate );
+                incidence->accept(v);
+            }
+            incidence = delSel.next();
+        }
+    }
+    QPtrList<KopiCalendarFile> calendars = KOPrefs::instance()->mCalendars;
+    KopiCalendarFile * cal = calendars.first();
+    while ( cal ) {
+        mCalendar->setCalendarEnabled( cal->mCalNumber,cal->isEnabled );
+        mCalendar->setAlarmEnabled( cal->mCalNumber, cal->isAlarmEnabled );
+        mCalendar->setReadOnly( cal->mCalNumber, cal->isReadOnly );
+        if ( cal->isStandard )
+            mCalendar->setDefaultCalendar( cal->mCalNumber );
+        cal = calendars.next();
+    }
+    mCalendar->setSyncEventsReadOnly();
+    mCalendar->reInitAlarmSettings();
+
+}
+void KOListView::populateCalPopup()
+{
+    mCalPopup->clear();
+    KopiCalendarFile * kkf = KOPrefs::instance()->mCalendars.first();
+    while ( kkf ) {
+        int index = mCalPopup->insertItem( kkf->mName+"...", kkf->mCalNumber);
+        if ( kkf->mErrorOnLoad || kkf->isReadOnly )
+        mCalPopup->setItemEnabled( index, false );
+        kkf = KOPrefs::instance()->mCalendars.next();
+    }
+}
 void KOListView::updateList()
 {
     // qDebug(" KOListView::updateList() ");
@@ -367,77 +484,64 @@ void KOListView::clearList()
 {
     clear ();
 }
-void KOListView::addCat( )
-{
-    setCategories( false );
-}
+
 void KOListView::setCat()
 {
-    setCategories( true );
+
+    bool set = true;
+    int result = KMessageBox::warningYesNoCancel(this, 
+                                                 i18n("Do you want to <b>add</b> categories to the selected items or <b>reset</b> the list (i.e. remove current categories)?"),
+                                                 i18n("Set categories"),
+                                                 i18n("Add"),
+                                                 i18n("Reset"));
+    if (result == KMessageBox::Cancel) return;
+    if (result == KMessageBox::Yes) set = false;
+    setCategories( set );
 }
+
 void  KOListView::setAlarm()
 {
     KOAlarmPrefs kap( this);
     if ( !kap.exec() )
         return;
-    QStringList itemList;
-    QPtrList<KOListViewItem> sel ;
-    QListViewItem *qitem  = mListView->firstChild ();
-    while ( qitem ) {
-        if ( qitem->isSelected() ) {
-            Incidence* inc = ((KOListViewItem *) qitem)->data();
-            if ( inc->type() != "Journal" ) {
-                if ( inc->type() == "Todo" ) {
-                    if ( ((Todo*)inc)->hasDueDate() )
-                      sel.append(((KOListViewItem *)qitem));
-                } else
-                      sel.append(((KOListViewItem *)qitem));
+    QPtrList<Incidence> delSel = getSelectedIncidences( true, true, false, true ); // no journals, only due todos
+    Incidence* inc = delSel.first();
+    int count = 0;
+    while ( inc ) {
+        ++count;
+        if (kap.mAlarmButton->isChecked()) {
+            if (inc->alarms().count() == 0) 
+                inc->newAlarm();
+            Alarm *alarm = inc->alarms().first();
+            alarm->setEnabled(true);
+            int j = kap.mAlarmTimeEdit->value()* -60;
+            if (kap.mAlarmIncrCombo->currentItem() == 1)
+                j = j * 60;
+            else if (kap.mAlarmIncrCombo->currentItem() == 2)
+                j = j * (60 * 24);
+            alarm->setStartOffset( j );
+
+            if (!kap.mAlarmProgram.isEmpty() && kap.mAlarmProgramButton->isOn()) {
+                alarm->setProcedureAlarm(kap.mAlarmProgram);
+            }
+            else if (!kap.mAlarmSound.isEmpty() && kap.mAlarmSoundButton->isOn())
+                alarm->setAudioAlarm(kap.mAlarmSound);
+            else
+                alarm->setType(Alarm::Invalid);
+        } else {
+            QPtrList<Alarm> alarms = inc->alarms();
+            Alarm *alarm;
+            for (alarm = alarms.first(); alarm; alarm = alarms.next() ) {
+                alarm->setEnabled(false);
+                alarm->setType(Alarm::Invalid);
             }
         }
-        qitem = qitem->nextSibling();
-    }
-    int count = 0;
-    KOListViewItem * item, *temp;
-    item = sel.first();
-    Incidence* inc;
-    while ( item ) {
-        inc = item->data();
-            ++count;
-            if (kap.mAlarmButton->isChecked()) {
-                if (inc->alarms().count() == 0) 
-                    inc->newAlarm();
-                QPtrList<Alarm> alarms = inc->alarms();
-                Alarm *alarm;
-                for (alarm = alarms.first(); alarm; alarm = alarms.next() ) {
-                    alarm->setEnabled(true);
-                    int j = kap.mAlarmTimeEdit->value()* -60;
-                    if (kap.mAlarmIncrCombo->currentItem() == 1)
-                        j = j * 60;
-                    else if (kap.mAlarmIncrCombo->currentItem() == 2)
-                        j = j * (60 * 24);
-                    alarm->setStartOffset( j );
-
-                    if (!kap.mAlarmProgram.isEmpty() && kap.mAlarmProgramButton->isOn()) {
-                        alarm->setProcedureAlarm(kap.mAlarmProgram);
-                    }
-                    else if (!kap.mAlarmSound.isEmpty() && kap.mAlarmSoundButton->isOn())
-                        alarm->setAudioAlarm(kap.mAlarmSound);
-                    else
-                        alarm->setType(Alarm::Invalid);
-                    //alarm->setAudioAlarm("default");
-                    // TODO: Deal with multiple alarms
-                    break; // For now, stop after the first alarm
-                }
-            } else {
-                Alarm* alarm = inc->alarms().first();
-                if ( alarm ) {
-                    alarm->setEnabled(false);
-                    alarm->setType(Alarm::Invalid);
-                }
-            }
+        KOListViewItem* item = getItemForEvent(inc);
+        if (item) { 
             ListItemVisitor v(item, mStartDate );
             inc->accept(v);
-            item = sel.next();
+        }
+        inc = delSel.next();   
     }
     topLevelWidget()->setCaption( i18n("Changed alarm for %1 items").arg( count )  );
     qDebug("KO: Set alarm for %d items", count);
@@ -455,100 +559,29 @@ void KOListView::setCategories( bool removeOld )
     }
     QStringList catList = csd->selectedCategories();
     delete csd;
-    // if ( catList.count() == 0 )
-    //   return;
-    //catList.sort();
-    QString categoriesStr = catList.join(",");
-    int i;
-    QStringList itemList;
-    QPtrList<KOListViewItem> sel ;
-    QListViewItem *qitem  = mListView->firstChild ();
-    while ( qitem ) {
-        if ( qitem->isSelected() ) {
-            sel.append(((KOListViewItem *)qitem));
-        }
-        qitem = qitem->nextSibling();
-    }
-    KOListViewItem * item, *temp;
-    item = sel.first();
-    if( item ) {
-        Incidence* inc = item->data() ;
-        bool setSub = false;
-        if( inc->type() == "Todo" && sel.count() == 1 &&  inc->relations().count() > 0 ) {
-            int result = KMessageBox::warningYesNoCancel(this, 
-                                                         i18n("The todo\n%1\nhas subtodos!\nDo you want to set\nthe categories for\nall subtodos as well?").arg( inc->summary().left ( 25 ) ),
-                                                         i18n("Todo has subtodos"),
-                                                         i18n("Yes"),
-                                                         i18n("No"));
-            if (result == KMessageBox::Cancel) item = 0;
-            if (result == KMessageBox::Yes) setSub = true;
-        }
-        while ( item ) {
-            inc = item->data();
-            if ( removeOld ) {
-                inc->setCategories( catList, setSub );
-            } else {
-                inc->addCategories( catList, setSub );
-            } 
+    QPtrList<Incidence> delSel = getSelectedIncidences(); // all inc allowed;
+    Incidence* inc = delSel.first();
+    while ( inc ) {
+        if ( removeOld ) {
+            inc->setCategories( catList, false );
+        } else {
+            inc->addCategories( catList, false );
+        } 
+        KOListViewItem* item = getItemForEvent(inc);
+        if (item) { 
             ListItemVisitor v(item, mStartDate );
             inc->accept(v);
-            item = sel.next();
         }
+        inc = delSel.next();
     }
     QTimer::singleShot( 1, this, SLOT ( resetFocus() ) );
 }
 
 void KOListView::beamSelected()
 {
-    int icount = 0;
-    QPtrList<Incidence> delSel ;
-    QListViewItem *item  = mListView->firstChild ();
-    while ( item ) {
-        if ( item->isSelected() ) {
-            delSel.append(((KOListViewItem *)item)->data());
-            ++icount;
-        }
-        
-        item = item->nextSibling();
-    }
-    if ( icount ) {
+    QPtrList<Incidence> delSel = getSelectedIncidences() ;
+    if ( delSel.count() )
         emit beamIncidenceList( delSel );
-        return;
-        QString fn ;
-        fn = QDir::homeDirPath()+"/kopitempbeamfile.vcs";
-        QString mes;
-        bool createbup = true;
-        if ( createbup ) {
-            QString description = "\n";
-            CalendarLocal* cal = new CalendarLocal();
-            cal->setTimeZoneId(KPimGlobalPrefs::instance()->mTimeZoneId);
-            Incidence *incidence = delSel.first();
-            while ( incidence ) {
-                Incidence *in = incidence->clone();
-                description += in->summary() + "\n";
-                cal->addIncidence( in );
-                incidence = delSel.next();
-            }
-            FileStorage storage( cal, fn, new VCalFormat );
-            storage.save();
-            delete cal;
-            mes = i18n("KO/Pi: Ready for beaming");
-            topLevelWidget()->setCaption(mes); 
-
-#ifndef DESKTOP_VERSION
-            Ir *ir = new Ir( this ); 
-            connect( ir, SIGNAL( done( Ir * ) ), this, SLOT( beamDone( Ir * ) ) );
-            ir->send( fn, description, "text/x-vCalendar" );
-#endif
-        }
-    }
-}
-void KOListView::beamDone( Ir *ir )
-{
-#ifndef DESKTOP_VERSION
-    delete ir;
-#endif
-    topLevelWidget()->setCaption(i18n("KO/Pi:Beaming done")); 
 }
 
 void KOListView::saveDescriptionToFile()
@@ -561,17 +594,8 @@ void KOListView::saveDescriptionToFile()
     if ( result != 0 ) {
         return;
     }
-  int icount = 0;
-    QPtrList<Incidence> delSel ;
-    QListViewItem *item  = mListView->firstChild ();
-    while ( item ) {
-        if ( item->isSelected() ) {
-            delSel.append(((KOListViewItem *)item)->data());
-            ++icount;
-        }
-        
-        item = item->nextSibling();
-    }
+    QPtrList<Incidence> delSel = getSelectedIncidences() ;
+    int icount = delSel.count();
     if ( icount ) {
         QString fn =  KOPrefs::instance()->mLastSaveFile;
         fn =  KFileDialog::getSaveFileName( fn, i18n("Save filename"), this );
@@ -597,9 +621,14 @@ void KOListView::saveDescriptionToFile()
             Incidence *incidence = delSel.first();
             icount = 0;
             while ( incidence ) {
-                if ( incidence->type()  == "Journal" ) {
+                if ( incidence->typeID()  == journalID ) {
                     text += "\n************************************\n";
-                    text += i18n("Journal from: ") +incidence->dtStartDateStr( false );
+                    if ( !incidence->summary().isEmpty() )
+                        text += i18n("Journal: %1 from ").arg( incidence->summary() )  +incidence->dtStartDateStr( false );
+                    else
+                        text += i18n("Journal from: ") +incidence->dtStartDateStr( false );
+                    if ( !incidence->location().isEmpty() )
+                        text +="\n(" +  i18n("Location: ") + incidence->location()+ ")";
                     text +="\n" +  i18n("Last modified: ") +KGlobal::locale()->formatDateTime(incidence->lastModified(), false);
                     text +="\n" +  i18n("Description: ") + "\n"+ incidence->description();
                     ++icount;
@@ -607,14 +636,14 @@ void KOListView::saveDescriptionToFile()
                 } else {
                     if ( !incidence->description().isEmpty() ) {
                         text += "\n************************************\n";
-                        if ( incidence->type()  == "Todo" )
+                        if ( incidence->typeID()  == todoID )
                             text += i18n("To-Do: ");
                         text += incidence->summary();
+                        if ( !incidence->location().isEmpty() )
+                            text +="\n(" +  i18n("Location: ") + incidence->location()+ ")";
                         if ( incidence->hasStartDate() )
                             text +="\n"+ i18n("Start Date: ") + incidence->dtStartStr( false );
                         text +="\n"+ i18n("Last modified: ") +KGlobal::locale()->formatDateTime(incidence->lastModified(), false);
-                        if ( !incidence->location().isEmpty() )
-                            text += "\n" +i18n("Location: ") + incidence->location();
                         text += "\n" + i18n("Description: ") + "\n" + incidence->description();
                         ++icount;
 
@@ -645,32 +674,89 @@ void KOListView::saveToFile()
 {
     writeToFile( true );
 }
-void KOListView::writeToFile( bool iCal )
+QPtrList<Incidence> KOListView::getSelectedIncidences( bool includeEvents, bool includeTodos, bool includeJournals, bool onlyDueTodos )
 {
-
-    int icount = 0;
     QPtrList<Incidence> delSel ;
+    bool addSubTodos = false;
+    bool askSubTodos = true;
     QListViewItem *item  = mListView->firstChild ();
-    bool journal = iCal; // warn only for vCal
     while ( item ) {
         if ( item->isSelected() ) {
-            if ( !journal )
-                if ( ((KOListViewItem *)item)->data()->type() == "Journal")
-                    journal = true;
-            delSel.append(((KOListViewItem *)item)->data());
-            ++icount;
+            Incidence* inc = ((KOListViewItem *)item)->data();
+            if ( ( addSubTodos && delSel.findRef( inc ) == -1) || !addSubTodos   ) {
+                if ( (inc->typeID() == todoID && includeTodos) || 
+                     (inc->typeID() == eventID && includeEvents) || 
+                     (inc->typeID() == journalID && includeJournals) ) {
+                    if ( inc->typeID() == todoID && onlyDueTodos ) {
+                        if ( ((Todo*)inc)->hasDueDate() )
+                            delSel.append( inc );
+                    } else
+                        delSel.append( inc );
+                    
+                }
+            }
+            if ( inc->typeID() == todoID ) {
+                Todo * todo = (Todo*) inc; 
+                if ( todo->relations().count() ) {
+                    if ( askSubTodos ) {
+                        int result = KMessageBox::warningYesNoCancel(this, 
+                                                                     i18n("One (or more) selected\ntodo has subtodos!\nDo you want to select\nall subtodos of all\nselected todos as well?"),
+                                                                     i18n("Todo has subtodos"),
+                                                                     i18n("Yes"),
+                                                                     i18n("No"));
+                        if ( result == KMessageBox::Cancel ) {
+                            delSel.clear();
+                            return delSel;
+                        }
+                        if (result == KMessageBox::Yes) 
+                            addSubTodos = true;
+                        askSubTodos = false;
+                    }
+                    if ( addSubTodos ) {
+                        QPtrList<Incidence> tempSel ;
+                        inc->addRelationsToList( &tempSel );
+                        Incidence* tempinc = tempSel.first();
+                        while ( tempinc ) {
+                            if ( delSel.findRef( tempinc ) == -1 ) {
+                                if ( tempinc->typeID() == todoID && onlyDueTodos ) {
+                                    if ( ((Todo*)tempinc)->hasDueDate() )
+                                        delSel.append( tempinc );
+                                } else
+                                    delSel.append( tempinc );
+                            }
+                            tempinc = tempSel.next();
+                        }
+                    }
+                }
+            }
         }
-        
         item = item->nextSibling();
     }
-    if ( !iCal && journal ) {
-        int result = KMessageBox::warningContinueCancel(this,
-                                                        i18n("The journal entries can not be\nexported to a vCalendar file."),
-                                                        i18n("Data Loss Warning"),i18n("Proceed"),i18n("Cancel"),
-                                                        true);
-        if (result != KMessageBox::Continue) return;
+    return delSel;
+}
+
+void KOListView::writeToFile( bool iCal )
+{
+    QPtrList<Incidence> delSel = getSelectedIncidences(); // all inc allowed;
+    if ( !iCal ) {
+        bool journal = false;
+        Incidence *incidence = delSel.first();
+        while ( incidence ) {
+            if ( incidence->typeID() == journalID ) {
+                journal = true;
+                break;
+            }
+            incidence = delSel.next();
+        }
+        if ( journal ) {
+            int result = KMessageBox::warningContinueCancel(this,
+                                                            i18n("The journal entries can not be\nexported to a vCalendar file."),
+                                                            i18n("Data Loss Warning"),i18n("Proceed"),i18n("Cancel"),
+                                                            true);
+            if (result != KMessageBox::Continue) return;
+        }
     }
-    if ( icount ) {
+    if ( delSel.count() ) {
         QString fn =  KOPrefs::instance()->mLastSaveFile;
         QString extension;
         if ( iCal ) {
@@ -722,20 +808,32 @@ void KOListView::writeToFile( bool iCal )
     }
     QTimer::singleShot( 1, this, SLOT ( resetFocus() ) );
 }
-void KOListView::deleteAll()
+void  KOListView::hideAll()
 {
-    int icount = 0;
-    QPtrList<Incidence> delSel ;
+    QPtrList<QListViewItem> delSel ;
     QListViewItem *item  = mListView->firstChild ();
     while ( item ) {
         if ( item->isSelected() ) {
-            delSel.append(((KOListViewItem *)item)->data());
-            ++icount;
+            delSel.append(item);
         }
-        
         item = item->nextSibling();
     }
-    if ( icount ) {
+    item = delSel.first() ;
+    while ( item ) {
+        QListViewItem * del = item;
+        item = delSel.next();
+        delete del;
+    }
+}
+void  KOListView::printList()
+{
+    mListView->printList();
+}
+void KOListView::deleteAll()
+{
+    QPtrList<Incidence> delSel = getSelectedIncidences(); // all inc allowed;;
+    if ( delSel.count() ) {
+        int icount = delSel.count();
         Incidence *incidence = delSel.first();
         Incidence *toDelete;   
         KOPrefs *p = KOPrefs::instance();
@@ -760,7 +858,7 @@ void KOListView::deleteAll()
             dia.setGeometry( (dw-w)/2, (dh - h )/2 ,w,h );
             //dia.resize( 240,50 );
             dia.show();
-            
+            KOPrefs::instance()->mGlobalUpdateDisabled = true;
             while ( incidence ) {
                 bar.setProgress( delCounter );
                 mess = mess.sprintf( i18n("Deleting item %d ..."), ++delCounter );
@@ -773,6 +871,8 @@ void KOListView::deleteAll()
                     break;
                
             }
+            KOPrefs::instance()->mGlobalUpdateDisabled = false;
+            emit deleteIncidenceSignal( 0 ); 
             mess = mess.sprintf( i18n("%d items remaining in list."), count() );
             topLevelWidget ()->setCaption( mess );
             p->mConfirm = confirm;
@@ -861,8 +961,10 @@ void KOListView::resetFocus()
 void KOListView::updateView()
 {
     mListView->setFocus();
-    if ( mListView->firstChild () )
+    if ( mListView->firstChild () ) {
         mListView->setCurrentItem( mListView->firstChild () );
+    }
+    processSelectionChange( mListView->firstChild ()  );
 }
 void KOListView::updateConfig()
 {
@@ -881,17 +983,13 @@ void KOListView::showDates(const QDate &start, const QDate &end)
     clear();
     mStartDate = start;
     QDate date = start;
-    QPtrList<Journal> j_list;
     while( date <= end ) {
         addEvents(calendar()->events(date));
         addTodos(calendar()->todos(date));
-        Journal* jo = calendar()->journal(date);
-        if ( jo )
-            j_list.append( jo );
+        addJournals( calendar()->journals4Date(date)  );
         date = date.addDays( 1 );
     }
-    addJournals(j_list);
-    emit incidenceSelected( 0 );
+    //emit incidenceSelected( 0 );
     updateView();
   
 }
@@ -929,11 +1027,21 @@ void KOListView::addJournals(QPtrList<Journal> eventList)
     }
 }
 
+void KOListView::showCompletedTodos()
+{
+    mForceShowCompletedTodos = true;
+}
 void KOListView::addIncidence(Incidence *incidence)
 {
     if ( mUidDict.find( incidence->uid() ) ) return;
   
     // mListView->setFont ( KOPrefs::instance()->mListViewFont );
+    if ( incidence->typeID() == todoID ) {
+        if ( ! mForceShowCompletedTodos ) {
+            if ( !KOPrefs::instance()->mShowCompletedTodo && ((Todo*)incidence)->isCompleted() )
+                return;
+        }
+    }
     mUidDict.insert( incidence->uid(), incidence );
     KOListViewItem *item = new KOListViewItem( incidence, mListView ); 
     ListItemVisitor v(item, mStartDate );
@@ -968,9 +1076,8 @@ void KOListView::changeEventDisplay(Event *event, int action)
     case KOGlobals::EVENTEDITED:
         item = getItemForEvent(event);
         if (item) { 
-            mUidDict.remove( event->uid() ); 
-            delete item;
-            addIncidence( event );
+            ListItemVisitor v(item, mStartDate );
+            ((Incidence*)event)->accept(v);
         }
         break;
     case KOGlobals::EVENTDELETED:
@@ -985,7 +1092,7 @@ void KOListView::changeEventDisplay(Event *event, int action)
     }
 }
 
-KOListViewItem *KOListView::getItemForEvent(Event *event)
+KOListViewItem *KOListView::getItemForEvent(Incidence *event)
 {
     KOListViewItem *item = (KOListViewItem *)mListView->firstChild();
     while (item) {
@@ -1202,7 +1309,6 @@ KOListViewListView::KOListViewListView(KOListView * lv )
 }
 bool KOListViewListView::hasMultiSelection(QListViewItem* item)
 {
-    int selCount = 0;
     QListViewItem *qitem  = firstChild ();
     while ( qitem ) {
         if ( qitem->isSelected() && item != qitem ) 
@@ -1287,3 +1393,50 @@ void KOListViewListView::contentsMouseMoveEvent(QMouseEvent *e)
     KListView::contentsMouseMoveEvent(e);
 }
 
+#define protected public
+#include <qheader.h>
+#undef protected 
+void  KOListViewListView::printList()
+{
+#ifdef DESKTOP_VERSION 
+    KOPrintPrefs pp ( this );
+    if (!pp.exec() )
+        return;
+    int scaleval = pp.printMode() ;
+
+    QPrinter printer;
+    if (!printer.setup() )
+        return;
+    clearSelection (); 
+    QPainter p;
+    p.begin ( &printer  );
+    QPaintDeviceMetrics m = QPaintDeviceMetrics ( &printer );
+    float dx, dy;
+    int wid = (m.width() * 9)/10;
+    dx = (float) wid/(float)contentsWidth ();
+    dy  = (float)(m.height()) / (float)contentsHeight ();
+    float scale;
+    // scale to fit the width or height of the paper
+    if ( dx < dy )
+        scale = dx;
+    else
+        scale = dy;
+
+    p.translate( m.width()/10,m.width()/10 );
+    if ( scaleval == 2 ||  scaleval == 1 && scale < 1.0 ) {
+        p.scale( scale, scale );
+    }
+
+    int cou = header()->count();
+    int iii;
+    QRect rect ( 0,0,0, header()->height());
+    for ( iii = 0; iii < cou; ++iii ) {
+        rect.setLeft ( header()->sectionPos( iii ) ); 
+        rect.setRight ( header()->sectionPos( iii ) + header()->sectionSize (iii)); 
+        header()->paintSection ( & p,  header()->mapToIndex (iii),  rect );
+    }
+    p.translate( 0,  header()->height());
+    drawContentsOffset ( &p, 0,0, 0,0, contentsWidth (),  contentsHeight () ); 
+    p.end();
+#endif   
+}
