@@ -53,6 +53,7 @@ static KStaticDeleter<KOPrefs> insd;
 KOPrefs::KOPrefs() :
   KPimPrefs("korganizerrc")
 {
+    mGlobalUpdateDisabled = false;
   mCategoryColors.setAutoDelete(true);
   fillMailDefaults();
   mDefaultCategoryColor           = QColor(175,210,255);//196,196,196);
@@ -116,6 +117,7 @@ KOPrefs::KOPrefs() :
   addItemBool("ToolBarHorF",&mToolBarHorF, true );
   addItemBool("ToolBarUpF",&mToolBarUpF, false );
   addItemBool("ToolBarMiniIcons",&mToolBarMiniIcons, false );
+  addItemBool("WhatsNextTime2Lines",&mWhatsNextTime2Lines, false );
   addItemInt("Whats Next Days",&mWhatsNextDays,3);
   addItemInt("Whats Next Prios",&mWhatsNextPrios,1);
 
@@ -131,6 +133,7 @@ KOPrefs::KOPrefs() :
   addItemStringList("LocationDefaults",&mLocationDefaults );
   addItemStringList("EventSummary User",&mEventSummaryUser);
   addItemStringList("TodoSummary User",&mTodoSummaryUser);
+  addItemStringList("JournalSummary User",&mJournalSummaryUser);
 
   addItemBool("Enable Group Scheduling",&mEnableGroupScheduling,false);
   addItemBool("Enable Project View",&mEnableProjectView,false);
@@ -229,7 +232,7 @@ KOPrefs::KOPrefs() :
   
 
   KPrefs::setCurrentGroup("Views");
-  addItemBool("Block Popup Menu",&mBlockPopupMenu,true);
+  addItemBool("Block Popup Menu",&mBlockPopupMenu,false);
   addItemBool("Show Date Navigator",&mShowDateNavigator,true);
   addItemInt("Hour Size",&mHourSize,8);
   addItemBool("Show Daily Recurrences",&mDailyRecur,true);
@@ -262,6 +265,7 @@ KOPrefs::KOPrefs() :
   addItemBool("TodoViewShowsPercentage",&mTodoViewShowsPercentage,false);
   addItemBool("TodoViewUsesSmallFont",&mTodoViewUsesSmallFont,true);
   addItemBool("MonthViewUsesBigFont",&mMonthViewUsesBigFont,true);
+  addItemBool("MonthViewWeekRowlayout",&mMonthViewWeekRowlayout,false);
   addItemBool("TodoViewUsesForegroundColor",&mTodoViewUsesForegroundColor,false);
   addItemBool("MonthViewUsesForegroundColor",&mMonthViewUsesForegroundColor,false);
 #ifdef DESKTOP_VERSION
@@ -318,7 +322,7 @@ KOPrefs::KOPrefs() :
   addItemBool("WTshowDetails",&mWTshowDetails,false);
   addItemBool("WTshowCreated",&mWTshowCreated,false);
   addItemBool("WTshowChanged",&mWTshowChanged,false);
-
+  mCalendars.setAutoDelete( true ); 
 }
 
 
@@ -326,7 +330,8 @@ KOPrefs::~KOPrefs()
 {
   if (mInstance == this)
       mInstance = insd.setObject(0); 
- 
+  mCalendars.setAutoDelete( true );
+  mCalendars.clear();
   //qDebug("KOPrefs::~KOPrefs() ");
 }
 
@@ -362,6 +367,7 @@ void KOPrefs::setAllDefaults()
     setCategoryDefaults();
     mEventSummaryUser  = getDefaultList() ;
     mTodoSummaryUser  = getDefaultList() ;
+    mJournalSummaryUser  = getDefaultList() ;
     mLocationDefaults  = getLocationDefaultList();
 }
 
@@ -390,19 +396,19 @@ QStringList KOPrefs::getLocationDefaultList()
 QStringList KOPrefs::getDefaultList()
 {
     QStringList retval ;
-    retval << i18n("Anniversary") << i18n("Appointment") << i18n("Birthday") << i18n("Business") << i18n("Business Travel") << i18n("Cinema")  << i18n("Customer")
-           << i18n("Break")<< i18n("Breakfast")<< i18n("Competition")<< i18n("Dinner")
-           << i18n("Education")<< i18n("Family")  << i18n("Favorites")  << i18n("Festival")<< i18n("Fishing")<< i18n("Flight") << i18n("Gifts")  
-           << i18n("Holiday") << i18n("Holiday Cards")<< i18n("Hot Contacts") << i18n("Hiking") << i18n("Hunting") << i18n("Key Customer") << i18n("Kids") 
-                    << i18n("Lunch")  << i18n("Meeting") << i18n("Miscellaneous") << i18n("Partner")<< i18n("Party") << i18n("Personal") << i18n("Personal Travel")
-           << i18n("PHB") << i18n("Phone Calls") << i18n("Projects") << i18n("Recurring") << i18n("School") << i18n("Shopping")
-           << i18n("Speach")  << i18n("Special Occasion") << i18n("Sports") << i18n("Talk") << i18n("Travel") << i18n("TV")<< i18n("University")
-           << i18n("Vacation") << i18n("VIP") << i18n("SyncEvent")  ;
+    retval << i18n("Anniversary") << i18n("Appointment") << i18n("Birthday") << i18n("Business")  << i18n("Customer")
+           << i18n("Break")
+           << i18n("Family")  << i18n("Favorites") << i18n("Fishing") << i18n("Gifts")  
+           << i18n("Holiday") << i18n("Holiday Cards")<< i18n("Hot Contacts")  
+                     << i18n("Meeting") << i18n("Miscellaneous") << i18n("Partner") << i18n("Personal") 
+           << i18n("PHB") << i18n("Phone Calls")   << i18n("Shopping")
+            << i18n("Sports") << i18n("Talk") << i18n("Travel") << i18n("TV") 
+           << i18n("Vacation")  ;
     retval.sort();
     //qDebug("cat %s ", retval.join("-").latin1());
     return retval; 
 }
-
+// << i18n("Business Travel") << i18n("Education") << i18n("Hiking") << i18n("Hunting")  << i18n("Recurring") << i18n("Personal Travel")  << i18n("Speach")   << i18n("Festival") << i18n("Competition")<< i18n("Party")<< i18n("Projects")<< i18n("Kids") << i18n("Special Occasion")<< i18n("Breakfast")<<  i18n("Dinner") << i18n("Lunch")<< i18n("University")<< i18n("School")<< i18n("Flight")<< i18n("Key Customer") << i18n("VIP") << i18n("SyncEvent")  << i18n("Cinema") 
 void KOPrefs::usrReadConfig()
 {
     config()->setGroup("General");
@@ -435,11 +441,92 @@ void KOPrefs::usrReadConfig()
         setCategoryColor(*it,config()->readColorEntry(*it,&mDefaultCategoryColor));
    
     }
- 
+    KConfig fc (locateLocal("config","kopicalendarrc"));
+    fc.setGroup("CC");
+    int numCals = fc.readNumEntry("NumberCalendars",0 );
+    mNextAvailableCalendar = 1;
+    if ( numCals == 0 ) {
+        KopiCalendarFile *kkf = getNewCalendar();
+        kkf->isStandard = true;
+        kkf->mName = i18n("Standard");
+        kkf->mFileName = locateLocal( "data", "korganizer/mycalendar.ics" );
+    } 
+    while ( mNextAvailableCalendar  <= numCals ) {
+        //qDebug("Read cal #%d ",  mNextAvailableCalendar );
+        QString prefix = "Cal_" +QString::number( mNextAvailableCalendar );
+        KopiCalendarFile *kkf = getNewCalendar();
+        kkf->isStandard = fc.readBoolEntry( prefix+"_isStandard", false );
+        kkf->isEnabled = fc.readBoolEntry( prefix+"_isEnabled", true);
+        kkf->isRelative = fc.readBoolEntry( prefix+"_isRelative", false );
+        kkf->isAlarmEnabled = fc.readBoolEntry( prefix+"_isAlarmEnabled", true);
+        kkf->isReadOnly = fc.readBoolEntry( prefix+"_isReadOnly", false);
+        kkf->mName =  fc.readEntry( prefix+"_Name", "Calendar");
+        kkf->mFileName = fc.readEntry( prefix+"_FileName", kkf->mFileName);
+        kkf->mSavedFileName = fc.readEntry( prefix+"_SavedFileName", kkf->mFileName);
+        kkf->mDefaultColor = fc.readColorEntry( prefix+"_Color",&mEventColor);
+        if ( kkf->mCalNumber == 1 ) {
+            kkf->mFileName = locateLocal( "data", "korganizer/mycalendar.ics" );
+        }
+        //qDebug("NAME %s %s", kkf->mName.latin1(), i18n("Birthdays").latin1() );
+        if ( kkf->mName == i18n("Birthdays") ) {
+            kkf->mFileName = locateLocal( "data", "korganizer/birthdays.ics" ); 
+        }
+        if ( kkf->isRelative )
+            kkf->mFileName = KGlobalSettings::calendarDir() + kkf->mSavedFileName;
+    }
+
     KPimPrefs::usrReadConfig();
 }
 
+KopiCalendarFile * KOPrefs::getCalendar( int num )
+{
+    return mDefCalColors[num-1];
+}
 
+KopiCalendarFile * KOPrefs::getNewCalendar()
+{
+    KopiCalendarFile * kkf = new KopiCalendarFile();
+    kkf->mCalNumber = mNextAvailableCalendar;
+    mDefCalColors.resize( mNextAvailableCalendar );
+    mDefCalColors[mNextAvailableCalendar-1] = kkf;
+    ++mNextAvailableCalendar;
+    kkf->mDefaultColor = mEventColor;
+    kkf->mName = i18n("New Calendar");
+    mCalendars.append( kkf );
+    return kkf;
+}
+void  KOPrefs::deleteCalendar( int num )
+{
+    KopiCalendarFile * kkf = mCalendars.first();
+    while ( kkf ) {
+        if ( kkf->mCalNumber == num ) {
+            qDebug("KOPrefs::deleteCalendar %d ", num );
+            mCalendars.remove( kkf );
+            delete kkf;
+            return;
+        }
+        kkf = mCalendars.next();
+    }
+}
+int KOPrefs::getCalendarID( const QString & name )
+{
+    KopiCalendarFile * kkf = mCalendars.first();
+    while ( kkf ) {
+        if ( name == kkf->mName)
+            return  kkf->mCalNumber;
+        kkf = mCalendars.next();
+    }
+    return 1;
+}
+QString KOPrefs::calName( int calNum) const
+{
+    return (mDefCalColors[calNum-1])->mName;
+}
+QColor  KOPrefs::defaultColor( int calNum ) const
+{
+    if ( calNum == 1 ) return mEventColor;
+    return (mDefCalColors[calNum-1])->mDefaultColor;
+}
 void KOPrefs::usrWriteConfig()
 {
   config()->setGroup("General");
@@ -454,9 +541,37 @@ void KOPrefs::usrWriteConfig()
   while (it.current()) {
     config()->writeEntry(it.currentKey(),*(it.current()));
     ++it;
-  }
-
-
+  } 
+  KConfig fc (locateLocal("config","kopicalendarrc")); 
+  fc.setGroup("CC");
+  fc.deleteGroup( "CC");
+  fc.setGroup("CC");
+  fc.writeEntry("NumberCalendars",mCalendars.count());
+    int numCal = 1;
+    int writeCal = 0;
+    while ( numCal < mNextAvailableCalendar  ) {
+        KopiCalendarFile * kkf = mCalendars.first();
+        while ( kkf ) {
+            //qDebug("cal num %d %d ", kkf->mCalNumber, numCal);
+            if ( kkf->mCalNumber == numCal ) {
+                ++writeCal;
+                //qDebug("Write calendar %d %d ", numCal , writeCal);
+                QString prefix = "Cal_" + QString::number( writeCal );
+                fc.writeEntry( prefix+"_isStandard", kkf->isStandard );
+                fc.writeEntry( prefix+"_isEnabled", kkf->isEnabled );
+                fc.writeEntry( prefix+"_isAlarmEnabled", kkf->isAlarmEnabled );
+                fc.writeEntry( prefix+"_isReadOnly", kkf->isReadOnly );
+                fc.writeEntry( prefix+"_isRelative", kkf->isRelative );
+                fc.writeEntry( prefix+"_Name", kkf->mName);
+                fc.writeEntry( prefix+"_FileName", kkf->mFileName);
+                fc.writeEntry( prefix+"_SavedFileName", kkf->mSavedFileName);
+                fc.writeEntry( prefix+"_Color",kkf->mDefaultColor);
+            }
+            kkf = mCalendars.next();
+        }
+        ++numCal;
+    }
+    fc.sync();
   KPimPrefs::usrWriteConfig();
 }
 
