@@ -86,8 +86,7 @@ KOPrefsDialog::KOPrefsDialog(QWidget *parent, char *name, bool modal) :
   if ( QApplication::desktop()->height() == 480  )
       hideButtons();
 #endif
-
-  setupGlobalTab();
+ 
   setupMainTab();
   // setupLocaleTab();
   //setupTimeZoneTab();
@@ -101,7 +100,7 @@ KOPrefsDialog::KOPrefsDialog(QWidget *parent, char *name, bool modal) :
   //setupPrinterTab();
   //setupGroupSchedulingTab();
   //setupGroupAutomationTab();
-
+  
 
 }
 
@@ -111,11 +110,7 @@ KOPrefsDialog::~KOPrefsDialog()
 }
 void KOPrefsDialog::setupGlobalTab() 
 {
-   QFrame *topFrame = addPage(i18n("Global"),0,0);
-   kdelibcfg = new KDEPIMConfigWidget(  KPimGlobalPrefs::instance(), topFrame, "KCMKdeLibConfig" );
-   QVBoxLayout *topLayout = new QVBoxLayout(topFrame);
-   topLayout->addWidget( kdelibcfg );
-
+   
 
 } 
 void KOPrefsDialog::setupLocaleDateTab()
@@ -238,103 +233,6 @@ void  KOPrefsDialog::setupLocaleTab()
 #endif
 #endif
 }
-void KOPrefsDialog::showSyncPage()
-{
-    showPage ( 0 ) ;
-    kdelibcfg->showTimeZoneTab() ;
-
-}
-void KOPrefsDialog::setupSyncAlgTab()
-{
-#if 0
-  QLabel * lab;
-   QFrame *topFrame = addPage(i18n("Sync Prefs"),0,0);
-   mSetupSyncAlgTab = topFrame;
-   QGridLayout *topLayout = new QGridLayout(topFrame,6,2);
-   topLayout->setSpacing(mSpacingHint);
-   topLayout->setMargin(mMarginHint);  
-   int iii = 0;  
-   
-   KPrefsDialogWidBool *sb =
-       addWidBool(i18n("Ask for preferences before syncing"),
-                  &(KOPrefs::instance()->mAskForPreferences),topFrame);
-   topLayout->addMultiCellWidget(sb->checkBox(), iii,iii,0,1);
-
-   ++iii;
-
-   KPrefsDialogWidRadios *syncPrefsGroup =
-      addWidRadios(i18n("Sync preferences:"),&(KOPrefs::instance()->mSyncAlgoPrefs),
-                   topFrame);
-   syncPrefsGroup->addRadio(i18n("Take local entry on conflict"));
-   syncPrefsGroup->addRadio(i18n("Take remote entry on conflict"));
-   syncPrefsGroup->addRadio(i18n("Take newest entry on conflict"));
-   syncPrefsGroup->addRadio(i18n("Ask for every entry on conflict"));
-   syncPrefsGroup->addRadio(i18n("Force take local entry always"));
-   syncPrefsGroup->addRadio(i18n("Force take remote entry always"));
-   topLayout->addMultiCellWidget( syncPrefsGroup->groupBox(),iii,iii,0,1);
-   ++iii;   
-  sb =
-       addWidBool(i18n("Show summary after syncing"),
-                  &(KOPrefs::instance()->mShowSyncSummary),topFrame);
-   topLayout->addMultiCellWidget(sb->checkBox(), iii,iii,0,1);
-
-   ++iii;
-#endif
-
-
-
-}
-
-
-void KOPrefsDialog::setupSyncTab()
-{
-#if 0
-    QLabel * lab;
-   QFrame *topFrame = addPage(i18n("Sync Network"),0,0);
-   QGridLayout *topLayout = new QGridLayout(topFrame,6,2);
-   topLayout->setSpacing(mSpacingHint);
-   topLayout->setMargin(mMarginHint);
-   lab = new QLabel(i18n("Remote syncing (via ssh/scp)\nnetwork settings "), topFrame);
-   int iii = 0;
-   topLayout->addMultiCellWidget(lab , iii,iii,0,1);
-   ++iii;
-
-   mRemoteIPEdit = new QLineEdit(topFrame);
-   lab = new QLabel(mRemoteIPEdit, i18n("Remote IP:"), topFrame);
-   topLayout->addWidget(lab ,iii,0);
-   topLayout->addWidget(mRemoteIPEdit,iii,1);
-   ++iii;
-   mRemoteUser = new QLineEdit(topFrame);
-   lab = new QLabel(mRemoteUser, i18n("Remote user:"), topFrame);
-   topLayout->addWidget(lab ,iii,0);
-   topLayout->addWidget(mRemoteUser, iii,1); 
-   ++iii;
-
-   mRemoteFile = new QLineEdit(topFrame);
-   lab = new QLabel(mRemoteFile, i18n("Remote file:"), topFrame);
-   topLayout->addWidget(lab ,iii,0);
-   topLayout->addWidget(mRemoteFile,iii,1);
-   ++iii;
- 
-   mLocalTempFile = new QLineEdit(topFrame);
-   lab = new QLabel(mLocalTempFile, i18n("Local temp file:"), topFrame);
-   topLayout->addWidget(lab ,iii,0);
-   topLayout->addWidget(mLocalTempFile,iii,1);
-   ++iii;
- 
-   KPrefsDialogWidBool *wb =
-       addWidBool(i18n("Write back synced file"),
-                  &(KOPrefs::instance()->mWriteBackFile),topFrame);
-   topLayout->addMultiCellWidget(wb->checkBox(), iii,iii,0,1);
-   ++iii;
-   wb =
-       addWidBool(i18n("Write back existing entries only"),
-                  &(KOPrefs::instance()->mWriteBackExistingOnly),topFrame);
-   topLayout->addMultiCellWidget(wb->checkBox(), iii,iii,0,1);
-   ++iii;
- 
-#endif
-}
 
 void KOPrefsDialog::setupMainTab()
 {
@@ -376,7 +274,7 @@ void KOPrefsDialog::setupMainTab()
 
 
  KPrefsDialogWidBool *verticalScreen =
-      addWidBool(i18n("Show vertical screen (Needs restart)"),
+      addWidBool(i18n("Vertical screen layout(Needs restart)"),
                  &(KOPrefs::instance()->mVerticalScreen),topFrame);
   //topLayout->addWidget(verticalScreen->checkBox(),ii++,0);
   topLayout->addMultiCellWidget(verticalScreen->checkBox(),4,4,0,1);
@@ -387,6 +285,13 @@ void KOPrefsDialog::setupMainTab()
              &(KOPrefs::instance()->mBlockPopupMenu),topFrame);
   topLayout->addMultiCellWidget(  widbool->checkBox(), iii,iii,0,1); 
   ++iii;
+  if (  QApplication::desktop()->height() <= 240 ) {
+      topFrame = addPage(i18n("General") +" 2",0,0);
+      topLayout = new QGridLayout(topFrame,4,2);
+      topLayout->setSpacing(2);
+      topLayout->setMargin(3);
+      iii = 0;
+  }
   QHBox *dummy = new QHBox(topFrame);
   new QLabel(i18n("Days in Next-X-Days:"),dummy);
   mNextXDaysSpin = new QSpinBox(2,14,1,dummy);
@@ -533,12 +438,19 @@ void KOPrefsDialog::setupTimeTab()
   mAlarmTimeCombo = new QComboBox(topFrame);
   mAlarmTimeCombo->insertStringList(alarmList);
   topLayout->addWidget(mAlarmTimeCombo,3,1);
-
+  int iii = 4;
+  if (  QApplication::desktop()->height() <= 240 ) {
+      topFrame = addPage(i18n("Time") +" 2",0,0);
+      topLayout = new QGridLayout(topFrame,1,2);
+      topLayout->setSpacing(2);
+      topLayout->setMargin(3);
+      iii = 0;
+  }
 
   QGroupBox *workingHoursGroup = new QGroupBox(1,Horizontal,
                                                i18n("Working Hours"),
                                                topFrame);
-  topLayout->addMultiCellWidget(workingHoursGroup,4,4,0,1);
+  topLayout->addMultiCellWidget(workingHoursGroup,iii,iii,0,1);
   workingHoursGroup->layout()->setSpacing( 0 );
   workingHoursGroup->layout()->setMargin( 4 );
   QHBox *workStartBox = new QHBox(workingHoursGroup);
@@ -790,6 +702,10 @@ void KOPrefsDialog::setupViewsTab()
     addWidBool(i18n("Week view mode uses bigger font"),
                &(KOPrefs::instance()->mMonthViewUsesBigFont),topFrame);
   topLayout->addWidget(dummy->checkBox(),ii++,0);
+  dummy =
+    addWidBool(i18n("Week view mode uses row layout"),
+               &(KOPrefs::instance()->mMonthViewWeekRowlayout),topFrame);
+  topLayout->addWidget(dummy->checkBox(),ii++,0);
   dummy =
     addWidBool(i18n("Show Sat/Sun together"),
                &(KOPrefs::instance()->mMonthViewSatSunTog),topFrame);
@@ -804,6 +720,18 @@ void KOPrefsDialog::setupViewsTab()
     addWidBool(i18n("Category colors are applied to text"),
                &(KOPrefs::instance()->mMonthViewUsesForegroundColor),topFrame);
   topLayout->addWidget(dummy->checkBox(),ii++,0);
+
+
+
+  if (  QApplication::desktop()->height() <= 240 ) {
+      topFrame = addPage(i18n("Month View") +" 2",0,0);
+      topLayout = new QGridLayout(topFrame,4,1);
+      topLayout->setSpacing(2);
+      topLayout->setMargin(1);
+      ii = 0;
+  }
+
+
  coloredCategoriesInMonthView =
        addWidBool(i18n("Month view uses day colors"),
                   &(KOPrefs::instance()->mMonthViewUsesDayColors),topFrame);
@@ -851,9 +779,13 @@ void KOPrefsDialog::setupViewsTab()
   mPrioSpin = new QSpinBox(0,5,1,prioBox);
   if ( QApplication::desktop()->width() <  300 )
       mPrioSpin->setFixedWidth( 40 );
-
   KPrefsDialogWidBool *passwdk =
 
+      addWidBool(i18n("Show times on two lines"),
+                 &(KOPrefs::instance()->mWhatsNextTime2Lines),topFrame);
+  topLayout->addWidget(passwdk->checkBox(), ii++,0);
+  passwdk =
+
       addWidBool(i18n("Show events that are done"),
                  &(KOPrefs::instance()->mWNViewShowsPast),topFrame);
   topLayout->addWidget(passwdk->checkBox(), ii++,0);
@@ -1003,9 +935,13 @@ dummy =
     addWidBool(i18n("Use internal alarm notification"),
                &(KOPrefs::instance()->mUseInternalAlarmNotification),topFrame);
   topLayout->addWidget(dummy->checkBox(),iii++,0);
-  lab = new QLabel( i18n("Note: KO/Pi must be running to notify you about an alarm. Recommended for use on Zaurus: Disable this option and install KO/Pi alarm applet.\n"), topFrame);
 
-   topLayout->addWidget(lab ,iii++,0);
+  if (  QApplication::desktop()->height() > 240 ) {
+      
+      lab = new QLabel( i18n("Note: KO/Pi must be running to notify you about an alarm. Recommended for use on Zaurus: Disable this option and install KO/Pi alarm applet.\n"), topFrame);
+      
+      topLayout->addWidget(lab ,iii++,0);
+  }
 #ifndef DESKTOP_VERSION
     lab->setAlignment( AlignLeft|WordBreak|AlignTop);
 #else
@@ -1266,6 +1202,18 @@ void KOPrefsDialog::setupColorsTab()
   topLayout->addWidget(eventColor->label(),ii,0);
   topLayout->addWidget(eventColor->button(),ii++,1);
 
+  if (  QApplication::desktop()->height() <= 240 ) {
+      topFrame = addPage(i18n("Colors") +" 2",0,0);
+      //  DesktopIcon("colorize",KIcon::SizeMedium));
+      
+      topLayout = new QGridLayout(topFrame,5,2);
+      // topLayout->setSpacing(mSpacingHint);
+      // topLayout->setMargin(mMarginHint);
+      
+      topLayout->setSpacing(2);
+      topLayout->setMargin(3);
+  }
+  
 
   // agenda view background color
   KPrefsDialogWidColor *agendaBgColor =
@@ -1458,22 +1406,15 @@ void KOPrefsDialog::setCombo(QComboBox *combo, const QString & text,
 
 void KOPrefsDialog::usrReadConfig()
 {
-  kdelibcfg->readConfig();
+  
   mNameEdit->setText(KOPrefs::instance()->fullName());
   mEmailEdit->setText(KOPrefs::instance()->email());
 
   mAutoSaveIntervalSpin->setValue(KOPrefs::instance()->mAutoSaveInterval);
-  // QDate current ( 2001, 1,1);
-  //mStartDateSavingEdit->setDate(current.addDays(KOPrefs::instance()->mDaylightsavingStart-1));
-  //mEndDateSavingEdit->setDate(current.addDays(KOPrefs::instance()->mDaylightsavingEnd-1));
-  //setCombo(mTimeZoneCombo,i18n(KOPrefs::instance()->mTimeZoneId));
-  //mTimezoneOffsetSpin->setValue( KOPrefs::instance()->mTimeZoneOffset);
+ 
   mStartTimeSpin->setValue(KOPrefs::instance()->mStartTime);
   mDefaultDurationSpin->setValue(KOPrefs::instance()->mDefaultDuration);
   mAlarmTimeCombo->setCurrentItem(KOPrefs::instance()->mAlarmTime);
-  // if  (KOPrefs::instance()->mAllDaySize > 47  )
-  //   KOPrefs::instance()->mAllDaySize = KOPrefs::instance()->mAllDaySize/2;
-  //mHourSizeSlider->setValue(KOPrefs::instance()->mAllDaySize);
 
   mNextXDaysSpin->setValue(KOPrefs::instance()->mNextXDays);
   mWhatsNextSpin->setValue(KOPrefs::instance()->mWhatsNextDays);
@@ -1486,64 +1427,36 @@ void KOPrefsDialog::usrReadConfig()
 //     mAMails->insertItem(item);
 //   }
 
-  // mRemoteIPEdit->setText(KOPrefs::instance()->mRemoteIP);
-  //mRemoteUser->setText(KOPrefs::instance()->mRemoteUser);
-  //mRemotePassWd->setText(KOPrefs::instance()->mRemotePassWd);
-  //mRemoteFile->setText(KOPrefs::instance()->mRemoteFile);
-
   //that soundmLocalTempFile->setText(KOPrefs::instance()->mLocalTempFile);
   mDefaultAlarmFile->setText(KOPrefs::instance()->mDefaultAlarmFile);
-  //QString dummy = KOPrefs::instance()->mUserDateFormatLong;
-  //mUserDateFormatLong->setText(dummy.replace( QRegExp("K"), QString(",") ));
-  //dummy = KOPrefs::instance()->mUserDateFormatShort;
-  //mUserDateFormatShort->setText(dummy.replace( QRegExp("K"), QString(",") ));
   updateCategories();
   mAlarmPlayBeeps->setValue(KOPrefs::instance()->mAlarmPlayBeeps );
   mAlarmSuspendTime->setValue(KOPrefs::instance()->mAlarmSuspendTime );
   mAlarmSuspendCount->setValue(KOPrefs::instance()->mAlarmSuspendCount );
   mAlarmBeepInterval->setValue(KOPrefs::instance()->mAlarmBeepInterval );
+  mCatDefaultColor = KOPrefs::instance()->mEventColor;
 }
 
 
 void KOPrefsDialog::usrWriteConfig()
 {
-
-  kdelibcfg->writeConfig();
-    // KOPrefs::instance()->mRemoteIP = mRemoteIPEdit->text();
-    //KOPrefs::instance()->mRemoteUser =  mRemoteUser->text();
-    //KOPrefs::instance()->mRemotePassWd = mRemotePassWd->text();
-    //KOPrefs::instance()->mRemoteFile= mRemoteFile->text();
-    //KOPrefs::instance()->mLocalTempFile =mLocalTempFile->text();
     KOPrefs::instance()->mDefaultAlarmFile =mDefaultAlarmFile->text();
-
-    //KOPrefs::instance()->mUserDateFormatShort = mUserDateFormatShort->text().replace( QRegExp(","), QString("K") );
-    //KOPrefs::instance()->mUserDateFormatLong = mUserDateFormatLong->text().replace( QRegExp(","), QString("K") );
     KOPrefs::instance()->setFullName(mNameEdit->text());
     KOPrefs::instance()->setEmail(mEmailEdit->text());
     
     KOPrefs::instance()->mAutoSaveInterval = mAutoSaveIntervalSpin->value();
-    
-    // KOPrefs::instance()->mTimeZoneId = mTimeZoneCombo->currentText();
-    //QDate date;
-    //date = mStartDateSavingEdit->date();
-    //int sub = 0;
-    //if ( QDate::leapYear( date.year() ) && date.dayOfYear() > 59 )
-    //     sub = 1;
-//     KOPrefs::instance()->mDaylightsavingStart = date.dayOfYear()-sub;
-//     date = mEndDateSavingEdit->date();
-//     if ( QDate::leapYear( date.year() ) && date.dayOfYear() > 59  )
-//         sub = 1;
-//     else 
-//         sub = 0;
-//     KOPrefs::instance()->mDaylightsavingEnd = date.dayOfYear()-sub;
-//     // KOPrefs::instance()->mTimeZoneOffset = mTimezoneOffsetSpin->value();
-    
     KOPrefs::instance()->mStartTime = mStartTimeSpin->value();
     KOPrefs::instance()->mDefaultDuration = mDefaultDurationSpin->value();
     KOPrefs::instance()->mAlarmTime = mAlarmTimeCombo->currentItem();
-    
-    //KOPrefs::instance()->mAllDaySize = mHourSizeSlider->value();
-    
+    if ( mCatDefaultColor != KOPrefs::instance()->mEventColor ) {
+        QStringList cat = KOPrefs::instance()->mCustomCategories;
+        int iii = 0;
+        while ( iii < cat.count() ) {
+            if ( *KOPrefs::instance()->categoryColor( cat[ iii ] ) == mCatDefaultColor )
+                KOPrefs::instance()->setCategoryColor( cat[ iii ], KOPrefs::instance()->mEventColor );
+            ++iii;
+        }
+    }
     QDictIterator<QColor> it(mCategoryDict);
     while (it.current()) {
         KOPrefs::instance()->setCategoryColor(it.currentKey(),*it.current());
@@ -1562,11 +1475,10 @@ void KOPrefsDialog::usrWriteConfig()
     //     KOPrefs::instance()->mAdditionalMails.append( item->text(0) );
     //     item = item->nextSibling();
     //   }
-  KOPrefs::instance()->mAlarmPlayBeeps  = mAlarmPlayBeeps->value();
-  KOPrefs::instance()->mAlarmSuspendTime = mAlarmSuspendTime->value() ;
-  KOPrefs::instance()->mAlarmSuspendCount= mAlarmSuspendCount->value() ;
-  KOPrefs::instance()->mAlarmBeepInterval= mAlarmBeepInterval->value() ;
-    
+    KOPrefs::instance()->mAlarmPlayBeeps  = mAlarmPlayBeeps->value();
+    KOPrefs::instance()->mAlarmSuspendTime = mAlarmSuspendTime->value() ;
+    KOPrefs::instance()->mAlarmSuspendCount= mAlarmSuspendCount->value() ;
+    KOPrefs::instance()->mAlarmBeepInterval= mAlarmBeepInterval->value() ;
 }
 
 void KOPrefsDialog::updateCategories()
@@ -1577,29 +1489,6 @@ void KOPrefsDialog::updateCategories()
   updateCategoryColor();
 }
 
-void KOPrefsDialog::warningGroupScheduling()
-{
-  warningExperimental(mEnableGroupScheduling->checkBox()->isChecked());
-}
-
-void KOPrefsDialog::warningProjectView()
-{
-  warningExperimental(mEnableProjectView->checkBox()->isChecked());
-}
-
-void KOPrefsDialog::warningExperimental(bool on)
-{
-  if (on) {
-    KMessageBox::information(this,i18n("This is an experimental feature. "
-        "It may not work, it may do nothing useful and it may cause data loss. "
-        "Use with care.\n"
-        "You have to restart KOrganizer for this setting to take effect."));
-  } else {
-    KMessageBox::information(this,
-        i18n("You have to restart KOrganizer for this setting to take effect."));
-  }
-}
-
 void KOPrefsDialog::toggleEmailSettings(bool on)
 {
   if (on) {
@@ -1660,90 +1549,4 @@ void KOPrefsDialog::updateInput()
 //   aEmailsEdit->setEnabled(true);
 //   aEmailsEdit->setText(item->text(0));
 }
-void KOPrefsDialog::updateTimezoneOffset( int index )
-{
-    /*
-    qDebug("updateTimezoneOffset %d ", index);
-    if ( index < 24 ) {
-        mTimezoneOffsetSpin->setEnabled ( false );
-        mTimezoneOffsetSpin->setValue( ( index-11 ) * 60 );
-
-
-    } else { 
-        if  ( index ==  24 ) {
-            mTimezoneOffsetSpin->setEnabled ( true );
-            mTimezoneOffsetSpin->setValue( KOPrefs::instance()->mTimeZoneOffset);
-            
-        } else {
-            mTimezoneOffsetSpin->setEnabled ( false );
-            mTimezoneOffsetSpin->setValue( 0 );
-        }
-    }
-    */
-}
-
-void KOPrefsDialog::setupTimeZoneTab()
-{
-#if 0
-    QFrame *topFrame = addPage(i18n("Time Zone"),0,0);
-    // DesktopIcon("clock",KIcon::SizeMedium));
-
-  QGridLayout *topLayout = new QGridLayout(topFrame,5,2);
-  topLayout->setSpacing(mSpacingHint);
-  topLayout->setMargin(mMarginHint);
-
-  QHBox *timeZoneBox = new QHBox( topFrame );
-  topLayout->addMultiCellWidget( timeZoneBox, 0, 0, 0, 1 );
-
-  new QLabel( i18n("Timezone:"), timeZoneBox );
-  mTimeZoneCombo = new QComboBox( timeZoneBox ); 
-  if ( QApplication::desktop()->width() <  300 ) {
-       mTimeZoneCombo->setMaximumWidth(150);
-    }
-
-  QStringList list;
-  list = KGlobal::locale()->timeZoneList();
-  mTimeZoneCombo->insertStringList(list);
-
-    // find the currently set time zone and select it
-  QString sCurrentlySet = KOPrefs::instance()->mTimeZoneId;
-  int nCurrentlySet = 11;
-  for (int i = 0; i < mTimeZoneCombo->count(); i++)
-    {
-      if (mTimeZoneCombo->text(i) == sCurrentlySet)
-        {
-         nCurrentlySet = i;
-         break;
-        }
-    }
-  mTimeZoneCombo->setCurrentItem(nCurrentlySet);
-  int iii = 1;
-  KPrefsDialogWidBool *sb =
-      addWidBool(i18n("Timezone has daylight saving"),
-                 &(KOPrefs::instance()->mUseDaylightsaving),topFrame);
-  topLayout->addMultiCellWidget(sb->checkBox(), iii,iii,0,1);
-  ++iii;  
-  QLabel* lab = new QLabel(  i18n("Actual start and end is the\nsunday before this date."), topFrame );
-  topLayout->addMultiCellWidget(lab, iii,iii,0,1);
-  ++iii;   
-  lab = new QLabel(  i18n("The year in the date is ignored."), topFrame );
-  topLayout->addMultiCellWidget(lab, iii,iii,0,1);
-  ++iii; 
-  lab = new QLabel(  i18n("Daylight start:"), topFrame );
-  topLayout->addWidget(lab, iii,0);
-  mStartDateSavingEdit = new KDateEdit(topFrame);
-  topLayout->addWidget(mStartDateSavingEdit, iii,1);
-  ++iii;
-
-  lab = new QLabel(  i18n("Daylight end:"), topFrame );
-  topLayout->addWidget(lab, iii,0);
-  mEndDateSavingEdit = new KDateEdit(topFrame);
-  topLayout->addWidget(mEndDateSavingEdit, iii,1);
-  ++iii;
-  QDate current ( 2001, 1,1);
-  mStartDateSavingEdit->setDate(current.addDays(KOPrefs::instance()->mDaylightsavingStart-1));
-  mEndDateSavingEdit->setDate(current.addDays(KOPrefs::instance()->mDaylightsavingEnd-1));
-#endif
- 
-}
 
