@@ -25,6 +25,9 @@
 #include <qheader.h>
 #include <qcursor.h>
 #include <qwhatsthis.h>
+#include <qdialog.h>
+#include <qlabel.h>
+#include <qpushbutton.h>
 
 #include <qinputdialog.h>
 
@@ -33,6 +36,8 @@
 #include "koprefs.h"
 #include <klocale.h>
 #include <kglobal.h>
+#include <kdateedit.h>
+#include "ktimeedit.h"
 #include <kiconloader.h>
 #include <kmessagebox.h>
 
@@ -58,6 +63,107 @@
 using namespace KOrg;
 
 
+KOStartTodoPrefs::KOStartTodoPrefs( QString sum, QWidget *parent, const char *name ) :
+    QDialog( parent, name, true ) 
+{
+    mStopAll = true;
+    setCaption( i18n("Start todo") );
+    QVBoxLayout* lay = new QVBoxLayout( this );
+    lay->setSpacing( 3 );
+    lay->setMargin( 3 );
+    QLabel * lab = new QLabel( i18n("<b>%1\n</b>").arg( sum ), this );
+    lay->addWidget( lab ); 
+    lab->setAlignment( AlignCenter );
+
+    QPushButton * ok = new QPushButton( i18n("Start this todo\nand stop all running"), this );
+    lay->addWidget( ok );
+    ok->setDefault( true );
+    QPushButton * start = new QPushButton( i18n("Start todo"), this );
+    lay->addWidget( start );
+    QPushButton * cancel = new QPushButton( i18n("Cancel - do not start"), this );
+    lay->addWidget( cancel );
+    connect ( ok,SIGNAL(clicked() ),this , SLOT ( accept() )  );
+    connect ( start,SIGNAL(clicked() ),this , SLOT ( doStop() )  );
+    connect (cancel, SIGNAL(clicked() ), this, SLOT ( reject())  );
+    resize( sizeHint() );
+        
+}
+void KOStartTodoPrefs::doStop()
+{
+    mStopAll = false;
+    accept();
+}      
+KOStopTodoPrefs::KOStopTodoPrefs( Todo* todo, QWidget *parent, const char *name ) :
+    QDialog( parent, name, true ) 
+{
+    mTodo = todo;
+    setCaption( i18n("Stop todo") );
+    QVBoxLayout* lay = new QVBoxLayout( this );
+    lay->setSpacing( 3 );
+    lay->setMargin( 3 );
+    QLabel * lab = new QLabel( i18n("<b>%1\n</b>").arg( todo->summary() ), this );
+    lay->addWidget( lab ); 
+    lab->setAlignment( AlignHCenter );
+    lab = new QLabel( i18n("Additional Comment:"), this );
+    lay->addWidget( lab ); 
+    mComment = new QLineEdit( this );
+    lay->addWidget( mComment );
+    QHBox * start = new QHBox ( this );
+    lay->addWidget( start ); 
+    lab = new QLabel( i18n("Start:"), start );
+    QHBox * end = new QHBox ( this );
+    lay->addWidget( end ); 
+    lab = new QLabel( i18n("End:"), end );
+    sde = new KDateEdit( start );
+    ste = new KOTimeEdit( start );
+    connect ( sde,SIGNAL(setTimeTo( QTime ) ),ste , SLOT ( setTime(QTime  ) )  );
+    ede = new KDateEdit( end );
+    ete = new KOTimeEdit(end );
+    connect ( ede,SIGNAL(setTimeTo( QTime ) ),ete , SLOT ( setTime(QTime  ) )  );
+    sde->setDate( mTodo->runStart().date() );
+    ste->setTime( mTodo->runStart().time() );
+    ede->setDate( QDate::currentDate());
+    ete->setTime( QTime::currentTime() );
+    QPushButton * ok = new QPushButton( i18n("Stop and save"), this );
+    lay->addWidget( ok );
+    ok->setDefault( true );
+    QPushButton * cancel = new QPushButton( i18n("Continue running"), this );
+    lay->addWidget( cancel );
+    connect ( ok,SIGNAL(clicked() ),this , SLOT ( accept() )  );
+    connect (cancel, SIGNAL(clicked() ), this, SLOT ( reject())  );
+    ok = new QPushButton( i18n("Stop - do not save"), this );
+    connect ( ok,SIGNAL(clicked() ),this , SLOT ( doNotSave() )  );
+    lay->addWidget( ok );
+    if (QApplication::desktop()->width() < 320 )
+        resize( 240, sizeHint().height() );
+    else
+        resize( 320, sizeHint().height() );
+        
+}
+       
+void KOStopTodoPrefs::accept()
+{
+    QDateTime start = QDateTime( sde->date(), ste->getTime() );
+    QDateTime stop = QDateTime( ede->date(), ete->getTime() );
+    if ( start > stop ) {
+        KMessageBox::sorry(this,
+                           i18n("The start time is\nafter the end time!"),
+                           i18n("Time mismatch!"));
+        return;
+    }
+    mTodo->saveRunningInfo( mComment->text(), start, stop );
+    QDialog::accept();
+}
+void KOStopTodoPrefs::doNotSave() 
+{
+    int result = KMessageBox::warningContinueCancel(this,
+                                                    i18n("Do you really want to set\nthe state to stopped\nwithout saving the data?"),mTodo->summary(),i18n("Yes, stop todo") );
+    if (result != KMessageBox::Continue) return;
+    mTodo->stopRunning();
+    QDialog::accept();
+}
+
+
 class KOTodoViewWhatsThis :public QWhatsThis
 {
 public:
@@ -296,6 +402,10 @@ void KOTodoListView::keyReleaseEvent ( QKeyEvent *e )
 void KOTodoListView::keyPressEvent ( QKeyEvent * e )
 {
     qApp->processEvents();
+    if ( !isVisible() ) {
+        e->ignore();
+        return;
+    }
     if ( e->isAutoRepeat() && !mFlagKeyPressed ) {
         e->ignore();
         // qDebug("  ignore  %d",e->isAutoRepeat()  );
@@ -322,6 +432,7 @@ void KOTodoListView::keyPressEvent ( QKeyEvent * e )
             }
         }
         
+        e->accept();
         return;
     }
    
@@ -330,6 +441,7 @@ void KOTodoListView::keyPressEvent ( QKeyEvent * e )
         case Qt::Key_Down:
         case Qt::Key_Up:
             QListView::keyPressEvent (  e );
+            e->accept();
             break; 
         case Qt::Key_Left:
         case Qt::Key_Right:
@@ -370,19 +482,19 @@ void KOTodoListView::contentsMouseDoubleClickEvent(QMouseEvent *e)
 KOQuickTodo::KOQuickTodo(QWidget *parent) :
   QLineEdit(parent)
 {
-  setText(i18n("Click to add a new Todo"));
+  setText(i18n("Click to add new Todo"));
 }
 
 void KOQuickTodo::focusInEvent(QFocusEvent *ev)
 {
-  if ( text()==i18n("Click to add a new Todo") )
+  if ( text()==i18n("Click to add new Todo") )
     setText("");
   QLineEdit::focusInEvent(ev);
 }
 
 void KOQuickTodo::focusOutEvent(QFocusEvent *ev)
 {
-  setText(i18n("Click to add a new Todo"));
+  setText(i18n("Click to add new Todo"));
   QLineEdit::focusOutEvent(ev);
 }
 
@@ -391,16 +503,63 @@ void KOQuickTodo::focusOutEvent(QFocusEvent *ev)
 KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   KOrg::BaseView(calendar,parent,name)
 {
+    mCategoryPopupMenu = 0;
     mPendingUpdateBeforeRepaint = false;
     isFlatDisplay = false;
   mNavigator = 0;
   QBoxLayout *topLayout = new QVBoxLayout(this);
   mName = QString ( name );
   mBlockUpdate = false;
-  mQuickAdd = new KOQuickTodo(this);
-  topLayout->addWidget(mQuickAdd);
+  mQuickBar = new QWidget( this );
+  topLayout->addWidget(mQuickBar);
+  
+  mQuickAdd = new KOQuickTodo(mQuickBar); 
+  QBoxLayout *quickLayout = new QHBoxLayout(mQuickBar);
+  quickLayout->addWidget( mQuickAdd );
+  mNewSubBut =  new QPushButton( "sub",mQuickBar );
+  QPushButton * s_done = new QPushButton( "D",mQuickBar );
+  QPushButton * s_run = new QPushButton( "R",mQuickBar );
+  QPushButton * allopen = new QPushButton( "O",mQuickBar );
+  QPushButton * allclose = new QPushButton( "C",mQuickBar );
+  QPushButton * flat = new QPushButton( "F",mQuickBar );
 
-  if ( !KOPrefs::instance()->mEnableQuickTodo ) mQuickAdd->hide();
+  int fixwid = mQuickAdd->sizeHint().height();
+  int fixhei = fixwid;
+  if ( QApplication::desktop()->width() > 800 )
+      fixwid = (fixwid*3)/2;
+  connect ( flat, SIGNAL ( clicked()), SLOT ( setAllFlat()));
+  connect ( allopen, SIGNAL ( clicked()), SLOT ( setAllOpen()));
+  connect ( allclose, SIGNAL ( clicked()), SLOT ( setAllClose()));
+  s_done->setPixmap( SmallIcon("greenhook16"));
+  connect ( s_done, SIGNAL ( clicked()), SLOT ( toggleCompleted()));
+  s_run->setPixmap( SmallIcon("ko16old"));
+  connect ( s_run, SIGNAL ( clicked()), SLOT ( toggleRunning()));
+
+  connect ( mNewSubBut, SIGNAL ( clicked()), SLOT ( newSubTodo()));
+
+  mNewSubBut->setFixedWidth(mNewSubBut->sizeHint().width() );
+  mNewSubBut->setEnabled( false );
+  flat->setFixedWidth( fixwid );
+  s_done->setFixedWidth( fixwid );
+  allopen->setFixedWidth( fixwid );
+  allclose->setFixedWidth( fixwid );
+  s_run->setFixedWidth( fixwid );
+
+  flat->setFixedHeight(fixhei );
+  s_done->setFixedHeight(fixhei );
+  allopen->setFixedHeight(fixhei );
+  allclose->setFixedHeight(fixhei );
+  s_run->setFixedHeight(fixhei );
+  mNewSubBut->setFixedHeight(fixhei );
+  
+  quickLayout->addWidget( mNewSubBut );
+  quickLayout->addWidget( s_done );
+  quickLayout->addWidget( s_run );
+  quickLayout->addWidget( allopen );
+  quickLayout->addWidget( allclose );
+  quickLayout->addWidget( flat );
+
+  if ( !KOPrefs::instance()->mEnableQuickTodo ) mQuickBar->hide();
 
   mTodoListView = new KOTodoListView(calendar,this, name );
   topLayout->addWidget(mTodoListView);
@@ -426,8 +585,12 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   mTodoListView->addColumn(i18n("Start Time"));
   mTodoListView->setColumnAlignment(6,AlignHCenter);
 
-  mTodoListView->addColumn(i18n("Cancelled"));
+  //mTodoListView->addColumn(i18n("Cancelled"));
   mTodoListView->addColumn(i18n("Categories"));
+  mTodoListView->addColumn(i18n("Calendar"));
+  mTodoListView->addColumn(i18n("Last Modified"));
+  mTodoListView->addColumn(i18n("Created"));
+  mTodoListView->addColumn(i18n("Last Modified Sub"));
 #if 0
   mTodoListView->addColumn(i18n("Sort Id"));
   mTodoListView->setColumnAlignment(4,AlignHCenter);
@@ -437,16 +600,10 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   mTodoListView->setItemsRenameable( true );
   mTodoListView->setRenameable( 0 );
   mTodoListView->setColumnWidth( 0, 120 );
-  mTodoListView->setColumnWidthMode(0, QListView::Manual);
-  mTodoListView->setColumnWidthMode(1, QListView::Manual);
-  mTodoListView->setColumnWidthMode(2, QListView::Manual);
-  mTodoListView->setColumnWidthMode(3, QListView::Manual);
-  mTodoListView->setColumnWidthMode(4, QListView::Manual);
-  mTodoListView->setColumnWidthMode(5, QListView::Manual);
-  mTodoListView->setColumnWidthMode(6, QListView::Manual);
-  mTodoListView->setColumnWidthMode(7, QListView::Manual);
-  mTodoListView->setColumnWidthMode(8, QListView::Manual);
- 
+  int iii = 0;
+  for ( iii = 0; iii< 12 ; ++iii )
+      mTodoListView->setColumnWidthMode( iii, QListView::Manual );
+
 
   mKOTodoViewWhatsThis = new KOTodoViewWhatsThis(mTodoListView->viewport(),this);
 
@@ -465,13 +622,25 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   connect (mPercentageCompletedPopupMenu, SIGNAL (activated (int)), SLOT (setNewPercentage (int)));
 
 
+  mCategoryPopupMenu = new QPopupMenu (this);
+  mCategoryPopupMenu->setCheckable (true);
+  connect (mCategoryPopupMenu, SIGNAL (activated (int)), SLOT (changedCategories (int)));
+  connect (mCategoryPopupMenu, SIGNAL (aboutToShow ()), SLOT (fillCategories ()));
+
+  mCalPopupMenu = new QPopupMenu (this);
+  mCalPopupMenu->setCheckable (true);
+  connect (mCalPopupMenu, SIGNAL (activated (int)), SLOT (changedCal (int)));
+  connect (mCalPopupMenu, SIGNAL (aboutToShow ()), SLOT (fillCal ()));
+
+
+
   
   mItemPopupMenu = new QPopupMenu(this); 
-  mItemPopupMenu->insertItem(i18n("Show..."), this,
+  mItemPopupMenu->insertItem(i18n("Show"), this,
                              SLOT (showTodo()));
   mItemPopupMenu->insertItem(i18n("Edit..."), this,
                              SLOT (editTodo()));
-  mItemPopupMenu->insertItem( i18n("Delete"), this,
+  mItemPopupMenu->insertItem( i18n("Delete..."), this,
                              SLOT (deleteTodo()));
   mItemPopupMenu->insertItem( i18n("Clone..."), this,
                              SLOT (cloneTodo()));
@@ -483,6 +652,8 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
 #endif
   mItemPopupMenu->insertItem( i18n("Toggle Cancel"), this,
                              SLOT (cancelTodo()));
+  mItemPopupMenu->insertItem( i18n("Categories"), mCategoryPopupMenu);
+  mItemPopupMenu->insertItem( i18n("Calendar"), mCalPopupMenu);
   mItemPopupMenu->insertSeparator();
   mItemPopupMenu->insertItem( i18n("Start/Stop todo..."), this,
                              SLOT (toggleRunningItem()));
@@ -499,7 +670,7 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
                              SLOT (reparentTodo()),0,22);
   mItemPopupMenu->insertSeparator();
 #if 0
-  mItemPopupMenu->insertItem(i18n("Delete completed To-Dos","Purge Completed"),
+  mItemPopupMenu->insertItem(i18n("Delete completed To-Dos","Purge Completed..."),
                              this, SLOT( purgeCompleted() ) );
   mItemPopupMenu->insertItem(i18n("toggle completed To-Dos","Show Completed"),
                              this, SLOT( toggleCompleted() ),0, 33 );
@@ -512,7 +683,7 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   mPopupMenu = new QPopupMenu(this);
   mPopupMenu->insertItem(SmallIconSet("todo"), i18n("New Todo..."), this,
                          SLOT (newTodo()),0,1);
-  mPopupMenu->insertItem(i18n("delete completed To-Dos","Purge Completed"),
+  mPopupMenu->insertItem(i18n("delete completed To-Dos","Purge Completed..."),
                          this, SLOT(purgeCompleted()),0,2);
   mPopupMenu->insertItem(i18n("Show Completed"),
                              this, SLOT( toggleCompleted() ),0,3 );
@@ -646,13 +817,12 @@ void KOTodoView::updateView()
        mPendingUpdateBeforeRepaint = true;
        return;
     }
-    storeCurrentItem();
     //qDebug("KOTodoView::updateView() %x", this);
     if ( isFlatDisplay ) {
         displayAllFlat();
-        resetCurrentItem();
         return;
     }
+    storeCurrentItem();
     //qDebug("update ");
 //  kdDebug() << "KOTodoView::updateView()" << endl;
     QFont fo = KOPrefs::instance()->mTodoViewFont;
@@ -701,10 +871,10 @@ void KOTodoView::updateView()
       bool next = true;
       // qDebug("todo %s ", todo->summary().latin1());
       Incidence *incidence = todo->relatedTo();
-      while  ( incidence ) {
-          if ( incidence->type() == "Todo") {
+      while  ( incidence  ) {
+          if ( incidence->typeID() == todoID ) {
               //qDebug("related %s ",incidence->summary().latin1() );
-              if ( !(todoList.contains ( ((Todo* )incidence ) ) )) {
+              if ( !(todoList.contains ( ((Todo* )incidence ) ) )  && incidence->calEnabled() ) {
                   //qDebug("related not found ");
                   todoList.remove( );
                   todo = todoList.current();
@@ -733,7 +903,6 @@ void KOTodoView::updateView()
   if( mDocPrefs ) restoreItemState( mTodoListView->firstChild() );
   mTodoListView->blockSignals( false );
   resetCurrentItem();
-  processSelectionChange();
 }
 
 void KOTodoView::storeCurrentItem()
@@ -758,7 +927,7 @@ void KOTodoView::storeCurrentItem()
 
 void KOTodoView::resetCurrentItem()
 {
-    mTodoListView->setFocus();
+    //mTodoListView->setFocus();
     KOTodoViewItem* foundItem = 0; 
     KOTodoViewItem* foundItemRoot = 0; 
     KOTodoViewItem* foundItemParent = 0; 
@@ -794,12 +963,22 @@ void KOTodoView::resetCurrentItem()
             }  
         } 
         if ( foundItem ) {
+            mTodoListView->setSelected (  foundItem, true  ); 
             mTodoListView->setCurrentItem( foundItem ); 
             mTodoListView->ensureItemVisible(  foundItem );
-        } else {
-            mTodoListView->setCurrentItem( mTodoListView->firstChild () );
+        } else { 
+            if ( mTodoListView->firstChild () ) {
+                mTodoListView->setSelected ( mTodoListView->firstChild (), true  ); 
+                mTodoListView->setCurrentItem( mTodoListView->firstChild () );
+            }
         }
     }
+    processSelectionChange(); 
+    QTimer::singleShot( 100, this, SLOT ( resetFocusToList() ));
+}
+void KOTodoView::resetFocusToList()
+{
+    topLevelWidget()->setActiveWindow();
     mTodoListView->setFocus();
 }
 //Incidence * mCurItem, *mCurItemRootParent,*mCurItemAbove; 
@@ -836,34 +1015,36 @@ void KOTodoView::restoreItemState( QListViewItem *item )
 
 
 QMap<Todo *,KOTodoViewItem *>::ConstIterator
-  KOTodoView::insertTodoItem(Todo *todo)
+KOTodoView::insertTodoItem(Todo *todo)
 {
 
-//  kdDebug() << "KOTodoView::insertTodoItem(): " << todo->getSummary() << endl;
-  // TODO: Check, if dynmaic cast is necessary
+    //  kdDebug() << "KOTodoView::insertTodoItem(): " << todo->getSummary() << endl;
+    // TODO: Check, if dynmaic cast is necessary
 
     pendingSubtodo = 0;
-  Incidence *incidence = todo->relatedTo();
-  if (incidence && incidence->type() == "Todo") {
-    Todo *relatedTodo = static_cast<Todo *>(incidence);
+    Incidence *incidence = todo->relatedTo();
+    while ( incidence && !incidence->calEnabled() )
+        incidence = incidence->relatedTo();
+    if (incidence && incidence->typeID() == todoID ) {
+        Todo *relatedTodo = static_cast<Todo *>(incidence);
 
-//    kdDebug() << "  has Related" << endl;
-    QMap<Todo *,KOTodoViewItem *>::ConstIterator itemIterator;
-    itemIterator = mTodoMap.find(relatedTodo);
-    if (itemIterator == mTodoMap.end()) {
-//      kdDebug() << "    related not yet in list" << endl;
-      itemIterator = insertTodoItem (relatedTodo);
+        //    kdDebug() << "  has Related" << endl;
+        QMap<Todo *,KOTodoViewItem *>::ConstIterator itemIterator;
+        itemIterator = mTodoMap.find(relatedTodo);
+        if (itemIterator == mTodoMap.end()) {
+            //      kdDebug() << "    related not yet in list" << endl;
+            itemIterator = insertTodoItem (relatedTodo);
+        }
+        // isn't this pretty stupid? We give one Todo  to the KOTodoViewItem
+        // and one into the map. Sure finding is more easy but why? -zecke
+        KOTodoViewItem *todoItem = new KOTodoViewItem(*itemIterator,todo,this);
+        return mTodoMap.insert(todo,todoItem);
+    } else {
+        //    kdDebug() << "  no Related" << endl;
+        // see above -zecke
+        KOTodoViewItem *todoItem = new KOTodoViewItem(mTodoListView,todo,this);
+        return mTodoMap.insert(todo,todoItem);
     }
-    // isn't this pretty stupid? We give one Todo  to the KOTodoViewItem
-    // and one into the map. Sure finding is more easy but why? -zecke
-    KOTodoViewItem *todoItem = new KOTodoViewItem(*itemIterator,todo,this);
-    return mTodoMap.insert(todo,todoItem);
-  } else {
-//    kdDebug() << "  no Related" << endl;
-      // see above -zecke
-    KOTodoViewItem *todoItem = new KOTodoViewItem(mTodoListView,todo,this);
-    return mTodoMap.insert(todo,todoItem);
-  }
 }
 
 
@@ -940,8 +1121,10 @@ void KOTodoView::popupMenu(QListViewItem *item,const QPoint &p,int column)
     case 3:
          moveTodo();
         break;
+    case 7:
+      mCategoryPopupMenu->popup(QCursor::pos ()); break;
     case 8:
-      getCategoryPopupMenu((KOTodoViewItem *)item)->popup(QCursor::pos ()); break;
+      mCalPopupMenu->popup(QCursor::pos ()); break;
     default:
             mItemPopupMenu->popup(QCursor::pos());
     }
@@ -954,8 +1137,12 @@ void KOTodoView::newTodo()
 
 void KOTodoView::newSubTodo()
 {
+    mActiveItem = (KOTodoViewItem*)mTodoListView->currentItem();
   if (mActiveItem) {
-    emit newSubTodoSignal(mActiveItem->todo());
+      if ( mQuickAdd->isVisible() && !mQuickAdd->text().isEmpty() && mQuickAdd->text() != i18n("Click to add new Todo") ) {
+          addQuickTodoPar( mActiveItem->todo());
+      } else
+          emit newSubTodoSignal(mActiveItem->todo());
   }
 }
 void KOTodoView::unparentTodo()
@@ -1026,6 +1213,7 @@ void KOTodoView::setNewPriority(int index)
    todoModified (mActiveItem->todo(), KOGlobals::PRIORITY_MODIFIED);
    mActiveItem->todo()->setRevision( mActiveItem->todo()->revision()+1  );
   }
+  processSelectionChange();
 }
 
 void KOTodoView::setNewPercentage(int index)
@@ -1034,6 +1222,7 @@ void KOTodoView::setNewPercentage(int index)
 
         if ( mPercentage[index] == 100 && !mActiveItem->isOn() ) {
             mActiveItem->setOn( true );
+            processSelectionChange();
             return;
         } else   if ( mPercentage[index] != 100 && mActiveItem->isOn() ) {
             KOTodoViewItem* par = (static_cast<KOTodoViewItem*>(mActiveItem->parent()));
@@ -1050,27 +1239,41 @@ void KOTodoView::setNewPercentage(int index)
         todoModified (mActiveItem->todo (), KOGlobals::COMPLETION_MODIFIED);
         mActiveItem->todo()->setRevision( mActiveItem->todo()->revision()+1  );
     }
+  processSelectionChange();
 }
 
-
-QPopupMenu * KOTodoView::getCategoryPopupMenu (KOTodoViewItem *todoItem)
+void KOTodoView::fillCategories ()
 {
-  QPopupMenu* tempMenu = new QPopupMenu (this);
-  QStringList checkedCategories = todoItem->todo()->categories ();
-
-  tempMenu->setCheckable (true);
-  for (QStringList::Iterator it = KOPrefs::instance()->mCustomCategories.begin ();
-       it != KOPrefs::instance()->mCustomCategories.end ();
-       ++it) {
-    int index = tempMenu->insertItem (*it);
-    mCategory[index] = *it;
-    if (checkedCategories.find (*it) != checkedCategories.end ()) tempMenu->setItemChecked (index, true);
-  }
-
-  connect (tempMenu, SIGNAL (activated (int)), SLOT (changedCategories (int)));
-  return tempMenu;
-
-
+    mCategoryPopupMenu->clear();
+    if ( ! mActiveItem ) return;
+    QStringList checkedCategories = mActiveItem->todo()->categories ();
+    for (QStringList::Iterator it = KOPrefs::instance()->mCustomCategories.begin ();
+         it != KOPrefs::instance()->mCustomCategories.end ();
+         ++it) {
+        int index = mCategoryPopupMenu->insertItem (*it);
+        mCategory[index] = *it;
+        if (checkedCategories.find (*it) != checkedCategories.end ()) mCategoryPopupMenu->setItemChecked (index, true);
+    }
+}
+void KOTodoView::fillCal ()
+{
+    mCalPopupMenu->clear();
+    if (!mActiveItem) return;
+    bool readO = mActiveItem->todo()->isReadOnly();
+    KopiCalendarFile * kkf = KOPrefs::instance()->mCalendars.first();
+    while ( kkf ) {
+        int index = mCalPopupMenu->insertItem( kkf->mName, kkf->mCalNumber);
+        if ( kkf->mErrorOnLoad || kkf->isReadOnly || readO )
+            mCalPopupMenu->setItemEnabled( index, false );
+        mCalPopupMenu->setItemChecked (index, kkf->mCalNumber == mActiveItem->todo()->calID());
+        kkf = KOPrefs::instance()->mCalendars.next();
+    }
+}
+void KOTodoView::changedCal (int index )
+{
+    if (!mActiveItem) return;
+    mActiveItem->todo()->setCalID( index );
+    mActiveItem->construct();
 }
 void KOTodoView::changedCategories(int index)
 {
@@ -1107,15 +1310,30 @@ void KOTodoView::itemDoubleClicked(QListViewItem *item)
         newTodo();
         return;
     } else {
-        if ( row == 2 || row == 1 ) {
+        if ( row == 1 ) {
             mActiveItem = (KOTodoViewItem *) item;
             newSubTodo();
             return;
         }
-        if ( row == 5 || row == 6 ) {
+        if ( row == 5 || row == 6 || row == 2) {
             mActiveItem = (KOTodoViewItem *) item;
-            toggleRunningItem();
-            return;
+            Todo * t = mActiveItem->todo();
+            if ( t->isRunning() ) {
+                if (  t->runTime()  < 15) {
+                    t->stopRunning();
+                    mActiveItem->construct();
+                    topLevelWidget()->setCaption(i18n("Todo stopped - no data saved because runtime was < 15 sec!"));
+                    return;
+                }
+                else
+                    toggleRunningItem();
+                return;
+            } else {
+                    t->setRunning( true );
+                    mActiveItem->construct();
+                    topLevelWidget()->setCaption(i18n("Todo started! Double click again to stop!"));
+                return;
+            }
         }
     }
     if ( KOPrefs::instance()->mEditOnDoubleClick )
@@ -1130,27 +1348,34 @@ void KOTodoView::toggleRunningItem()
         return;
     Todo * t = mActiveItem->todo();
     if ( t->isRunning() ) {
-#if 0
-        int result = KMessageBox::warningContinueCancel(this,
-                                                        i18n("The todo\n%1\nis started.\nDo you want to set\nthe state to stopped?").arg(mActiveItem->text(0).left( 25 ) ),i18n("Todo is started"),i18n("Stop todo"),i18n("Cancel"), true);
-#endif
-
-        int result = KMessageBox::warningYesNoCancel(this,
-                                                        i18n("The todo\n%1\nis started.\nDo you want to set\nthe state to stopped?").arg(mActiveItem->text(0).left( 25 ) ),i18n("Todo is started"),i18n("Stop"),i18n("Stop+note"));
-        if (result == KMessageBox::Cancel) return;
-        if ( result == KMessageBox::No ) {
-            QString comment = QInputDialog::getText(mActiveItem->text(0).left( 25 ),i18n("Comment for todo:") );
-            t->setRunningFalse( comment );
-        } else {
-            t->setRunning( false );
+        KOStopTodoPrefs tp ( t, this );
+        if (QApplication::desktop()->width() <= 800 ){
+            int wid = tp.width();
+            int hei = tp.height();
+            int xx = (QApplication::desktop()->width()-wid)/2;
+            int yy = (QApplication::desktop()->height()-hei)/2;
+            tp.setGeometry( xx,yy,wid,hei );
         }
+        tp.exec();
         mActiveItem->construct();
     } else {
-        int result = KMessageBox::warningContinueCancel(this,
-                                                        i18n("The todo\n%1\nis stopped.\nDo you want to set\nthe state to started?").arg(mActiveItem->text(0).left( 25 ) ),i18n("Todo is stopped"),i18n("Start todo"),i18n("Cancel"), true);
-        if (result != KMessageBox::Continue) return;
-        t->setRunning( true );
-        mActiveItem->construct();
+        KOStartTodoPrefs tp ( t->summary(), this );
+        if (QApplication::desktop()->width() <= 800 ){
+            int wid = tp.width();
+            int hei = tp.height();
+            int xx = (QApplication::desktop()->width()-wid)/2;
+            int yy = (QApplication::desktop()->height()-hei)/2;
+            tp.setGeometry( xx,yy,wid,hei );
+        }
+        if ( !tp.exec() ) return;
+        if ( tp.stopAll() ) {
+            mCalendar->stopAllTodos();
+            t->setRunning( true );
+            updateView();
+        } else {
+            t->setRunning( true );
+            mActiveItem->construct();
+        }
     }
 }
 
@@ -1225,8 +1450,10 @@ void KOTodoView::processSelectionChange()
 
   if ( !item ) {
     emit incidenceSelected( 0 );
+    mNewSubBut->setEnabled( false );
   } else {
     emit incidenceSelected( item->todo() );
+    mNewSubBut->setEnabled( true );
   }
 }
 
@@ -1278,6 +1505,7 @@ void  KOTodoView::setOpen( QListViewItem* item, bool setOpenI)
 
 void KOTodoView::displayAllFlat()
 {
+    storeCurrentItem();
     pendingSubtodo = 0;
     if ( mBlockUpdate ) {
         return;
@@ -1289,11 +1517,12 @@ void KOTodoView::displayAllFlat()
     mTodoListView->clear();
     Todo *todo;   
     for(todo = todoList.first(); todo; todo = todoList.next()) {
-        KOTodoViewItem *todoItem = new KOTodoViewItem(mTodoListView,todo,this);
-        mTodoMap.insert(todo,todoItem);
+        if ( checkTodo( todo ) ) {
+            KOTodoViewItem *todoItem = new KOTodoViewItem(mTodoListView,todo,this);
+            mTodoMap.insert(todo,todoItem);
+        }
     }
-    mTodoListView->setFocus();
-    processSelectionChange();
+    resetCurrentItem();
 }
 
 void  KOTodoView::setAllFlat()
@@ -1304,9 +1533,7 @@ void  KOTodoView::setAllFlat()
         updateView();
         return;
     } 
-    storeCurrentItem();
     displayAllFlat();
-    resetCurrentItem();
 }
 
 void KOTodoView::purgeCompleted()
@@ -1316,12 +1543,12 @@ void KOTodoView::purgeCompleted()
 }
 void KOTodoView::toggleQuickTodo()
 {
-    if ( mQuickAdd->isVisible() ) {
-        mQuickAdd->hide();
+    if ( mQuickBar->isVisible() ) {
+        mQuickBar->hide();
         KOPrefs::instance()->mEnableQuickTodo = false;
     }
     else {
-        mQuickAdd->show();
+        mQuickBar->show();
         KOPrefs::instance()->mEnableQuickTodo = true;
     }
     mPopupMenu->setItemChecked(4,KOPrefs::instance()->mEnableQuickTodo);
@@ -1334,6 +1561,10 @@ void KOTodoView::toggleRunning()
     mPopupMenu->setItemChecked(5,KOPrefs::instance()->mHideNonStartedTodos);
     mItemPopupMenu->setItemChecked( 35 , KOPrefs::instance()->mHideNonStartedTodos );
     updateView();
+    if ( KOPrefs::instance()->mHideNonStartedTodos )
+        topLevelWidget()->setCaption(i18n("Hide not Running"));
+    else
+        topLevelWidget()->setCaption(i18n("Show not Running"));
 }
 
 void KOTodoView::toggleCompleted()
@@ -1342,39 +1573,67 @@ void KOTodoView::toggleCompleted()
     mPopupMenu->setItemChecked( 3,KOPrefs::instance()->mShowCompletedTodo  );
     mItemPopupMenu->setItemChecked( 33 , KOPrefs::instance()->mShowCompletedTodo   );
     updateView();
+    if ( KOPrefs::instance()->mShowCompletedTodo )
+        topLevelWidget()->setCaption(i18n("Show Completed"));
+    else
+        topLevelWidget()->setCaption(i18n("Hide Completed"));
 }
 
 void KOTodoView::addQuickTodo()
 {
-  Todo *todo = new Todo();
-  todo->setSummary(mQuickAdd->text());
-  todo->setOrganizer(KOPrefs::instance()->email());
-  CalFilter * cf = mCalendar->filter();
-  if ( cf ) {
-      if ( cf->isEnabled()&& cf->showCategories()) {
-          todo->setCategories(cf->categoryList());
-      }
-      if ( cf->isEnabled() )
-          todo->setSecrecy( cf->getSecrecy());
-  }
-  mCalendar->addTodo(todo);
-  mQuickAdd->setText("");
-  todoModified (todo,  KOGlobals::EVENTADDED );
-  updateView();
+    addQuickTodoPar( 0 );
 }
+void KOTodoView::addQuickTodoPar( Todo * parentTodo)
+{
+    Todo *todo = new Todo();
+    todo->setSummary(mQuickAdd->text());
+    todo->setOrganizer(KOPrefs::instance()->email());
+    if ( parentTodo ) {
+        todo->setRelatedTo(parentTodo);
 
+        todo->setCategories (parentTodo->categoriesStr ());
+        todo->setSecrecy (parentTodo->secrecy ());
+        if ( parentTodo->priority() < 3 )
+            todo->setPriority( parentTodo->priority() );
+        todo->setCalID( parentTodo->calID() );
+    } else {
+        CalFilter * cf = mCalendar->filter();
+        if ( cf ) {
+            if ( cf->isEnabled()&& cf->showCategories()) {
+                todo->setCategories(cf->categoryList());
+            }
+            if ( cf->isEnabled() )
+                todo->setSecrecy( cf->getSecrecy());
+        }
+    }
+    mCalendar->addTodo(todo);
+    mQuickAdd->setText("");
+    todoModified (todo,  KOGlobals::EVENTADDED );
+    updateView();
+
+}
 void KOTodoView::keyPressEvent ( QKeyEvent * e )
 {  
     //    e->ignore();
     //return;
-    //qDebug("KOTodoView::keyPressEvent  ");
+    if ( !isVisible() ) {
+        e->ignore();
+        return;
+    }
     switch ( e->key() ) {
     case Qt::Key_Down:
     case Qt::Key_Up:
-        QWidget::keyPressEvent (  e );
+        // KOrg::BaseView::keyPressEvent (  e );
+        e->ignore();
         break; 
    
     case Qt::Key_Q:
+
+
+        if ( e->state() == Qt::ControlButton || e->state() == Qt::ShiftButton ) {
+            e->ignore();
+            break; 
+        }
         toggleQuickTodo();
         break; 
     case Qt::Key_U:
