@@ -65,9 +65,171 @@ void CalendarLocal::init()
 
 CalendarLocal::~CalendarLocal()
 {
-  close();
+    registerObserver( 0 );
+    if ( mDeleteIncidencesOnClose )
+        close();
+}
+bool CalendarLocal::mergeCalendarFile( QString name )
+{
+    CalendarLocal calendar( timeZoneId() );
+    calendar.setDefaultCalendar( 1 );
+    if ( calendar.load( name ) ) {
+        mergeCalendar( &calendar  );
+        return true;
+    }
+    return false;
+}
+ 
+Incidence* CalendarLocal::incidenceForUid( const QString& uid , bool doNotCheckDuplicates) 
+{
+    Todo *todo;;
+    Incidence *retVal = 0;
+    for ( todo = mTodoList.first(); todo; todo = mTodoList.next() ) {
+        if ( todo->uid() == uid ) {
+            if ( doNotCheckDuplicates ) return todo;
+            if ( retVal ) {
+                if ( retVal->calID() > todo->calID() ) {
+                    retVal = todo;
+                }
+            } else {
+                retVal = todo;
+            }
+        } 
+    }
+    if ( retVal ) return retVal;
+    Event *event;
+    for ( event = mEventList.first(); event; event = mEventList.next() ) {
+        if (  event->uid() == uid ) {
+            if ( doNotCheckDuplicates ) return event;
+            if ( retVal ) {
+                if ( retVal->calID() > event->calID() ) {
+                    retVal = event;
+                }
+            } else {
+                retVal = event;
+            }
+        }
+    }
+    if ( retVal ) return retVal;
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->uid() == uid ) {
+            if ( doNotCheckDuplicates ) return it;
+            if ( retVal ) {
+                if ( retVal->calID() > it->calID() ) {
+                    retVal = it;
+                }
+            } else {
+                retVal = it;
+            }
+        }
+    return retVal;
 }
 
+bool CalendarLocal::mergeCalendar( Calendar* remote  )
+{
+    // 1 look for raw inc in local
+    //   if inc not in remote, delete in local
+    // 2 look for raw inc in remote
+    //   if inc in local, replace it
+    //   if not in local, add it to default calendar
+    QPtrList<Incidence> localInc = rawIncidences(); 
+    Incidence* inL = localInc.first(); 
+    while ( inL ) {
+        if ( ! inL->isReadOnly () )
+            if ( !remote->incidenceForUid( inL->uid(), true ))
+                deleteIncidence( inL );
+        inL = localInc.next();
+    }
+    QPtrList<Incidence> er = remote->rawIncidences(); 
+    Incidence* inR = er.first();
+    while ( inR ) {
+        inL = incidenceForUid( inR->uid(),false );
+        if ( inL ) {
+            if ( ! inL->isReadOnly () || inL->uid().left(15) == QString("last-syncEvent-") ) {
+                int calID = inL->calID();
+                deleteIncidence( inL );
+                inL = inR->clone();
+                inL->setCalID( calID );
+                addIncidence( inL );
+            }
+        } else {
+            inL = inR->clone();
+            inL->setCalID( 0 );// add to default cal
+            addIncidence( inL );
+        }
+        inR = er.next();
+    }
+    return true;
+}
+
+
+bool CalendarLocal::addCalendarFile( QString name, int id )
+{
+    CalendarLocal calendar( timeZoneId() );
+    calendar.setDefaultCalendar( id );
+    if ( calendar.load( name ) ) {
+        addCalendar( &calendar  );
+        return true;
+    }
+    return false;
+}
+void CalendarLocal::setSyncEventsReadOnly()
+{
+    Event * ev;
+    ev = mEventList.first();
+    while ( ev ) {
+        if ( ev->uid().left(15) == QString("last-syncEvent-") )
+            ev->setReadOnly( true );
+        ev =  mEventList.next();
+    } 
+}
+void CalendarLocal::addCalendar( Calendar* cal )
+{
+    cal->setDontDeleteIncidencesOnClose();
+    {
+        QPtrList<Event> EventList = cal->rawEvents();
+        Event * ev = EventList.first();
+        while ( ev ) {
+            ev->unRegisterObserver( cal );
+            ev->registerObserver( this );
+            mEventList.append( ev );
+            ev = EventList.next();
+        }
+    }
+    {
+
+        QPtrList<Todo> TodoList = cal->rawTodos();
+        Todo * ev = TodoList.first();
+        while ( ev ) {
+            QString rel = ev->relatedToUid();
+            if ( !rel.isEmpty() ){
+                ev->setRelatedTo ( 0 );
+                ev->setRelatedToUid( rel );
+            }
+            ev = TodoList.next();
+        }
+        //TodoList = cal->rawTodos();
+        ev = TodoList.first();
+        while ( ev ) {
+            ev->unRegisterObserver( cal );
+            ev->registerObserver( this );
+            mTodoList.append( ev );
+            setupRelations( ev );
+            ev = TodoList.next();
+        }
+    }
+    {
+        QPtrList<Journal> JournalList = cal->journals();
+        Journal * ev = JournalList.first();
+        while ( ev ) {
+            ev->unRegisterObserver( cal );
+            ev->registerObserver( this );
+            mJournalList.append( ev );
+            ev = JournalList.next();
+        }
+    }
+    setModified( true );
+}
 bool CalendarLocal::load( const QString &fileName )
 {
   FileStorage storage( this, fileName );
@@ -80,6 +242,12 @@ bool CalendarLocal::save( const QString &fileName, CalFormat *format )
   return storage.save();
 }
 
+void CalendarLocal::stopAllTodos()
+{
+    for ( Todo *it = mTodoList.first(); it; it = mTodoList.next() )
+        it->setRunning( false );
+
+}
 void CalendarLocal::close()
 {
 
@@ -150,6 +318,9 @@ bool CalendarLocal::addEvent( Event *event )
   event->registerObserver( this );
 
   setModified( true );
+  if ( event->calID() == 0 )
+      event->setCalID( mDefaultCalendar );
+  event->setCalEnabled( true );
 
   return true;
 }
@@ -166,16 +337,20 @@ void CalendarLocal::deleteEvent( Event *event )
 
 Event *CalendarLocal::event( const QString &uid )
 {
-
-  Event *event;
-
-  for ( event = mEventList.first(); event; event = mEventList.next() ) {
-    if ( event->uid() == uid ) {
-      return event;
+    Event *event;
+    Event *retVal = 0;
+    for ( event = mEventList.first(); event; event = mEventList.next() ) {
+        if ( event->calEnabled() && event->uid() == uid ) {
+            if ( retVal ) {
+                if ( retVal->calID() > event->calID() ) {
+                    retVal = event;
+                }
+            } else {
+                retVal = event;
+            }
+        }
     }
-  }
-
-  return 0;
+  return retVal;
 }
 bool CalendarLocal::addTodoNoDup( Todo *todo )
 {
@@ -198,7 +373,9 @@ bool CalendarLocal::addTodo( Todo *todo )
   setupRelations( todo );
 
   setModified( true );
-
+  if ( todo->calID() == 0 )
+  todo->setCalID( mDefaultCalendar );
+  todo->setCalEnabled( true );
   return true;
 }
 
@@ -216,13 +393,16 @@ void CalendarLocal::deleteTodo( Todo *todo )
 
 QPtrList<Todo> CalendarLocal::rawTodos()
 {
-  return mTodoList;
+    QPtrList<Todo> el;
+    for ( Todo *it = mTodoList.first(); it; it = mTodoList.next() )
+        if ( it->calEnabled() ) el.append( it );
+    return el;
 }
 Todo *CalendarLocal::todo( QString syncProf, QString id )
 {
   Todo *todo;
   for ( todo = mTodoList.first(); todo; todo = mTodoList.next() ) {
-      if ( todo->getID( syncProf ) == id ) return todo;
+      if ( todo->calEnabled() && todo->getID( syncProf ) == id ) return todo;
   }
 
   return 0;
@@ -267,19 +447,27 @@ Event *CalendarLocal::event( QString syncProf,  QString id )
 {
   Event *todo;
   for ( todo = mEventList.first(); todo; todo = mEventList.next() ) {
-      if ( todo->getID( syncProf ) == id ) return todo;
+      if ( todo->calEnabled() && todo->getID( syncProf ) == id ) return todo;
   }
 
   return 0;
 }
 Todo *CalendarLocal::todo( const QString &uid )
 {
-  Todo *todo;
+  Todo *todo;;
+  Todo *retVal = 0;
   for ( todo = mTodoList.first(); todo; todo = mTodoList.next() ) {
-    if ( todo->uid() == uid ) return todo;
+      if ( todo->calEnabled() && todo->uid() == uid ) {
+          if ( retVal ) {
+                if ( retVal->calID() > todo->calID() ) {
+                    retVal = todo;
+                }
+            } else {
+                retVal = todo;
+            }
+      } 
   }
-
-  return 0;
+  return retVal;
 }
 QString CalendarLocal::nextSummary() const
 {
@@ -389,6 +577,7 @@ QPtrList<Todo> CalendarLocal::todos( const QDate &date )
 
   Todo *todo;
   for ( todo = mTodoList.first(); todo; todo = mTodoList.next() ) {
+      if ( !todo->calEnabled() ) continue; 
     if ( todo->hasDueDate() && todo->dtDue().date() == date ) {
       todos.append( todo );
     }
@@ -421,6 +610,7 @@ QDateTime  CalendarLocal::nextAlarm( int daysTo )
     int offset;
     mNextAlarmIncidence = 0;
     for( e = mEventList.first(); e; e = mEventList.next() ) {
+        if ( !e->calEnabled() ) continue;
         next = e->getNextAlarmDateTime(& ok, &offset, QDateTime::currentDateTime() ) ;
         if ( ok ) {
             if (  next < nextA ) {
@@ -434,6 +624,7 @@ QDateTime  CalendarLocal::nextAlarm( int daysTo )
     }
     Todo *t;
     for( t = mTodoList.first(); t; t = mTodoList.next() ) {
+      if ( !t->calEnabled() ) continue; 
         next = t->getNextAlarmDateTime(& ok, &offset, QDateTime::currentDateTime() ) ;
         if ( ok ) {
             if (  next < nextA ) {
@@ -458,21 +649,21 @@ Alarm::List CalendarLocal::alarmsTo( const QDateTime &to )
 
 Alarm::List CalendarLocal::alarms( const QDateTime &from, const QDateTime &to )
 {
-  kdDebug(5800) << "CalendarLocal::alarms(" << from.toString() << " - "
-                << to.toString() << ")\n";
-
+ 
   Alarm::List alarms;
 
   Event *e;
 
   for( e = mEventList.first(); e; e = mEventList.next() ) {
+      if ( !e->calEnabled() ) continue;
     if ( e->doesRecur() ) appendRecurringAlarms( alarms, e, from, to );
     else appendAlarms( alarms, e, from, to );
   }
 
   Todo *t;
   for( t = mTodoList.first(); t; t = mTodoList.next() ) {
-    appendAlarms( alarms, t, from, to );
+      if ( !t->calEnabled() ) continue; 
+      appendAlarms( alarms, t, from, to );
   }
 
   return alarms;
@@ -488,8 +679,6 @@ void CalendarLocal::appendAlarms( Alarm::List &alarms, Incidence *incidence,
 //                  << "': " << alarm->time().toString() << " - " << alarm->enabled() << endl;
     if ( alarm->enabled() ) {
       if ( alarm->time() >= from && alarm->time() <= to ) {
-        kdDebug(5800) << "CalendarLocal::appendAlarms() '" << incidence->summary()
-                      << "': " << alarm->time().toString() << endl;
         alarms.append( alarm );
       }
     }
@@ -547,6 +736,7 @@ QPtrList<Event> CalendarLocal::rawEventsForDate( const QDate &qd, bool sorted )
 
   Event *event;
   for( event = mEventList.first(); event; event = mEventList.next() ) {
+      if ( !event->calEnabled() ) continue;
     if ( event->doesRecur() ) {
       if ( event->isMultiDay() ) {
         int extraDays = event->dtStart().date().daysTo( event->dtEnd().date() );
@@ -599,6 +789,7 @@ QPtrList<Event> CalendarLocal::rawEvents( const QDate &start, const QDate &end,
 
   // Get non-recurring events
   for( event = mEventList.first(); event; event = mEventList.next() ) {
+      if ( !event->calEnabled() ) continue;
     if ( event->doesRecur() ) {
       QDate rStart = event->dtStart().date();
       bool found = false;
@@ -657,7 +848,7 @@ QPtrList<Event> CalendarLocal::rawEvents( const QDate &start, const QDate &end,
           eventList.append( event );
         }
       } else {
-        if ( ( s >= start && s <= end ) || ( e >= start && e <= end ) ) {
+        if ( ( e >= start && s <= end ) ) {
           eventList.append( event );
         }
       }
@@ -674,22 +865,22 @@ QPtrList<Event> CalendarLocal::rawEventsForDate( const QDateTime &qdt )
 
 QPtrList<Event> CalendarLocal::rawEvents()
 {
-  return mEventList;
+    QPtrList<Event> el;
+    for ( Event *it = mEventList.first(); it; it = mEventList.next() )
+        if ( it->calEnabled() ) el.append( it );
+    return el;
 }
 
 bool CalendarLocal::addJournal(Journal *journal)
 {
-  if ( journal->dtStart().isValid())
-    kdDebug(5800) << "Adding Journal on " << journal->dtStart().toString() << endl;
-  else
-    kdDebug(5800) << "Adding Journal without a DTSTART" << endl;
-
-  mJournalList.append(journal);
+    mJournalList.append(journal);
 
   journal->registerObserver( this );
 
   setModified( true );
-
+  if ( journal->calID() == 0 )
+      journal->setCalID( mDefaultCalendar );
+  journal->setCalEnabled( true );
   return true;
 }
 
@@ -703,12 +894,19 @@ void CalendarLocal::deleteJournal( Journal *journal )
   }
 }
 
+QPtrList<Journal> CalendarLocal::journals4Date( const QDate & date )
+{
+    QPtrList<Journal> el;
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->calEnabled() && it->dtStart().date() == date) el.append( it );
+    return el;
+}
 Journal *CalendarLocal::journal( const QDate &date )
 {
 //  kdDebug(5800) << "CalendarLocal::journal() " << date.toString() << endl;
 
   for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
-    if ( it->dtStart().date() == date )
+      if ( it->calEnabled() && it->dtStart().date() == date )
       return it;
 
   return 0;
@@ -716,15 +914,112 @@ Journal *CalendarLocal::journal( const QDate &date )
 
 Journal *CalendarLocal::journal( const QString &uid )
 {
-  for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
-    if ( it->uid() == uid )
-      return it;
-
-  return 0;
+    Journal * retVal = 0;
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->calEnabled() && it->uid() == uid ) {
+            if ( retVal ) {
+                if ( retVal->calID() > it->calID() ) {
+                    retVal = it;
+                }
+            } else {
+                retVal = it;
+            }
+        }
+    return retVal;
 }
 
 QPtrList<Journal> CalendarLocal::journals()
 {
-  return mJournalList;
+    QPtrList<Journal> el;
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->calEnabled() ) el.append( it );
+    return el;
+}
+void CalendarLocal::setCalendarRemove( int id )
+{
+   
+    {
+        QPtrList<Event> EventList = mEventList;
+        Event * ev = EventList.first();
+        while ( ev ) {
+            if ( ev->calID() == id )
+                deleteEvent( ev );
+            ev = EventList.next();
+        }
+    }
+    {
+
+        QPtrList<Todo> TodoList = mTodoList;
+        Todo * ev = TodoList.first();
+        while ( ev ) {
+            if ( ev->calID() == id )
+                deleteTodo( ev );
+            ev = TodoList.next();
+        }
+    }
+    {
+        QPtrList<Journal> JournalList = mJournalList;
+        Journal * ev = JournalList.first();
+        while ( ev ) {
+            if ( ev->calID() == id )
+                deleteJournal( ev );
+            ev = JournalList.next();
+        }
+    }
+
+    if ( mUndoIncidence ) delete mUndoIncidence;
+    mUndoIncidence = 0;
+
 }
 
+void CalendarLocal::setCalendarEnabled( int id, bool enable )
+{
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->calID() == id ) it->setCalEnabled( enable );
+
+    for ( Event *it = mEventList.first(); it; it = mEventList.next() )
+        if ( it->calID() == id ) it->setCalEnabled( enable );
+
+    for ( Todo *it = mTodoList.first(); it; it = mTodoList.next() )
+        if ( it->calID() == id ) it->setCalEnabled( enable );
+
+}
+
+void CalendarLocal::setReadOnly( int id, bool enable )
+{
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->calID() == id ) it->setReadOnly( enable );
+
+    for ( Event *it = mEventList.first(); it; it = mEventList.next() )
+        if ( it->calID() == id ) it->setReadOnly( enable );
+
+    for ( Todo *it = mTodoList.first(); it; it = mTodoList.next() )
+        if ( it->calID() == id ) it->setReadOnly( enable );
+
+}
+
+void CalendarLocal::setAlarmEnabled( int id, bool enable )
+{
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        if ( it->calID() == id ) it->setAlarmEnabled( enable );
+
+    for ( Event *it = mEventList.first(); it; it = mEventList.next() )
+        if ( it->calID() == id ) it->setAlarmEnabled( enable );
+
+    for ( Todo *it = mTodoList.first(); it; it = mTodoList.next() )
+        if ( it->calID() == id ) it->setAlarmEnabled( enable );
+    reInitAlarmSettings();
+
+}
+void CalendarLocal::setDefaultCalendarEnabledOnly()
+{
+    for ( Journal *it = mJournalList.first(); it; it = mJournalList.next() )
+        it->setCalEnabled( it->calID() == mDefaultCalendar );
+
+    for ( Event *it = mEventList.first(); it; it = mEventList.next() )
+        it->setCalEnabled( it->calID() == mDefaultCalendar);
+
+    for ( Todo *it = mTodoList.first(); it; it = mTodoList.next() )
+        it->setCalEnabled( it->calID() == mDefaultCalendar);
+
+}
