@@ -372,18 +372,15 @@ void ICalFormatImpl::writeIncidence(icalcomponent *parent,Incidence *incidence)
   }
 
   // recurrence rule stuff
-  Recurrence *recur = incidence->recurrence();
-  if (recur->doesRecur()) {
-    
-    icalcomponent_add_property(parent,writeRecurrenceRule(recur));
-  }
-
-  // recurrence excpetion dates
-  DateList dateList = incidence->exDates();
-  DateList::ConstIterator exIt;
-  for(exIt = dateList.begin(); exIt != dateList.end(); ++exIt) {
-    icalcomponent_add_property(parent,icalproperty_new_exdate(
-        writeICalDate(*exIt)));
+  if (incidence->doesRecur()) {
+      icalcomponent_add_property(parent,writeRecurrenceRule(incidence->recurrence()));
+      // recurrence excpetion dates
+      DateList dateList = incidence->exDates();
+      DateList::ConstIterator exIt;
+      for(exIt = dateList.begin(); exIt != dateList.end(); ++exIt) {
+          icalcomponent_add_property(parent,icalproperty_new_exdate(
+                                                                    writeICalDate(*exIt)));
+      }
   }
   
   // attachments
@@ -1023,6 +1020,9 @@ Journal *ICalFormatImpl::readJournal(icalcomponent *vjournal)
 
   readIncidence(vjournal,journal);
 
+  if ( !journal->dtStart().isValid() && journal->created().isValid() ) {
+      journal->setDtStart( journal->created() );
+  }
   return journal;
 }
 
@@ -1292,7 +1292,8 @@ void ICalFormatImpl::readIncidence(icalcomponent *parent,Incidence *incidence)
   }
 
   // Cancel backwards compatibility mode for subsequent changes by the application
-  incidence->recurrence()->setCompatVersion();
+  if ( readrec )
+      incidence->recurrence()->setCompatVersion();
 
   // add categories
   incidence->setCategories(categories);
@@ -2155,15 +2156,15 @@ icalcomponent *ICalFormatImpl::createScheduleComponent(IncidenceBase *incidence,
   icalcomponent_add_property(message,icalproperty_new_method(icalmethod));
 
   // TODO: check, if dynamic cast is required
-  if(incidence->type() == "Todo") {
+  if(incidence->typeID() == todoID ) {
     Todo *todo = static_cast<Todo *>(incidence);
     icalcomponent_add_component(message,writeTodo(todo));
   }
-  if(incidence->type() == "Event") {
+  if(incidence->typeID() == eventID ) {
     Event *event = static_cast<Event *>(incidence);
     icalcomponent_add_component(message,writeEvent(event));
   }
-  if(incidence->type() == "FreeBusy") {
+  if(incidence->typeID() == freebusyID) {
     FreeBusy *freebusy = static_cast<FreeBusy *>(incidence);
     icalcomponent_add_component(message,writeFreeBusy(freebusy, method));
   }
