@@ -33,7 +33,7 @@ Incidence::Incidence() :
   IncidenceBase(),
   mRelatedTo(0), mSecrecy(SecrecyPublic), mPriority(3)
 {
-  mRecurrence = new Recurrence(this);
+    mRecurrence = 0;//new Recurrence(this);
   mCancelled = false;
   recreate();
   mHasStartDate = true;
@@ -78,7 +78,10 @@ Incidence::Incidence( const Incidence &i ) : IncidenceBase( i )
   mAlarms.setAutoDelete(true);
   mHasRecurrenceID = i.mHasRecurrenceID;
   mRecurrenceID = i.mRecurrenceID;
-  mRecurrence = new Recurrence( *(i.mRecurrence), this );
+  if ( i.mRecurrence )
+      mRecurrence = new Recurrence( *(i.mRecurrence), this );
+  else
+      mRecurrence = 0;
   mHoliday = i.mHoliday ;
   mBirthday = i.mBirthday;
   mAnniversary = i.mAnniversary;
@@ -93,10 +96,40 @@ Incidence::~Incidence()
     if (ev->relatedTo() == this) ev->setRelatedTo(0);
   } 
   if (relatedTo()) relatedTo()->removeRelation(this);
-  delete mRecurrence; 
+  if ( mRecurrence ) 
+      delete mRecurrence; 
  
 }
+QString Incidence::durationText()
+{
+    return "---";
+}
+QString Incidence::durationText4Time( int offset )
+{
+    int min = offset/60;
+    int hours = min /60;
+    min = min % 60;
+    int days = hours /24;
+    hours = hours % 24;
 
+    if ( doesFloat() || ( min == 0 && hours == 0 )  ) {
+        if ( days == 1 )
+            return "1" + i18n(" day");
+        else
+            return QString::number( days )+   i18n(" days");
+
+    }
+    QString message = QString::number ( hours ) +":";
+    if ( min < 10 ) message += "0";
+    message += QString::number ( min );
+    if ( days > 0 ) { 
+        if ( days == 1 )
+            message =  "1" + i18n(" day") + " "+message;
+        else
+            message =  QString::number( days )+   i18n(" days") + " "+message;
+    }
+    return message; 
+}
 bool Incidence::isHoliday() const
 {
     return mHoliday;
@@ -208,10 +241,24 @@ bool KCal::operator==( const Incidence& i1, const Incidence& i2 )
     } else {
         return false;
     }
-    if (!( *i1.recurrence() == *i2.recurrence()) ) {
-        qDebug("recurrence is NOT equal ");
-        return false;
+    if ( i1.mRecurrence != 0 && i2.mRecurrence != 0 ) {
+        if (!( *i1.mRecurrence == *i2.mRecurrence) ) {
+            //qDebug("recurrence is NOT equal ");
+            return false;
+        }
+    } else {
+        // one ( or both ) recurrence is 0
+        if ( i1.mRecurrence == 0 ) {
+            if ( i2.mRecurrence != 0 && i2.mRecurrence->doesRecur() != Recurrence::rNone )
+                return false;
+        } else {
+            // i1.mRecurrence != 0
+            // i2.mRecurrence == 0
+            if ( i1.mRecurrence->doesRecur() != Recurrence::rNone )
+                return false;
+        }
     }
+   
     return
         //  i1.created() == i2.created() &&
         stringCompare( i1.description(), i2.description() ) &&
@@ -236,7 +283,7 @@ Incidence* Incidence::recreateCloneException( QDate d  )
     if ( doesRecur() ) {
         addExDate( d );
         newInc->recurrence()->unsetRecurs();
-        if ( type() == "Event") {
+        if ( typeID() == eventID ) {
             int len = dtStart().secsTo( ((Event*)this)->dtEnd());
             QTime tim = dtStart().time();
             newInc->setDtStart( QDateTime(d, tim) );
@@ -279,9 +326,30 @@ void Incidence::cloneRelations( Incidence * newInc )
 void Incidence::setReadOnly( bool readOnly )
 {
   IncidenceBase::setReadOnly( readOnly );
-  recurrence()->setRecurReadOnly( readOnly);
+  if ( mRecurrence )
+      mRecurrence->setRecurReadOnly( readOnly);
+}
+void Incidence::setLastModifiedSubInvalid()
+{
+    mLastModifiedSub = QDateTime();
+    if ( mRelatedTo )
+        mRelatedTo->setLastModifiedSubInvalid();
+}
+QDateTime Incidence::lastModifiedSub()
+{
+    if ( !mRelations.count() )
+        return lastModified();
+    if ( mLastModifiedSub.isValid() )
+        return mLastModifiedSub;
+    mLastModifiedSub = lastModified();
+    Incidence * inc;
+    QPtrList<Incidence> Relations = relations();
+    for (inc=Relations.first();inc;inc=Relations.next()) {
+        if ( inc->lastModifiedSub() > mLastModifiedSub )
+            mLastModifiedSub = inc->lastModifiedSub();
+    }
+    return mLastModifiedSub;
 }
-
 void Incidence::setCreated(QDateTime created)
 {
   if (mReadOnly) return;
@@ -310,7 +378,9 @@ void Incidence::setDtStart(const QDateTime &dtStart)
 {
 
   QDateTime  dt = getEvenTime(dtStart);
-  recurrence()->setRecurStart( dt);
+
+  if ( mRecurrence )
+      mRecurrence->setRecurStart( dt);
   IncidenceBase::setDtStart( dt );
 }
 
@@ -396,6 +466,11 @@ void Incidence::setCategories(const QString &catStr)
   checkCategories();
   updated();
 }
+// using this makes filtering 3 times faster
+QStringList* Incidence::categoriesP()
+{
+  return &mCategories;
+}
 
 QStringList Incidence::categories() const
 {
@@ -450,8 +525,20 @@ QPtrList<Incidence> Incidence::relations() const
   return mRelations;
 }
 
+void Incidence::addRelationsToList(QPtrList<Incidence> *rel)
+{
+    Incidence* inc;
+    QPtrList<Incidence> Relations = relations();
+    for (inc=Relations.first();inc;inc=Relations.next()) {
+        inc->addRelationsToList( rel );
+    } 
+    if ( rel->findRef( this ) == -1 ) 
+        rel->append( this );
+}
+
 void Incidence::addRelation(Incidence *event)
 {
+    setLastModifiedSubInvalid();
   if( mRelations.findRef( event ) == -1 ) {
     mRelations.append(event);
     //updated();
@@ -460,15 +547,14 @@ void Incidence::addRelation(Incidence *event)
 
 void Incidence::removeRelation(Incidence *event)
 {
-  
-  mRelations.removeRef(event); 
- 
+    setLastModifiedSubInvalid();
+  mRelations.removeRef(event);
 //  if (event->getRelatedTo() == this) event->setRelatedTo(0);
 }
 
 bool Incidence::recursOn(const QDate &qd) const
 {
-  if (recurrence()->recursOnPure(qd) && !isException(qd)) return true;
+  if (mRecurrence && mRecurrence->recursOnPure(qd) && !isException(qd)) return true;
   else return false;
 }
 
@@ -476,7 +562,6 @@ void Incidence::setExDates(const DateList &exDates)
 {
   if (mReadOnly) return;
   mExDates = exDates;
-
   recurrence()->setRecurExDatesCount(mExDates.count());
 
   updated();
@@ -662,15 +747,22 @@ bool Incidence::isAlarmEnabled() const
   }
   return false;
 }
-
-Recurrence *Incidence::recurrence() const
+#include <stdlib.h>
+Recurrence *Incidence::recurrence()
 {
+    if ( ! mRecurrence ) {
+        mRecurrence = new Recurrence(this);
+        mRecurrence->setRecurStart( dtStart() );
+        //qDebug("creating new recurence ");
+        //abort();
+    }
   return mRecurrence;
 }
 void Incidence::setRecurrence( Recurrence * r) 
 {
-  delete mRecurrence;
-  mRecurrence = r;
+    if ( mRecurrence )
+        delete mRecurrence;
+    mRecurrence = r;
 }
 
 void Incidence::setLocation(const QString &location)
@@ -684,6 +776,11 @@ QString Incidence::location() const
 {
   return mLocation;
 }
+QString Incidence::recurrenceText() const
+{
+    if ( mRecurrence ) return mRecurrence->recurrenceText();
+    return i18n("No");
+}
 
 ushort Incidence::doesRecur() const
 {
@@ -697,12 +794,12 @@ QDateTime Incidence::getNextOccurence( const QDateTime& dt, bool* ok ) const
     *ok = false;
     if ( doesRecur() ) {
         bool last;
-         recurrence()->getPreviousDateTime( incidenceStart , &last );
+         mRecurrence->getPreviousDateTime( incidenceStart , &last );
          int count = 0;
          if ( !last ) {
              while ( !last ) {
                  ++count;
-                 incidenceStart = recurrence()->getNextDateTime( incidenceStart, &last );
+                 incidenceStart = mRecurrence->getNextDateTime( incidenceStart, &last );
                  if ( recursOn( incidenceStart.date() ) ) {
                      last = true; // exit while llop
                  } else {
@@ -724,7 +821,7 @@ QDateTime Incidence::getNextOccurence( const QDateTime& dt, bool* ok ) const
         if ( hasStartDate () ) {
             incidenceStart = dtStart(); 
         }
-        if ( type() =="Todo" ) {
+        if ( typeID() == todoID ) {
             if ( ((Todo*)this)->hasDueDate() )
                 incidenceStart = ((Todo*)this)->dtDue();
         }
@@ -736,7 +833,7 @@ QDateTime Incidence::getNextOccurence( const QDateTime& dt, bool* ok ) const
 QDateTime Incidence::dtStart() const
 {
     if ( doesRecur() ) {
-        if ( type() == "Todo" ) {
+        if ( typeID() == todoID ) {
             ((Todo*)this)->checkSetCompletedFalse();
         }
     }
