@@ -392,7 +392,7 @@ VObject *VCalFormat::eventToVTodo(const Todo *anEvent)
   return vtodo;
 }
 
-VObject* VCalFormat::eventToVEvent(const Event *anEvent)
+VObject* VCalFormat::eventToVEvent(Event *anEvent)
 {
   VObject *vevent;
   QString tmpStr;
@@ -459,7 +459,7 @@ VObject* VCalFormat::eventToVEvent(const Event *anEvent)
   }
 
   // recurrence rule stuff
-  if (anEvent->recurrence()->doesRecur()) {
+  if (anEvent->doesRecur()) {
     // some more variables
     QPtrList<Recurrence::rMonthPos> tmpPositions;
     QPtrList<int> tmpDays;
