@@ -25,11 +25,12 @@
 Enhanced Version of the file for platform independent KDE tools.
 Copyright (c) 2004 Ulf Schenk
 
-$Id: externalapphandler.cpp,v 1.21 2005/04/03 05:23:46 zautrix Exp $
+$Id: externalapphandler.cpp,v 1.22 2005/06/29 16:15:53 zautrix Exp $
 */
 #include <stdlib.h>
 
 #include <qfile.h>
+#include <qtimer.h>
 #include <qmap.h>
 #include <qregexp.h>
 
@@ -1129,15 +1130,20 @@ void ExternalAppHandler::passParameters(QCopEnvelope* e, const QString& paramete
 
 void ExternalAppHandler::appMessage( const QCString& cmsg, const QByteArray& data )
 {
-
+    qDebug("ExternalAppHandler::appMessage %s %x", cmsg.data(), this);
     if ( cmsg == "nextView()" ) {
         qDebug("nextView()");
-        emit nextView();
+        QTimer::singleShot( 0, this, SIGNAL ( nextView() ));
         return;
     }
     if ( cmsg == "callContactdialog()" ) {
         qDebug("callContactdialog()");
-        emit callContactdialog();
+        QTimer::singleShot( 0, this, SIGNAL ( callContactdialog() ));
+        return;
+    }
+    if ( cmsg == "doRingSync" ) {
+        qDebug("doRingSync");
+        QTimer::singleShot( 0, this, SIGNAL ( doRingSync() ));
         return;
     }
     
