@@ -18,7 +18,7 @@
   Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksyncmanager.cpp,v 1.54 2005/04/04 09:34:58 zautrix Exp $
+// $Id: ksyncmanager.cpp,v 1.57 2005/07/08 23:55:56 zautrix Exp $
 
 #include "ksyncmanager.h"
 
@@ -49,6 +49,7 @@
 #include <qtextcodec.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
+#include <qapplication.h>
 
 #include <klocale.h>
 #include <kglobal.h>
@@ -352,7 +353,7 @@ void KSyncManager::enableQuick( bool ask )
         lay.setMargin(7);
         lay.setSpacing(7);
         int po = 9197+mTargetApp;
-        QLabel label ( i18n("Port number (Default: %1)").arg(po), &dia );
+        QLabel label ( i18n("Port number (Default: %1)\nValid range from 1 to 65535").arg(po), &dia );
         lay.addWidget( &label);
         lay.addWidget( &lab);
 
@@ -414,16 +415,18 @@ void KSyncManager::enableQuick( bool ask )
         changed =  true;
     bool ok;
     mPrefs->mPassiveSyncAutoStart = false;
-    Q_UINT16 port = mPrefs->mPassiveSyncPort.toUInt(&ok);
-    if ( ! ok ) {
-        KMessageBox::information( 0, i18n("No valid port"));
+    Q_UINT32 port_t = mPrefs->mPassiveSyncPort.toUInt(&ok);
+    qDebug("%d ", port_t);
+    if ( ! ok || port_t > 65535 ) {
+        KMessageBox::information( 0, i18n("No valid port number:\n%1").arg ( mPrefs->mPassiveSyncPort ), i18n("Pi-Sync Port Error"));
         return;
     }
+    Q_UINT16 port = port_t;
     //qDebug("port %d ", port);
     mServerSocket = new KServerSocket ( mPrefs->mPassiveSyncPw, port ,1 );
     mServerSocket->setFileName( defaultFileName() );//bbb
     if ( !mServerSocket->ok() ) {
-        KMessageBox::information( 0, i18n("Failed to bind or\nlisten to the port!"));
+        QTimer::singleShot( 2000, this, SLOT ( displayErrorPort() ) );
         delete mServerSocket;
         mServerSocket = 0;
         return;
@@ -435,7 +438,10 @@ void KSyncManager::enableQuick( bool ask )
     connect( mServerSocket, SIGNAL ( request_file() ),this, SIGNAL  ( request_file() ) );
     connect( mServerSocket, SIGNAL ( file_received( bool ) ), this,  SIGNAL  ( getFile( bool ) ) );
 }
-
+void KSyncManager::displayErrorPort()
+{
+    KMessageBox::information( 0, i18n("<b>Enabling Pi-Sync failed!</b> Failed to bind or listen to the port %1! Is another instance already listening to that port?").arg( mPrefs->mPassiveSyncPort) , i18n("Pi-Sync Port Error"));
+}
 void KSyncManager::syncLocalFile()
 {
 
@@ -521,14 +527,16 @@ void KSyncManager::multiSync( bool askforPrefs  )
     if (blockSave())
         return;
     setBlockSave(true);
-    QString question = i18n("Do you really want\nto multiple sync\nwith all checked profiles?\nSyncing takes some\ntime - all profiles\nare synced twice!");
-    if ( QMessageBox::information( mParent, i18n("KDE-Pim Sync"),
-                                   question,
-                                   i18n("Yes"), i18n("No"),
-                                   0, 0 ) != 0 ) {
-        setBlockSave(false);
-        mParent->topLevelWidget()->setCaption(i18n("Aborted! Nothing synced!"));
-        return;
+    if ( askforPrefs ) {
+        QString question = i18n("Do you really want\nto multiple sync\nwith all checked profiles?\nSyncing takes some\ntime - all profiles\nare synced twice!");
+        if ( QMessageBox::information( mParent, i18n("KDE-Pim Sync"),
+                                       question,
+                                       i18n("Yes"), i18n("No"),
+                                       0, 0 ) != 0 ) {
+            setBlockSave(false);
+            mParent->topLevelWidget()->setCaption(i18n("Aborted! Nothing synced!"));
+            return;
+        }
     }
     mCurrentSyncDevice = i18n("Multiple profiles") ;
     mSyncAlgoPrefs = mPrefs->mRingSyncAlgoPrefs;
@@ -793,7 +801,7 @@ bool KSyncManager::edit_pisync_options()
     lay.addWidget( &lab2 );
     QLineEdit le2 (&dia );
     lay.addWidget( &le2 );
-    QLabel lab3 ( i18n("Remote port number:"), &dia);
+    QLabel lab3 ( i18n("Remote port number:\n(May be: 1 - 65535)"), &dia);
     lay.addWidget( &lab3 );
     QLineEdit le3 (&dia );
     lay.addWidget( &le3 );
@@ -1185,8 +1193,10 @@ void KSyncManager::readFileFromSocket()
     }
     KCommandSocket* commandSocket = new KCommandSocket( mPassWordPiSync, mActiveSyncPort.toUInt(), mActiveSyncIP, this, mParent->topLevelWidget() );
     connect( commandSocket, SIGNAL(commandFinished( KCommandSocket*, int)), this, SLOT(deleteCommandSocket(KCommandSocket*, int )) );
-    if ( mWriteBackFile && syncOK  ) 
+    if ( mWriteBackFile && syncOK  ) {
+        mParent->topLevelWidget()->setCaption( i18n("Sending back file ...") );
         commandSocket->writeFile(  fileName );
+    }
     else {
         commandSocket->sendStop();
         if ( syncOK ) 
@@ -1289,11 +1299,11 @@ void KServerSocket::readClient()
 void KServerSocket::displayErrorMessage()
 {
     if ( mErrorMessage == 1 ) {
-        KMessageBox::error( 0, i18n("Got send file request\nwith invalid password"));
+        KMessageBox::error( 0, i18n("Got send file request\nwith invalid password"), i18n("Pi-Sync Error"));
         mErrorMessage = 0;
     }
     else if ( mErrorMessage == 2 ) {
-        KMessageBox::error( 0, i18n("Got receive file request\nwith invalid password"));
+        KMessageBox::error( 0, i18n("Got receive file request\nwith invalid password"), i18n("Pi-Sync Error"));
         mErrorMessage = 0;
     }
 }
@@ -1463,13 +1473,19 @@ KCommandSocket::KCommandSocket (  QString password, Q_UINT16 port, QString host,
     tlw = cap;
     mRetVal = quiet;
     mTimerSocket = new QTimer ( this );
-    connect( mTimerSocket, SIGNAL ( timeout () ), this, SLOT ( deleteSocket()  ) );
+    connect( mTimerSocket, SIGNAL ( timeout () ), this, SLOT ( updateConnectDialog() ) );
+    mConnectProgress.setCaption( i18n("Pi-Sync") );
+    connect( &mConnectProgress, SIGNAL ( cancelled () ), this, SLOT ( deleteSocket() ) );
+    mConnectCount = -1;
 }
 void KCommandSocket::sendFileRequest()
 {
     if ( tlw )
         tlw->setCaption( i18n("Connected! Sending request for remote file ...") );
-    mTimerSocket->start( 300000 );
+    mConnectProgress.hide();
+    mConnectCount = 300;mConnectMax = 300;
+    mConnectProgress.setCaption( i18n("Pi-Sync: Connected!") );
+    mTimerSocket->start( 100, true );
     QTextStream os( mSocket );
     os.setEncoding( QTextStream::Latin1 );
 
@@ -1490,11 +1506,30 @@ void KCommandSocket::readFile( QString fn )
     mFirst = true;
     if ( tlw )
         tlw->setCaption( i18n("Trying to connect to remote...") );
-    mTimerSocket->start( 20000 );
+    mConnectCount = 30;mConnectMax = 30;
+    mTimerSocket->start( 1000, true );
     mSocket->connectToHost( mHost, mPort ); 
     qDebug("KSS: Waiting for connection");
 }
-
+void KCommandSocket::updateConnectDialog()
+{
+    
+    if ( mConnectCount == mConnectMax  ) {
+        //qDebug("MAXX %d", mConnectMax);
+        mConnectProgress.setTotalSteps ( 30 );
+        mConnectProgress.show();
+        mConnectProgress.setLabelText( i18n("Trying to connect to remote...") );
+    }
+    //qDebug("updateConnectDialog() %d", mConnectCount);
+    mConnectProgress.raise();
+    mConnectProgress.setProgress( (mConnectMax - mConnectCount)%30 );
+    --mConnectCount;
+    if ( mConnectCount > 0 )
+        mTimerSocket->start( 1000, true );
+    else
+        deleteSocket(); 
+    
+}
 void KCommandSocket::writeFile( QString fileName  )
 {
     if ( !mSocket ) {
@@ -1503,7 +1538,8 @@ void KCommandSocket::writeFile( QString fileName  )
         connect( mSocket, SIGNAL(connected ()), this, SLOT(writeFileToSocket()) );
     }
     mFileName = fileName ;
-    mTimerSocket->start( 20000 );
+    mConnectCount = 30;mConnectMax = 30;
+    mTimerSocket->start( 1000, true );
     mSocket->connectToHost( mHost, mPort ); 
 }
 void KCommandSocket::writeFileToSocket()
@@ -1511,26 +1547,41 @@ void KCommandSocket::writeFileToSocket()
     mTimerSocket->stop();
     QFile file2( mFileName );
     if (!file2.open( IO_ReadOnly ) ) {
+        mConnectProgress.hide();
+        mConnectCount = -1;
         mRetVal= errorW;
         mSocket->close();
         if ( mSocket->state() == QSocket::Idle )
             QTimer::singleShot( 10, this , SLOT ( deleteSocket()));
         return ;
     }  
+    mConnectProgress.setTotalSteps ( file2.size() );
+    mConnectProgress.show();
+    int count = 0;
+    mConnectProgress.setLabelText( i18n("Sending back synced file...") );
+    mConnectProgress.setProgress( count );
+    mConnectProgress.blockSignals( true );
     QTextStream ts2( &file2 );
     ts2.setEncoding( QTextStream::Latin1 );
     QTextStream os2( mSocket );
     os2.setEncoding( QTextStream::Latin1 );
     os2 << "PUT " << mPassWord << "\r\n\r\n";;
     while ( ! ts2.atEnd() ) {
-        os2 << ts2.readLine() << "\r\n";
+        qApp->processEvents();
+        mConnectProgress.setProgress( count );
+        QString temp = ts2.readLine();
+        count += temp.length();
+        os2 << temp << "\r\n";
     }
+    file2.close();
+    mConnectProgress.hide();
+    mConnectCount = -1;
     os2 << "\r\n";
     mRetVal= successW;
-    file2.close();
     mSocket->close();
     if ( mSocket->state() == QSocket::Idle )
         QTimer::singleShot( 10, this , SLOT ( deleteSocket()));
+    mConnectProgress.blockSignals( false );
 }
 void KCommandSocket::sendStop()
 {
@@ -1551,8 +1602,8 @@ void KCommandSocket::startReadFileFromSocket()
 {
     if ( ! mFirst )
         return;
+    mConnectProgress.setLabelText( i18n("Receiving file from remote...") );
     mFirst = false;
-    mTimerSocket->stop();
     mFileString = "";
     mTime.start();
     mFirstLine = true;
@@ -1568,6 +1619,8 @@ void KCommandSocket::readFileFromSocket()
         if ( mFirstLine ) {
             mFirstLine = false;
             if (  line.left( 6 ) == "ERROR_" ) {
+                mTimerSocket->stop();
+                mConnectCount = -1;
                 if (  line.left( 8 ) == "ERROR_PW" ) {
                     mRetVal = errorPW;
                     deleteSocket();
@@ -1602,6 +1655,9 @@ void KCommandSocket::readFileFromSocket()
         QTimer::singleShot( 100, this , SLOT (readFileFromSocket( ) ));
         return;
     }
+    mTimerSocket->stop();
+    mConnectCount = -1;
+    mConnectProgress.hide();
     QString fileName = mFileName;
     QFile file ( fileName );
     if (!file.open( IO_WriteOnly ) ) {
@@ -1629,7 +1685,9 @@ void KCommandSocket::readFileFromSocket()
 void KCommandSocket::deleteSocket()
 {
     //qDebug("KCommandSocket::deleteSocket() ");
-    if ( mTimerSocket->isActive () ) {
+    mConnectProgress.hide();
+   
+    if ( mConnectCount >= 0  ) {
         mTimerSocket->stop();
         mRetVal = errorTO;
         qDebug("KCS::Connection to remote host timed out");
@@ -1640,7 +1698,10 @@ void KCommandSocket::deleteSocket()
             delete mSocket;
             mSocket = 0;
         }
+        if ( mConnectCount == 0  )
         KMessageBox::error( 0, i18n("Connection to remote\nhost timed out!\nDid you forgot to enable\nsyncing on remote host?"));
+        else if ( tlw )
+            tlw->setCaption( i18n("Connection to remote host cancelled!") );
         emit commandFinished( this, mRetVal );
         return;      
     }
@@ -1648,5 +1709,6 @@ void KCommandSocket::deleteSocket()
     if ( mSocket)
         delete mSocket;
     mSocket = 0; 
+    qDebug("commandFinished ");
     emit commandFinished( this, mRetVal );
 }
