@@ -180,6 +180,17 @@ void KSyncPrefsDialog::setupSyncAlgTab()
        //topLayout->addMultiCellWidget(mShowSummaryAfterSync, iii,iii,0,1);
        //++iii;  
 
+#if 0
+       QHGroupBox* gb51 = new QHGroupBox( i18n("Local resources to sync with:"), topFrame); 
+       {
+           QVBox * fibo2 = new QVBox ( gb51 );
+           new QLabel ( i18n("Calendar resources:"), fibo2 );
+           //mFilterInCal = new QComboBox( fibo2 );
+           fibo2 = new QVBox ( gb51 );
+           new QLabel ( i18n("Addressbook resources:"), fibo2 );
+           //mFilterInAB = new QComboBox( fibo2 ); 
+       }
+#endif
        QHGroupBox* gb5 = new QHGroupBox( i18n("Apply filter when adding data to local:"), topFrame);
        QVBox * fibo2 = new QVBox ( gb5 );
        new QLabel ( i18n("Incoming calendar filter:"), fibo2 );
