@@ -16,6 +16,7 @@ void KColorButton:: edit()
         mColor = col;
         setColor ( mColor );
         emit changed ( mColor );
+        emit changedID ( mColor, id );
     }
 #else
     KColorDialog* k =  new KColorDialog( this );
@@ -25,6 +26,7 @@ void KColorButton:: edit()
         mColor = k->getColor(); 
         setColor ( mColor );
         emit changed ( mColor );
+        emit changedID ( mColor, id );
     }
     delete k;
 #endif
@@ -32,12 +34,17 @@ void KColorButton:: edit()
 KColorButton::KColorButton( QWidget *p ):QPushButton( p )
 {
     int size = 24;
-    if(  QApplication::desktop()->width() < 480 )
+    if(  QApplication::desktop()->width() < 480 || QApplication::desktop()->height() <= 320 )
         size = 18;
     setFixedSize( size,size );
+    int id = 0;
     connect ( this, SIGNAL( clicked() ), this ,SLOT (edit() ));
     
 }
+void KColorButton::setID ( int i) 
+{
+    id = i;
+}
 void KColorButton::setColor ( const QColor & c) 
 {
  mColor = c; 
